// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_ParallelReader$ParallelTermPositions__
#define __org_apache_lucene_index_ParallelReader$ParallelTermPositions__

#pragma interface

#include <org/apache/lucene/index/ParallelReader$ParallelTermDocs.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class ParallelReader$ParallelTermPositions;
          class Term;
          class ParallelReader;
        }
      }
    }
  }
}

class org::apache::lucene::index::ParallelReader$ParallelTermPositions : public ::org::apache::lucene::index::ParallelReader$ParallelTermDocs
{
public:
  ParallelReader$ParallelTermPositions (::org::apache::lucene::index::ParallelReader *);
  ParallelReader$ParallelTermPositions (::org::apache::lucene::index::ParallelReader *, ::org::apache::lucene::index::Term *);
  virtual void seek (::org::apache::lucene::index::Term *);
  virtual jint nextPosition ();
private:
  ::org::apache::lucene::index::ParallelReader * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::ParallelReader$ParallelTermDocs )))) this$0;

  friend class org_apache_lucene_index_ParallelReader$ParallelTermPositions;
  friend class org_apache_lucene_index_ParallelReader$ParallelTermDocs;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_ParallelReader$ParallelTermPositions__ */
