// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_IndexOutput__
#define __org_apache_lucene_store_IndexOutput__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class IndexOutput;
        }
      }
    }
  }
}

class org::apache::lucene::store::IndexOutput : public ::java::lang::Object
{
public:
  IndexOutput ();
  virtual void writeByte (jbyte) = 0;
  virtual void writeBytes (jbyteArray, jint) = 0;
  virtual void writeInt (jint);
  virtual void writeVInt (jint);
  virtual void writeLong (jlong);
  virtual void writeVLong (jlong);
  virtual void writeString (::java::lang::String *);
  virtual void writeChars (::java::lang::String *, jint, jint);
  virtual void flush () = 0;
  virtual void close () = 0;
  virtual jlong getFilePointer () = 0;
  virtual void seek (jlong) = 0;
  virtual jlong length () = 0;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_IndexOutput__ */
