// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_ru_RussianCharsets__
#define __org_apache_lucene_analysis_ru_RussianCharsets__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace ru
          {
            class RussianCharsets;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::ru::RussianCharsets : public ::java::lang::Object
{
public:
  RussianCharsets ();
  static jchar toLowerCase (jchar, jcharArray);
  static jcharArray UnicodeRussian;
  static jcharArray KOI8;
  static jcharArray CP1251;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_ru_RussianCharsets__ */
