// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Filter__
#define __org_apache_lucene_search_Filter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Filter;
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::Filter : public ::java::lang::Object
{
public:
  Filter ();
  virtual ::java::util::BitSet *bits (::org::apache::lucene::index::IndexReader *) = 0;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Filter__ */
