// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_PhraseScorer__
#define __org_apache_lucene_search_PhraseScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermPositions;
        }
        namespace search
        {
          class PhraseScorer;
          class Explanation;
          class Similarity;
          class PhrasePositions;
          class PhraseQueue;
          class Weight;
        }
      }
    }
  }
}

class org::apache::lucene::search::PhraseScorer : public ::org::apache::lucene::search::Scorer
{
public: // actually package-private
  PhraseScorer (::org::apache::lucene::search::Weight *, JArray< ::org::apache::lucene::index::TermPositions *> *, jintArray, ::org::apache::lucene::search::Similarity *, jbyteArray);
public:
  virtual jint doc ();
  virtual jboolean next ();
private:
  jboolean doNext ();
public:
  virtual jfloat score ();
  virtual jboolean skipTo (jint);
public:  // actually protected
  virtual jfloat phraseFreq () = 0;
private:
  void init ();
  void sort ();
public:  // actually protected
  void pqToList ();
  void firstToLast ();
public:
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::search::Weight * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) weight;
public:  // actually protected
  jbyteArray norms;
  jfloat value;
private:
  jboolean firstTime;
  jboolean more;
public:  // actually protected
  ::org::apache::lucene::search::PhraseQueue *pq;
  ::org::apache::lucene::search::PhrasePositions *first;
  ::org::apache::lucene::search::PhrasePositions *last;
private:
  jfloat freq;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_PhraseScorer__ */
