// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentTermPositions__
#define __org_apache_lucene_index_SegmentTermPositions__

#pragma interface

#include <org/apache/lucene/index/SegmentTermDocs.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentTermPositions;
          class TermInfo;
          class SegmentReader;
        }
        namespace store
        {
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentTermPositions : public ::org::apache::lucene::index::SegmentTermDocs
{
public: // actually package-private
  SegmentTermPositions (::org::apache::lucene::index::SegmentReader *);
  void seek (::org::apache::lucene::index::TermInfo *);
public:
  void close ();
  jint nextPosition ();
public:  // actually protected
  void skippingDoc ();
public:
  jboolean next ();
  jint read (jintArray, jintArray);
public:  // actually protected
  void skipProx (jlong);
private:
  void skipPositions (jint);
  void lazySkip ();
  ::org::apache::lucene::store::IndexInput * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::SegmentTermDocs )))) proxStream;
  jint proxCount;
  jint position;
  jlong lazySkipPointer;
  jint lazySkipDocCount;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentTermPositions__ */
