// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_Token__
#define __org_apache_lucene_queryParser_Token__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::Token : public ::java::lang::Object
{
public:
  Token ();
  virtual ::java::lang::String *toString () { return image; }
  static ::org::apache::lucene::queryParser::Token *newToken (jint);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  kind;
  jint beginLine;
  jint beginColumn;
  jint endLine;
  jint endColumn;
  ::java::lang::String *image;
  ::org::apache::lucene::queryParser::Token *next;
  ::org::apache::lucene::queryParser::Token *specialToken;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_Token__ */
