// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_TokenSources$1StoredTokenStream__
#define __org_apache_lucene_search_highlight_TokenSources$1StoredTokenStream__

#pragma interface

#include <org/apache/lucene/analysis/TokenStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class TokenSources$1StoredTokenStream;
          }
        }
        namespace analysis
        {
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::TokenSources$1StoredTokenStream : public ::org::apache::lucene::analysis::TokenStream
{
public: // actually package-private
  TokenSources$1StoredTokenStream (JArray< ::org::apache::lucene::analysis::Token *> *);
public:
  virtual ::org::apache::lucene::analysis::Token *next ();
public: // actually package-private
  JArray< ::org::apache::lucene::analysis::Token *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenStream )))) tokens;
  jint currentToken;

  friend class org_apache_lucene_search_highlight_TokenSources$1StoredTokenStream;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_TokenSources$1StoredTokenStream__ */
