// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_el_GreekAnalyzer__
#define __org_apache_lucene_analysis_el_GreekAnalyzer__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace el
          {
            class GreekAnalyzer;
          }
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::el::GreekAnalyzer : public ::org::apache::lucene::analysis::Analyzer
{
public:
  GreekAnalyzer ();
  GreekAnalyzer (jcharArray);
  GreekAnalyzer (jcharArray, JArray< ::java::lang::String *> *);
private:
  static JArray< ::java::lang::String *> *makeStopWords (jcharArray);
public:
  GreekAnalyzer (jcharArray, ::java::util::Hashtable *);
  ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);
private:
  static jchar A;
  static jchar B;
  static jchar G;
  static jchar D;
  static jchar E;
  static jchar Z;
  static jchar H;
  static jchar TH;
  static jchar I;
  static jchar K;
  static jchar L;
  static jchar M;
  static jchar N;
  static jchar KS;
  static jchar O;
  static jchar P;
  static jchar R;
  static jchar S;
  static jchar T;
  static jchar Y;
  static jchar F;
  static jchar X;
  static jchar PS;
  static jchar W;
  static JArray<jcharArray> * GREEK_STOP_WORDS;
  ::java::util::Set * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Analyzer )))) stopSet;
  jcharArray charset;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_el_GreekAnalyzer__ */
