// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MultiPhraseQuery$MultiPhraseWeight__
#define __org_apache_lucene_search_MultiPhraseQuery$MultiPhraseWeight__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class MultiPhraseQuery$MultiPhraseWeight;
          class Explanation;
          class Scorer;
          class Query;
          class Searcher;
          class MultiPhraseQuery;
          class Similarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::MultiPhraseQuery$MultiPhraseWeight : public ::java::lang::Object
{
public:
  MultiPhraseQuery$MultiPhraseWeight (::org::apache::lucene::search::MultiPhraseQuery *, ::org::apache::lucene::search::Searcher *);
  virtual ::org::apache::lucene::search::Query *getQuery () { return reinterpret_cast< ::org::apache::lucene::search::Query *> (this$0); }
  virtual jfloat getValue () { return value; }
  virtual jfloat sumOfSquaredWeights ();
  virtual void normalize (jfloat);
  virtual ::org::apache::lucene::search::Scorer *scorer (::org::apache::lucene::index::IndexReader *);
  virtual ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::index::IndexReader *, jint);
private:
  ::org::apache::lucene::search::Similarity * __attribute__((aligned(__alignof__( ::java::lang::Object )))) similarity;
  jfloat value;
  jfloat idf;
  jfloat queryNorm;
  jfloat queryWeight;
  ::org::apache::lucene::search::MultiPhraseQuery *this$0;

  friend class org_apache_lucene_search_MultiPhraseQuery$MultiPhraseWeight;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MultiPhraseQuery$MultiPhraseWeight__ */
