// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MatchAllDocsQuery__
#define __org_apache_lucene_search_MatchAllDocsQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class MatchAllDocsQuery;
          class Weight;
          class Searcher;
        }
      }
    }
  }
}

class org::apache::lucene::search::MatchAllDocsQuery : public ::org::apache::lucene::search::Query
{
public:
  MatchAllDocsQuery ();
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Searcher *);
public:
  virtual void extractTerms (::java::util::Set *) { }
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();

  friend class org_apache_lucene_search_MatchAllDocsQuery$MatchAllDocsWeight;
  friend class org_apache_lucene_search_MatchAllDocsQuery$MatchAllScorer;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MatchAllDocsQuery__ */
