// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_SpanNearQuery__
#define __org_apache_lucene_search_spans_SpanNearQuery__

#pragma interface

#include <org/apache/lucene/search/spans/SpanQuery.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class Query;
          namespace spans
          {
            class SpanNearQuery;
            class Spans;
            class SpanQuery;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::SpanNearQuery : public ::org::apache::lucene::search::spans::SpanQuery
{
public:
  SpanNearQuery (JArray< ::org::apache::lucene::search::spans::SpanQuery *> *, jint, jboolean);
  virtual JArray< ::org::apache::lucene::search::spans::SpanQuery *> *getClauses ();
  virtual jint getSlop () { return slop; }
  virtual jboolean isInOrder () { return inOrder; }
  virtual ::java::lang::String *getField () { return field; }
  virtual ::java::util::Collection *getTerms ();
  virtual void extractTerms (::java::util::Set *);
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual ::org::apache::lucene::search::spans::Spans *getSpans (::org::apache::lucene::index::IndexReader *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  ::java::util::List * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::spans::SpanQuery )))) clauses;
  jint slop;
  jboolean inOrder;
  ::java::lang::String *field;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_SpanNearQuery__ */
