// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_standard_StandardTokenizerTokenManager__
#define __org_apache_lucene_analysis_standard_StandardTokenizerTokenManager__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace standard
          {
            class StandardTokenizerTokenManager;
            class Token;
            class CharStream;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::standard::StandardTokenizerTokenManager : public ::java::lang::Object
{
public:
  virtual void setDebugStream (::java::io::PrintStream *);
private:
  jint jjMoveStringLiteralDfa0_0 ();
  void jjCheckNAdd (jint);
  void jjAddStates (jint, jint);
  void jjCheckNAddTwoStates (jint, jint);
  void jjCheckNAddStates (jint, jint);
  void jjCheckNAddStates (jint);
  jint jjMoveNfa_0 (jint, jint);
  static jboolean jjCanMove_0 (jint, jint, jint, jlong, jlong);
  static jboolean jjCanMove_1 (jint, jint, jint, jlong, jlong);
  static jboolean jjCanMove_2 (jint, jint, jint, jlong, jlong);
  static jboolean jjCanMove_3 (jint, jint, jint, jlong, jlong);
  static jboolean jjCanMove_4 (jint, jint, jint, jlong, jlong);
public:
  StandardTokenizerTokenManager (::org::apache::lucene::analysis::standard::CharStream *);
  StandardTokenizerTokenManager (::org::apache::lucene::analysis::standard::CharStream *, jint);
  virtual void ReInit (::org::apache::lucene::analysis::standard::CharStream *);
private:
  void ReInitRounds ();
public:
  virtual void ReInit (::org::apache::lucene::analysis::standard::CharStream *, jint);
  virtual void SwitchTo (jint);
public:  // actually protected
  virtual ::org::apache::lucene::analysis::standard::Token *jjFillToken ();
public:
  virtual ::org::apache::lucene::analysis::standard::Token *getNextToken ();
  ::java::io::PrintStream * __attribute__((aligned(__alignof__( ::java::lang::Object )))) debugStream;
public: // actually package-private
  static jlongArray jjbitVec0;
  static jlongArray jjbitVec2;
  static jlongArray jjbitVec3;
  static jlongArray jjbitVec4;
  static jlongArray jjbitVec5;
  static jlongArray jjbitVec6;
  static jlongArray jjbitVec7;
  static jlongArray jjbitVec8;
  static jlongArray jjbitVec9;
  static jlongArray jjbitVec10;
  static jlongArray jjbitVec11;
  static jlongArray jjbitVec12;
  static jlongArray jjbitVec13;
  static jlongArray jjbitVec14;
  static jlongArray jjbitVec15;
  static jlongArray jjbitVec16;
  static jlongArray jjbitVec17;
  static jlongArray jjbitVec18;
  static jlongArray jjbitVec19;
  static jintArray jjnextStates;
public:
  static JArray< ::java::lang::String *> *jjstrLiteralImages;
  static JArray< ::java::lang::String *> *lexStateNames;
public: // actually package-private
  static jlongArray jjtoToken;
  static jlongArray jjtoSkip;
public:  // actually protected
  ::org::apache::lucene::analysis::standard::CharStream *input_stream;
private:
  jintArray jjrounds;
  jintArray jjstateSet;
public:  // actually protected
  jchar curChar;
public: // actually package-private
  jint curLexState;
  jint defaultLexState;
  jint jjnewStateCnt;
  jint jjround;
  jint jjmatchedPos;
  jint jjmatchedKind;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_standard_StandardTokenizerTokenManager__ */
