// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermPositionVector__
#define __org_apache_lucene_index_TermPositionVector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermPositionVector;
          class TermVectorOffsetInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermPositionVector : public ::java::lang::Object
{
public:
  virtual jintArray getTermPositions (jint) = 0;
  virtual JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *getOffsets (jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_index_TermPositionVector__ */
