// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MultiTermQuery__
#define __org_apache_lucene_search_MultiTermQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class MultiTermQuery;
          class Query;
          class FilteredTermEnum;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::MultiTermQuery : public ::org::apache::lucene::search::Query
{
public:
  MultiTermQuery (::org::apache::lucene::index::Term *);
  virtual ::org::apache::lucene::index::Term *getTerm () { return term; }
public:  // actually protected
  virtual ::org::apache::lucene::search::FilteredTermEnum *getEnum (::org::apache::lucene::index::IndexReader *) = 0;
public:
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Query )))) term;

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MultiTermQuery__ */
