// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MatchAllDocsQuery$MatchAllScorer__
#define __org_apache_lucene_search_MatchAllDocsQuery$MatchAllScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class MatchAllDocsQuery$MatchAllScorer;
          class Explanation;
          class Weight;
          class Similarity;
          class MatchAllDocsQuery;
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::MatchAllDocsQuery$MatchAllScorer : public ::org::apache::lucene::search::Scorer
{
public: // actually package-private
  MatchAllDocsQuery$MatchAllScorer (::org::apache::lucene::search::MatchAllDocsQuery *, ::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::search::Similarity *, ::org::apache::lucene::search::Weight *);
public:
  virtual ::org::apache::lucene::search::Explanation *explain (jint) { return 0; }
  virtual jint doc () { return id; }
  virtual jboolean next ();
  virtual jfloat score () { return score__; }
  virtual jboolean skipTo (jint);
public: // actually package-private
  ::org::apache::lucene::index::IndexReader * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) reader;
  jint id;
  jint maxId;
  jfloat score__;
private:
  ::org::apache::lucene::search::MatchAllDocsQuery *this$0;

  friend class org_apache_lucene_search_MatchAllDocsQuery$MatchAllScorer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MatchAllDocsQuery$MatchAllScorer__ */
