// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_RemoteSearchable_Stub__
#define __org_apache_lucene_search_RemoteSearchable_Stub__

#pragma interface

#include <java/rmi/server/RemoteStub.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class RemoteSearchable_Stub;
          class HitCollector;
          class TopFieldDocs;
          class Sort;
          class TopDocs;
          class Filter;
          class Query;
          class Explanation;
          class Weight;
        }
        namespace index
        {
          class Term;
        }
        namespace document
        {
          class Document;
        }
      }
    }
  }
  namespace java
  {
    namespace rmi
    {
      namespace server
      {
        class RemoteRef;
      }
    }
  }
}

class org::apache::lucene::search::RemoteSearchable_Stub : public ::java::rmi::server::RemoteStub
{
public:
  RemoteSearchable_Stub (::java::rmi::server::RemoteRef *);
  void close ();
  ::org::apache::lucene::document::Document *doc (jint);
  jint docFreq (::org::apache::lucene::index::Term *);
  jintArray docFreqs (JArray< ::org::apache::lucene::index::Term *> *);
  ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::search::Weight *, jint);
  jint maxDoc ();
  ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::search::Query *);
  ::org::apache::lucene::search::TopDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint);
  ::org::apache::lucene::search::TopFieldDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::Sort *);
  void search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::HitCollector *);
private:
  static const jlong serialVersionUID = 2LL;
  static ::java::lang::reflect::Method *$method_close_0;
  static ::java::lang::reflect::Method *$method_doc_1;
  static ::java::lang::reflect::Method *$method_docFreq_2;
  static ::java::lang::reflect::Method *$method_docFreqs_3;
  static ::java::lang::reflect::Method *$method_explain_4;
  static ::java::lang::reflect::Method *$method_maxDoc_5;
  static ::java::lang::reflect::Method *$method_rewrite_6;
  static ::java::lang::reflect::Method *$method_search_7;
  static ::java::lang::reflect::Method *$method_search_8;
  static ::java::lang::reflect::Method *$method_search_9;
public: // actually package-private
  static ::java::lang::Class *class$org$apache$lucene$search$Searchable;
  static ::java::lang::Class *class$org$apache$lucene$index$Term;
  static ::java::lang::Class *array$Lorg$apache$lucene$index$Term;
  static ::java::lang::Class *class$org$apache$lucene$search$Weight;
  static ::java::lang::Class *class$org$apache$lucene$search$Query;
  static ::java::lang::Class *class$org$apache$lucene$search$Filter;
  static ::java::lang::Class *class$org$apache$lucene$search$Sort;
  static ::java::lang::Class *class$org$apache$lucene$search$HitCollector;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_RemoteSearchable_Stub__ */
