// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ComplexExplanation__
#define __org_apache_lucene_search_ComplexExplanation__

#pragma interface

#include <org/apache/lucene/search/Explanation.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ComplexExplanation;
        }
      }
    }
  }
}

class org::apache::lucene::search::ComplexExplanation : public ::org::apache::lucene::search::Explanation
{
public:
  ComplexExplanation ();
  ComplexExplanation (jboolean, jfloat, ::java::lang::String *);
  virtual ::java::lang::Boolean *getMatch () { return match; }
  virtual void setMatch (::java::lang::Boolean *);
  virtual jboolean isMatch ();
public:  // actually protected
  virtual ::java::lang::String *getSummary ();
private:
  ::java::lang::Boolean * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Explanation )))) match;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ComplexExplanation__ */
