// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_IndexReader$FieldOption__
#define __org_apache_lucene_index_IndexReader$FieldOption__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader$FieldOption;
        }
      }
    }
  }
}

class org::apache::lucene::index::IndexReader$FieldOption : public ::java::lang::Object
{
private:
  IndexReader$FieldOption ();
  IndexReader$FieldOption (::java::lang::String *);
public:
  ::java::lang::String *toString () { return option; }
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) option;
public:
  static ::org::apache::lucene::index::IndexReader$FieldOption *ALL;
  static ::org::apache::lucene::index::IndexReader$FieldOption *INDEXED;
  static ::org::apache::lucene::index::IndexReader$FieldOption *UNINDEXED;
  static ::org::apache::lucene::index::IndexReader$FieldOption *INDEXED_WITH_TERMVECTOR;
  static ::org::apache::lucene::index::IndexReader$FieldOption *INDEXED_NO_TERMVECTOR;
  static ::org::apache::lucene::index::IndexReader$FieldOption *TERMVECTOR;
  static ::org::apache::lucene::index::IndexReader$FieldOption *TERMVECTOR_WITH_POSITION;
  static ::org::apache::lucene::index::IndexReader$FieldOption *TERMVECTOR_WITH_OFFSET;
  static ::org::apache::lucene::index::IndexReader$FieldOption *TERMVECTOR_WITH_POSITION_OFFSET;

  friend class org_apache_lucene_index_IndexReader$FieldOption;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_IndexReader$FieldOption__ */
