// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __net_sf_snowball_SnowballProgram__
#define __net_sf_snowball_SnowballProgram__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        class Among;
        class SnowballProgram;
      }
    }
  }
}

class net::sf::snowball::SnowballProgram : public ::java::lang::Object
{
public:  // actually protected
  SnowballProgram ();
public:
  virtual void setCurrent (::java::lang::String *);
  virtual ::java::lang::String *getCurrent ();
public:  // actually protected
  virtual void copy_from (::net::sf::snowball::SnowballProgram *);
  virtual jboolean in_grouping (jcharArray, jint, jint);
  virtual jboolean in_grouping_b (jcharArray, jint, jint);
  virtual jboolean out_grouping (jcharArray, jint, jint);
  virtual jboolean out_grouping_b (jcharArray, jint, jint);
  virtual jboolean in_range (jint, jint);
  virtual jboolean in_range_b (jint, jint);
  virtual jboolean out_range (jint, jint);
  virtual jboolean out_range_b (jint, jint);
  virtual jboolean eq_s (jint, ::java::lang::String *);
  virtual jboolean eq_s_b (jint, ::java::lang::String *);
  virtual jboolean eq_v (::java::lang::StringBuffer *);
  virtual jboolean eq_v_b (::java::lang::StringBuffer *);
  virtual jint find_among (JArray< ::net::sf::snowball::Among *> *, jint);
  virtual jint find_among_b (JArray< ::net::sf::snowball::Among *> *, jint);
  virtual jint replace_s (jint, jint, ::java::lang::String *);
  virtual void slice_check ();
  virtual void slice_from (::java::lang::String *);
  virtual void slice_from (::java::lang::StringBuffer *);
  virtual void slice_del ();
  virtual void insert (jint, jint, ::java::lang::String *);
  virtual void insert (jint, jint, ::java::lang::StringBuffer *);
  virtual ::java::lang::StringBuffer *slice_to (::java::lang::StringBuffer *);
  virtual ::java::lang::StringBuffer *assign_to (::java::lang::StringBuffer *);
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) current;
  jint cursor;
  jint limit;
  jint limit_backward;
  jint bra;
  jint ket;
public:

  static ::java::lang::Class class$;
};

#endif /* __net_sf_snowball_SnowballProgram__ */
