// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_StringHelper__
#define __org_apache_lucene_util_StringHelper__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class StringHelper;
        }
      }
    }
  }
}

class org::apache::lucene::util::StringHelper : public ::java::lang::Object
{
public:
  static jint stringDifference (::java::lang::String *, ::java::lang::String *);
private:
  StringHelper ();
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_StringHelper__ */
