// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_FSIndexInput$Descriptor__
#define __org_apache_lucene_store_FSIndexInput$Descriptor__

#pragma interface

#include <java/io/RandomAccessFile.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class FSIndexInput$Descriptor;
          class FSIndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::store::FSIndexInput$Descriptor : public ::java::io::RandomAccessFile
{
public:
  FSIndexInput$Descriptor (::org::apache::lucene::store::FSIndexInput *, ::java::io::File *, ::java::lang::String *);
  jlong __attribute__((aligned(__alignof__( ::java::io::RandomAccessFile ))))  position;
private:
  ::org::apache::lucene::store::FSIndexInput *this$0;

  friend class org_apache_lucene_store_FSIndexInput$Descriptor;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_FSIndexInput$Descriptor__ */
