// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ConjunctionScorer__
#define __org_apache_lucene_search_ConjunctionScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ConjunctionScorer;
          class Explanation;
          class Similarity;
          class Scorer;
        }
      }
    }
  }
}

class org::apache::lucene::search::ConjunctionScorer : public ::org::apache::lucene::search::Scorer
{
public:
  ConjunctionScorer (::org::apache::lucene::search::Similarity *);
public: // actually package-private
  void add (::org::apache::lucene::search::Scorer *);
public:
  virtual jint doc ();
  virtual jboolean next ();
private:
  jboolean doNext ();
public:
  virtual jboolean skipTo (jint);
  virtual jfloat score ();
private:
  void init (jboolean);
  void sortScorers ();
public:
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  JArray< ::org::apache::lucene::search::Scorer *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) scorers;
  jint length;
  jint first;
  jint last;
  jboolean firstTime;
  jboolean more;
  jfloat coord;

  friend class org_apache_lucene_search_ConjunctionScorer$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ConjunctionScorer__ */
