// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_Posting__
#define __org_apache_lucene_index_Posting__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Posting;
          class TermVectorOffsetInfo;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::index::Posting : public ::java::lang::Object
{
public: // actually package-private
  Posting (::org::apache::lucene::index::Term *, jint, ::org::apache::lucene::index::TermVectorOffsetInfo *);
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::java::lang::Object )))) term;
  jint freq;
  jintArray positions;
  JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *offsets;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_Posting__ */
