// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_nl_DutchStemmer__
#define __org_apache_lucene_analysis_nl_DutchStemmer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace nl
          {
            class DutchStemmer;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::nl::DutchStemmer : public ::java::lang::Object
{
public:
  DutchStemmer ();
  virtual ::java::lang::String *stem (::java::lang::String *);
private:
  jboolean enEnding (::java::lang::StringBuffer *);
  void step1 (::java::lang::StringBuffer *);
  void step2 (::java::lang::StringBuffer *);
  void step3a (::java::lang::StringBuffer *);
  void step3b (::java::lang::StringBuffer *);
  void step4 (::java::lang::StringBuffer *);
  jboolean isStemmable (::java::lang::String *);
  void substitute (::java::lang::StringBuffer *);
  jboolean isValidSEnding (::java::lang::StringBuffer *, jint);
  jboolean isValidEnEnding (::java::lang::StringBuffer *, jint);
  void unDouble (::java::lang::StringBuffer *);
  void unDouble (::java::lang::StringBuffer *, jint);
  jint getRIndex (::java::lang::StringBuffer *, jint);
  void storeYandI (::java::lang::StringBuffer *);
  void reStoreYandI (::java::lang::StringBuffer *);
  jboolean isVowel (jchar);
public: // actually package-private
  virtual void setStemDictionary (::java::util::Map *);
private:
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sb;
  jboolean _removedE;
  ::java::util::Map *_stemDict;
  jint _R1;
  jint _R2;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_nl_DutchStemmer__ */
