// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_NearSpansUnordered$SpansCell__
#define __org_apache_lucene_search_spans_NearSpansUnordered$SpansCell__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace spans
          {
            class NearSpansUnordered;
            class NearSpansUnordered$SpansCell;
            class Spans;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::NearSpansUnordered$SpansCell : public ::java::lang::Object
{
public:
  NearSpansUnordered$SpansCell (::org::apache::lucene::search::spans::NearSpansUnordered *, ::org::apache::lucene::search::spans::Spans *, jint);
  virtual jboolean next ();
  virtual jboolean skipTo (jint);
private:
  jboolean adjust (jboolean);
public:
  virtual jint doc ();
  virtual jint start ();
  virtual jint end ();
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::search::spans::Spans * __attribute__((aligned(__alignof__( ::java::lang::Object )))) spans;
  ::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *next__;
  jint length;
  jint index;
  ::org::apache::lucene::search::spans::NearSpansUnordered *this$0;

  friend class org_apache_lucene_search_spans_NearSpansUnordered$SpansCell;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_NearSpansUnordered$SpansCell__ */
