// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Explanation__
#define __org_apache_lucene_search_Explanation__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Explanation;
        }
      }
    }
  }
}

class org::apache::lucene::search::Explanation : public ::java::lang::Object
{
public:
  Explanation ();
  Explanation (jfloat, ::java::lang::String *);
  virtual jboolean isMatch ();
  virtual jfloat getValue () { return value; }
  virtual void setValue (jfloat);
  virtual ::java::lang::String *getDescription () { return description; }
  virtual void setDescription (::java::lang::String *);
public:  // actually protected
  virtual ::java::lang::String *getSummary ();
public:
  virtual JArray< ::org::apache::lucene::search::Explanation *> *getDetails ();
  virtual void addDetail (::org::apache::lucene::search::Explanation *);
  virtual ::java::lang::String *toString ();
public:  // actually protected
  virtual ::java::lang::String *toString (jint);
public:
  virtual ::java::lang::String *toHtml ();
private:
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  value;
  ::java::lang::String *description;
  ::java::util::ArrayList *details;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Explanation__ */
