// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ScoreDocComparator__
#define __org_apache_lucene_search_ScoreDocComparator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ScoreDoc;
          class ScoreDocComparator;
        }
      }
    }
  }
}

class org::apache::lucene::search::ScoreDocComparator : public ::java::lang::Object
{
public:
  virtual jint compare (::org::apache::lucene::search::ScoreDoc *, ::org::apache::lucene::search::ScoreDoc *) = 0;
  virtual ::java::lang::Comparable *sortValue (::org::apache::lucene::search::ScoreDoc *) = 0;
  virtual jint sortType () = 0;
  static ::org::apache::lucene::search::ScoreDocComparator *RELEVANCE;
  static ::org::apache::lucene::search::ScoreDocComparator *INDEXORDER;

  friend class org_apache_lucene_search_ScoreDocComparator$1;
  friend class org_apache_lucene_search_ScoreDocComparator$2;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_search_ScoreDocComparator__ */
