// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FilterIndexReader__
#define __org_apache_lucene_index_FilterIndexReader__

#pragma interface

#include <org/apache/lucene/index/IndexReader.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Document;
          class FieldSelector;
        }
        namespace index
        {
          class FilterIndexReader;
          class IndexReader$FieldOption;
          class TermPositions;
          class TermDocs;
          class Term;
          class TermEnum;
          class TermFreqVector;
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::index::FilterIndexReader : public ::org::apache::lucene::index::IndexReader
{
public:
  FilterIndexReader (::org::apache::lucene::index::IndexReader *);
  virtual JArray< ::org::apache::lucene::index::TermFreqVector *> *getTermFreqVectors (jint);
  virtual ::org::apache::lucene::index::TermFreqVector *getTermFreqVector (jint, ::java::lang::String *);
  virtual jint numDocs ();
  virtual jint maxDoc ();
  virtual ::org::apache::lucene::document::Document *document (jint, ::org::apache::lucene::document::FieldSelector *);
  virtual jboolean isDeleted (jint);
  virtual jboolean hasDeletions ();
public:  // actually protected
  virtual void doUndeleteAll ();
public:
  virtual jboolean hasNorms (::java::lang::String *);
  virtual jbyteArray norms (::java::lang::String *);
  virtual void norms (::java::lang::String *, jbyteArray, jint);
public:  // actually protected
  virtual void doSetNorm (jint, ::java::lang::String *, jbyte);
public:
  virtual ::org::apache::lucene::index::TermEnum *terms ();
  virtual ::org::apache::lucene::index::TermEnum *terms (::org::apache::lucene::index::Term *);
  virtual jint docFreq (::org::apache::lucene::index::Term *);
  virtual ::org::apache::lucene::index::TermDocs *termDocs ();
  virtual ::org::apache::lucene::index::TermPositions *termPositions ();
public:  // actually protected
  virtual void doDelete (jint);
  virtual void doCommit ();
  virtual void doClose ();
public:
  virtual ::java::util::Collection *getFieldNames (::org::apache::lucene::index::IndexReader$FieldOption *);
  virtual jlong getVersion ();
  virtual jboolean isCurrent ();
public:  // actually protected
  ::org::apache::lucene::index::IndexReader * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::IndexReader )))) in;

  friend class org_apache_lucene_index_FilterIndexReader$FilterTermEnum;
  friend class org_apache_lucene_index_FilterIndexReader$FilterTermPositions;
  friend class org_apache_lucene_index_FilterIndexReader$FilterTermDocs;
  friend class org_apache_lucene_index_IndexReader$FieldOption;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FilterIndexReader__ */
