// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __net_sf_snowball_Among__
#define __net_sf_snowball_Among__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        class Among;
        class SnowballProgram;
      }
    }
  }
}

class net::sf::snowball::Among : public ::java::lang::Object
{
public:
  Among (::java::lang::String *, jint, jint, ::java::lang::String *, ::net::sf::snowball::SnowballProgram *);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  s_size;
  ::java::lang::String *s;
  jint substring_i;
  jint result;
  ::java::lang::reflect::Method *method;
  ::net::sf::snowball::SnowballProgram *methodobject;

  static ::java::lang::Class class$;
};

#endif /* __net_sf_snowball_Among__ */
