// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldCacheImpl$Entry__
#define __org_apache_lucene_search_FieldCacheImpl$Entry__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldCacheImpl$Entry;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldCacheImpl$Entry : public ::java::lang::Object
{
public: // actually package-private
  FieldCacheImpl$Entry (::java::lang::String *, jint, ::java::util::Locale *);
  FieldCacheImpl$Entry (::java::lang::String *, ::java::lang::Object *);
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) field;
  jint type;
  ::java::lang::Object *custom;
  ::java::util::Locale *locale;

  friend class org_apache_lucene_search_FieldCacheImpl$Entry;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldCacheImpl$Entry__ */
