// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_MultiFieldQueryParser__
#define __org_apache_lucene_queryParser_MultiFieldQueryParser__

#pragma interface

#include <org/apache/lucene/queryParser/QueryParser.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class MultiFieldQueryParser;
        }
        namespace search
        {
          class BooleanClause$Occur;
          class Query;
        }
        namespace analysis
        {
          class Analyzer;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::MultiFieldQueryParser : public ::org::apache::lucene::queryParser::QueryParser
{
public:
  MultiFieldQueryParser (JArray< ::java::lang::String *> *, ::org::apache::lucene::analysis::Analyzer *, ::java::util::Map *);
  MultiFieldQueryParser (JArray< ::java::lang::String *> *, ::org::apache::lucene::analysis::Analyzer *);
public:  // actually protected
  virtual ::org::apache::lucene::search::Query *getFieldQuery (::java::lang::String *, ::java::lang::String *, jint);
  virtual ::org::apache::lucene::search::Query *getFieldQuery (::java::lang::String *, ::java::lang::String *);
  virtual ::org::apache::lucene::search::Query *getFuzzyQuery (::java::lang::String *, ::java::lang::String *, jfloat);
  virtual ::org::apache::lucene::search::Query *getPrefixQuery (::java::lang::String *, ::java::lang::String *);
  virtual ::org::apache::lucene::search::Query *getWildcardQuery (::java::lang::String *, ::java::lang::String *);
  virtual ::org::apache::lucene::search::Query *getRangeQuery (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, jboolean);
public:
  static ::org::apache::lucene::search::Query *parse (JArray< ::java::lang::String *> *, JArray< ::java::lang::String *> *, ::org::apache::lucene::analysis::Analyzer *);
  static ::org::apache::lucene::search::Query *parse (::java::lang::String *, JArray< ::java::lang::String *> *, JArray< ::org::apache::lucene::search::BooleanClause$Occur *> *, ::org::apache::lucene::analysis::Analyzer *);
  static ::org::apache::lucene::search::Query *parse (JArray< ::java::lang::String *> *, JArray< ::java::lang::String *> *, JArray< ::org::apache::lucene::search::BooleanClause$Occur *> *, ::org::apache::lucene::analysis::Analyzer *);
private:
  JArray< ::java::lang::String *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::queryParser::QueryParser )))) fields;
  ::java::util::Map *boosts;

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_MultiFieldQueryParser__ */
