// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentInfo__
#define __org_apache_lucene_index_SegmentInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentInfo;
        }
        namespace store
        {
          class IndexOutput;
          class IndexInput;
          class Directory;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentInfo : public ::java::lang::Object
{
public:
  SegmentInfo (::java::lang::String *, jint, ::org::apache::lucene::store::Directory *);
  SegmentInfo (::java::lang::String *, jint, ::org::apache::lucene::store::Directory *, jboolean);
  SegmentInfo (::org::apache::lucene::store::Directory *, jint, ::org::apache::lucene::store::IndexInput *);
public: // actually package-private
  void setNumField (jint);
  jboolean hasDeletions ();
  void advanceDelGen ();
  void clearDelGen ();
  ::java::lang::String *getDelFileName ();
  jboolean hasSeparateNorms (jint);
  jboolean hasSeparateNorms ();
  void advanceNormGen (jint);
  ::java::lang::String *getNormFileName (jint);
  void setUseCompoundFile (jboolean);
  jboolean getUseCompoundFile ();
  void write (::org::apache::lucene::store::IndexOutput *);
public:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  jint docCount;
  ::org::apache::lucene::store::Directory *dir;
private:
  jboolean preLockless;
  jlong delGen;
  jlongArray normGen;
  jbyte isCompoundFile;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentInfo__ */
