// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_Field__
#define __org_apache_lucene_document_Field__

#pragma interface

#include <org/apache/lucene/document/AbstractField.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Field;
          class Field$TermVector;
          class Field$Index;
          class Field$Store;
        }
      }
    }
  }
}

class org::apache::lucene::document::Field : public ::org::apache::lucene::document::AbstractField
{
public:
  ::java::lang::String *stringValue ();
  ::java::io::Reader *readerValue ();
  jbyteArray binaryValue ();
  Field (::java::lang::String *, ::java::lang::String *, ::org::apache::lucene::document::Field$Store *, ::org::apache::lucene::document::Field$Index *);
  Field (::java::lang::String *, ::java::lang::String *, ::org::apache::lucene::document::Field$Store *, ::org::apache::lucene::document::Field$Index *, ::org::apache::lucene::document::Field$TermVector *);
  Field (::java::lang::String *, ::java::io::Reader *);
  Field (::java::lang::String *, ::java::io::Reader *, ::org::apache::lucene::document::Field$TermVector *);
  Field (::java::lang::String *, jbyteArray, ::org::apache::lucene::document::Field$Store *);

  friend class org_apache_lucene_document_Field$TermVector;
  friend class org_apache_lucene_document_Field$Index;
  friend class org_apache_lucene_document_Field$Store;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_Field__ */
