// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_FSIndexInput__
#define __org_apache_lucene_store_FSIndexInput__

#pragma interface

#include <org/apache/lucene/store/BufferedIndexInput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class FSIndexInput;
          class FSIndexInput$Descriptor;
        }
      }
    }
  }
}

class org::apache::lucene::store::FSIndexInput : public ::org::apache::lucene::store::BufferedIndexInput
{
public:
  FSIndexInput (::java::io::File *);
public:  // actually protected
  virtual void readInternal (jbyteArray, jint, jint);
public:
  virtual void close ();
public:  // actually protected
  virtual void seekInternal (jlong) { }
public:
  virtual jlong length () { return length__; }
public:  // actually protected
  virtual void finalize ();
public:
  virtual ::java::lang::Object *clone ();
public: // actually package-private
  virtual jboolean isFDValid ();
private:
  ::org::apache::lucene::store::FSIndexInput$Descriptor * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::BufferedIndexInput )))) file;
public: // actually package-private
  jboolean isClone;
private:
  jlong length__;

  friend class org_apache_lucene_store_FSIndexInput$Descriptor;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_FSIndexInput__ */
