// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FuzzyQuery$ScoreTerm__
#define __org_apache_lucene_search_FuzzyQuery$ScoreTerm__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FuzzyQuery$ScoreTerm;
        }
        namespace index
        {
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::FuzzyQuery$ScoreTerm : public ::java::lang::Object
{
public:
  FuzzyQuery$ScoreTerm (::org::apache::lucene::index::Term *, jfloat);
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::java::lang::Object )))) term;
  jfloat score;

  friend class org_apache_lucene_search_FuzzyQuery$ScoreTerm;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FuzzyQuery$ScoreTerm__ */
