// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_SpanGradientFormatter__
#define __org_apache_lucene_search_highlight_SpanGradientFormatter__

#pragma interface

#include <org/apache/lucene/search/highlight/GradientFormatter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class SpanGradientFormatter;
            class TokenGroup;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::SpanGradientFormatter : public ::org::apache::lucene::search::highlight::GradientFormatter
{
public:
  SpanGradientFormatter (jfloat, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *highlightTerm (::java::lang::String *, ::org::apache::lucene::search::highlight::TokenGroup *);
private:
  static ::java::lang::String *TEMPLATE;
  static jint EXTRA;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_SpanGradientFormatter__ */
