// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_SetBasedFieldSelector__
#define __org_apache_lucene_document_SetBasedFieldSelector__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class SetBasedFieldSelector;
          class FieldSelectorResult;
        }
      }
    }
  }
}

class org::apache::lucene::document::SetBasedFieldSelector : public ::java::lang::Object
{
public:
  SetBasedFieldSelector (::java::util::Set *, ::java::util::Set *);
  virtual ::org::apache::lucene::document::FieldSelectorResult *accept (::java::lang::String *);
private:
  ::java::util::Set * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fieldsToLoad;
  ::java::util::Set *lazyFieldsToLoad;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_SetBasedFieldSelector__ */
