// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_LucenePackage__
#define __org_apache_lucene_LucenePackage__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        class LucenePackage;
      }
    }
  }
}

class org::apache::lucene::LucenePackage : public ::java::lang::Object
{
private:
  LucenePackage ();
public:
  static ::java::lang::Package *get ();
public: // actually package-private
  static ::java::lang::Class *class$org$apache$lucene$LucenePackage;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_LucenePackage__ */
