// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_similar_MoreLikeThisQuery__
#define __org_apache_lucene_search_similar_MoreLikeThisQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace similar
          {
            class MoreLikeThisQuery;
          }
          class Query;
        }
        namespace index
        {
          class IndexReader;
        }
        namespace analysis
        {
          class Analyzer;
        }
      }
    }
  }
}

class org::apache::lucene::search::similar::MoreLikeThisQuery : public ::org::apache::lucene::search::Query
{
public:
  MoreLikeThisQuery (::java::lang::String *, JArray< ::java::lang::String *> *, ::org::apache::lucene::analysis::Analyzer *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jfloat getPercentTermsToMatch () { return percentTermsToMatch; }
  virtual void setPercentTermsToMatch (jfloat);
  virtual ::org::apache::lucene::analysis::Analyzer *getAnalyzer () { return analyzer; }
  virtual void setAnalyzer (::org::apache::lucene::analysis::Analyzer *);
  virtual ::java::lang::String *getLikeText () { return likeText; }
  virtual void setLikeText (::java::lang::String *);
  virtual jint getMaxQueryTerms () { return maxQueryTerms; }
  virtual void setMaxQueryTerms (jint);
  virtual jint getMinTermFrequency () { return minTermFrequency; }
  virtual void setMinTermFrequency (jint);
  virtual JArray< ::java::lang::String *> *getMoreLikeFields () { return moreLikeFields; }
  virtual void setMoreLikeFields (JArray< ::java::lang::String *> *);
  virtual ::java::util::Set *getStopWords () { return stopWords; }
  virtual void setStopWords (::java::util::Set *);
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Query )))) likeText;
  JArray< ::java::lang::String *> *moreLikeFields;
  ::org::apache::lucene::analysis::Analyzer *analyzer;
public: // actually package-private
  jfloat percentTermsToMatch;
  jint minTermFrequency;
  jint maxQueryTerms;
  ::java::util::Set *stopWords;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_similar_MoreLikeThisQuery__ */
