// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_DefaultSimilarity__
#define __org_apache_lucene_search_DefaultSimilarity__

#pragma interface

#include <org/apache/lucene/search/Similarity.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class DefaultSimilarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::DefaultSimilarity : public ::org::apache::lucene::search::Similarity
{
public:
  DefaultSimilarity ();
  virtual jfloat lengthNorm (::java::lang::String *, jint);
  virtual jfloat queryNorm (jfloat);
  virtual jfloat tf (jfloat);
  virtual jfloat sloppyFreq (jint);
  virtual jfloat idf (jint, jint);
  virtual jfloat coord (jint, jint);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_DefaultSimilarity__ */
