// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanQuery$BooleanWeight2__
#define __org_apache_lucene_search_BooleanQuery$BooleanWeight2__

#pragma interface

#include <org/apache/lucene/search/BooleanQuery$BooleanWeight.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class BooleanQuery$BooleanWeight2;
          class Scorer;
          class Searcher;
          class BooleanQuery;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanQuery$BooleanWeight2 : public ::org::apache::lucene::search::BooleanQuery$BooleanWeight
{
public:
  BooleanQuery$BooleanWeight2 (::org::apache::lucene::search::BooleanQuery *, ::org::apache::lucene::search::Searcher *);
  virtual ::org::apache::lucene::search::Scorer *scorer (::org::apache::lucene::index::IndexReader *);
private:
  ::org::apache::lucene::search::BooleanQuery * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::BooleanQuery$BooleanWeight )))) this$0;

  friend class org_apache_lucene_search_BooleanQuery$BooleanWeight2;
  friend class org_apache_lucene_search_BooleanQuery$BooleanWeight;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanQuery$BooleanWeight2__ */
