// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery__
#define __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery__

#pragma interface

#include <org/apache/lucene/search/TermQuery.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FuzzyLikeThisQuery$FuzzyTermQuery;
          class Similarity;
          class Searcher;
        }
        namespace index
        {
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::FuzzyLikeThisQuery$FuzzyTermQuery : public ::org::apache::lucene::search::TermQuery
{
public:
  FuzzyLikeThisQuery$FuzzyTermQuery (::org::apache::lucene::index::Term *, jboolean);
  virtual ::org::apache::lucene::search::Similarity *getSimilarity (::org::apache::lucene::search::Searcher *);
public: // actually package-private
  jboolean __attribute__((aligned(__alignof__( ::org::apache::lucene::search::TermQuery ))))  ignoreTF;

  friend class org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery;
  friend class org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery__ */
