// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_Formatter__
#define __org_apache_lucene_search_highlight_Formatter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class Formatter;
            class TokenGroup;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::Formatter : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *highlightTerm (::java::lang::String *, ::org::apache::lucene::search::highlight::TokenGroup *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_search_highlight_Formatter__ */
