// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MultiSearcherThread__
#define __org_apache_lucene_search_MultiSearcherThread__

#pragma interface

#include <java/lang/Thread.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class PriorityQueue;
        }
        namespace search
        {
          class MultiSearcherThread;
          class FieldDocSortedHitQueue;
          class HitQueue;
          class Sort;
          class TopDocs;
          class Filter;
          class Weight;
          class Searchable;
        }
      }
    }
  }
}

class org::apache::lucene::search::MultiSearcherThread : public ::java::lang::Thread
{
public:
  MultiSearcherThread (::org::apache::lucene::search::Searchable *, ::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::HitQueue *, jint, jintArray, ::java::lang::String *);
  MultiSearcherThread (::org::apache::lucene::search::Searchable *, ::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::FieldDocSortedHitQueue *, ::org::apache::lucene::search::Sort *, jint, jintArray, ::java::lang::String *);
  virtual void run ();
  virtual jint hits ();
  virtual jfloat getMaxScore ();
  virtual ::java::io::IOException *getIOException () { return ioe; }
private:
  ::org::apache::lucene::search::Searchable * __attribute__((aligned(__alignof__( ::java::lang::Thread )))) searchable;
  ::org::apache::lucene::search::Weight *weight;
  ::org::apache::lucene::search::Filter *filter;
  jint nDocs;
  ::org::apache::lucene::search::TopDocs *docs;
  jint i;
  ::org::apache::lucene::util::PriorityQueue *hq;
  jintArray starts;
  ::java::io::IOException *ioe;
  ::org::apache::lucene::search::Sort *sort;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MultiSearcherThread__ */
