// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_MMapDirectory$1__
#define __org_apache_lucene_store_MMapDirectory$1__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class MMapDirectory$1;
        }
      }
    }
  }
}

class org::apache::lucene::store::MMapDirectory$1 : public ::java::lang::Object
{

  friend class org_apache_lucene_store_MMapDirectory$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_MMapDirectory$1__ */
