// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermBuffer__
#define __org_apache_lucene_index_TermBuffer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class IndexInput;
        }
        namespace index
        {
          class FieldInfos;
          class TermBuffer;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermBuffer : public ::java::lang::Object
{
public: // actually package-private
  TermBuffer ();
public:
  jint compareTo (::org::apache::lucene::index::TermBuffer *);
private:
  static jint compareChars (jcharArray, jint, jcharArray, jint);
  void setTextLength (jint);
public:
  void read (::org::apache::lucene::store::IndexInput *, ::org::apache::lucene::index::FieldInfos *);
  void set (::org::apache::lucene::index::Term *);
  void set (::org::apache::lucene::index::TermBuffer *);
  void reset ();
  ::org::apache::lucene::index::Term *toTerm ();
public:  // actually protected
  ::java::lang::Object *clone ();
private:
  static jcharArray NO_CHARS;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) field;
  jcharArray text;
  jint textLength;
  ::org::apache::lucene::index::Term *term;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermBuffer__ */
