// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ScoreDocComparator$1__
#define __org_apache_lucene_search_ScoreDocComparator$1__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ScoreDocComparator$1;
          class ScoreDoc;
        }
      }
    }
  }
}

class org::apache::lucene::search::ScoreDocComparator$1 : public ::java::lang::Object
{
public: // actually package-private
  ScoreDocComparator$1 ();
public:
  virtual jint compare (::org::apache::lucene::search::ScoreDoc *, ::org::apache::lucene::search::ScoreDoc *);
  virtual ::java::lang::Comparable *sortValue (::org::apache::lucene::search::ScoreDoc *);
  virtual jint sortType ();

  friend class org_apache_lucene_search_ScoreDocComparator$1;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ScoreDocComparator$1__ */
