// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_SimpleFragmenter__
#define __org_apache_lucene_search_highlight_SimpleFragmenter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class SimpleFragmenter;
          }
        }
        namespace analysis
        {
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::SimpleFragmenter : public ::java::lang::Object
{
public:
  SimpleFragmenter ();
  SimpleFragmenter (jint);
  virtual void start (::java::lang::String *);
  virtual jboolean isNewFragment (::org::apache::lucene::analysis::Token *);
  virtual jint getFragmentSize () { return fragmentSize; }
  virtual void setFragmentSize (jint);
private:
  static const jint DEFAULT_FRAGMENT_SIZE = 100L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  currentNumFrags;
  jint fragmentSize;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_SimpleFragmenter__ */
