// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldDocSortedHitQueue__
#define __org_apache_lucene_search_FieldDocSortedHitQueue__

#pragma interface

#include <org/apache/lucene/util/PriorityQueue.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace text
    {
      class Collator;
    }
  }
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldDocSortedHitQueue;
          class SortField;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldDocSortedHitQueue : public ::org::apache::lucene::util::PriorityQueue
{
public: // actually package-private
  FieldDocSortedHitQueue (JArray< ::org::apache::lucene::search::SortField *> *, jint);
  virtual void setFields (JArray< ::org::apache::lucene::search::SortField *> *);
  virtual JArray< ::org::apache::lucene::search::SortField *> *getFields () { return fields; }
private:
  JArray< ::java::text::Collator *> *hasCollators (JArray< ::org::apache::lucene::search::SortField *> *);
public:  // actually protected
  jboolean lessThan (::java::lang::Object *, ::java::lang::Object *);
public: // actually package-private
  JArray< ::org::apache::lucene::search::SortField *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::util::PriorityQueue )))) fields;
  JArray< ::java::text::Collator *> *collators;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldDocSortedHitQueue__ */
