// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_SortComparator__
#define __org_apache_lucene_search_SortComparator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class SortComparator;
          class ScoreDocComparator;
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::SortComparator : public ::java::lang::Object
{
public:
  SortComparator ();
  virtual ::org::apache::lucene::search::ScoreDocComparator *newComparator (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
public:  // actually protected
  virtual ::java::lang::Comparable *getComparable (::java::lang::String *) = 0;

  friend class org_apache_lucene_search_SortComparator$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_SortComparator__ */
