// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_Lock__
#define __org_apache_lucene_store_Lock__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class Lock;
        }
      }
    }
  }
}

class org::apache::lucene::store::Lock : public ::java::lang::Object
{
public:
  Lock ();
  virtual jboolean obtain () = 0;
  virtual jboolean obtain (jlong);
  virtual void release () = 0;
  virtual jboolean isLocked () = 0;
  static jlong LOCK_POLL_INTERVAL;
public:  // actually protected
  ::java::lang::Throwable * __attribute__((aligned(__alignof__( ::java::lang::Object )))) failureReason;

  friend class org_apache_lucene_store_Lock$With;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_Lock__ */
