// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentMergeInfo__
#define __org_apache_lucene_index_SegmentMergeInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentMergeInfo;
          class TermPositions;
          class IndexReader;
          class TermEnum;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentMergeInfo : public ::java::lang::Object
{
public: // actually package-private
  SegmentMergeInfo (jint, ::org::apache::lucene::index::TermEnum *, ::org::apache::lucene::index::IndexReader *);
  jintArray getDocMap ();
  ::org::apache::lucene::index::TermPositions *getPositions ();
  jboolean next ();
  void close ();
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::java::lang::Object )))) term;
  jint base;
  ::org::apache::lucene::index::TermEnum *termEnum;
  ::org::apache::lucene::index::IndexReader *reader;
private:
  ::org::apache::lucene::index::TermPositions *postings;
  jintArray docMap;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentMergeInfo__ */
