// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BoostingQuery$1__
#define __org_apache_lucene_search_BoostingQuery$1__

#pragma interface

#include <org/apache/lucene/search/BooleanQuery.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BoostingQuery$1;
          class Similarity;
          class Searcher;
          class BoostingQuery;
        }
      }
    }
  }
}

class org::apache::lucene::search::BoostingQuery$1 : public ::org::apache::lucene::search::BooleanQuery
{
public: // actually package-private
  BoostingQuery$1 (::org::apache::lucene::search::BoostingQuery *);
public:
  virtual ::org::apache::lucene::search::Similarity *getSimilarity (::org::apache::lucene::search::Searcher *);
private:
  ::org::apache::lucene::search::BoostingQuery * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::BooleanQuery )))) this$0;

  friend class org_apache_lucene_search_BoostingQuery$1;
  friend class org_apache_lucene_search_BoostingQuery$1$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BoostingQuery$1__ */
