// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_DisjunctionMaxScorer__
#define __org_apache_lucene_search_DisjunctionMaxScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class DisjunctionMaxScorer;
          class Explanation;
          class Scorer;
          class Similarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::DisjunctionMaxScorer : public ::org::apache::lucene::search::Scorer
{
public:
  DisjunctionMaxScorer (jfloat, ::org::apache::lucene::search::Similarity *);
  virtual void add (::org::apache::lucene::search::Scorer *);
  virtual jboolean next ();
  virtual jint doc ();
  virtual jfloat score ();
private:
  void scoreAll (jint, jint, jint, jfloatArray, jfloatArray);
public:
  virtual jboolean skipTo (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  void heapify ();
  void heapAdjust (jint);
  void heapRemoveRoot ();
  ::java::util::ArrayList * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) subScorers;
  jfloat tieBreakerMultiplier;
  jboolean more;
  jboolean firstTime;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_DisjunctionMaxScorer__ */
