// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FilterClause__
#define __org_apache_lucene_search_FilterClause__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FilterClause;
          class Filter;
          class BooleanClause$Occur;
        }
      }
    }
  }
}

class org::apache::lucene::search::FilterClause : public ::java::lang::Object
{
public:
  FilterClause (::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::BooleanClause$Occur *);
  virtual ::org::apache::lucene::search::Filter *getFilter () { return filter; }
  virtual ::org::apache::lucene::search::BooleanClause$Occur *getOccur () { return occur; }
public: // actually package-private
  ::org::apache::lucene::search::BooleanClause$Occur * __attribute__((aligned(__alignof__( ::java::lang::Object )))) occur;
  ::org::apache::lucene::search::Filter *filter;

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FilterClause__ */
