// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_Parameter__
#define __org_apache_lucene_util_Parameter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class Parameter;
        }
      }
    }
  }
}

class org::apache::lucene::util::Parameter : public ::java::lang::Object
{
private:
  Parameter ();
public:  // actually protected
  Parameter (::java::lang::String *);
private:
  ::java::lang::String *makeKey (::java::lang::String *);
public:
  virtual ::java::lang::String *toString () { return name; }
public:  // actually protected
  virtual ::java::lang::Object *readResolve ();
public: // actually package-private
  static ::java::util::Map *allParameters;
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_Parameter__ */
