// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ReqExclScorer__
#define __org_apache_lucene_search_ReqExclScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ReqExclScorer;
          class Explanation;
          class Scorer;
        }
      }
    }
  }
}

class org::apache::lucene::search::ReqExclScorer : public ::org::apache::lucene::search::Scorer
{
public:
  ReqExclScorer (::org::apache::lucene::search::Scorer *, ::org::apache::lucene::search::Scorer *);
  virtual jboolean next ();
private:
  jboolean toNonExcluded ();
public:
  virtual jint doc ();
  virtual jfloat score ();
  virtual jboolean skipTo (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  ::org::apache::lucene::search::Scorer * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) reqScorer;
  ::org::apache::lucene::search::Scorer *exclScorer;
  jboolean firstTime;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ReqExclScorer__ */
