// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Hits__
#define __org_apache_lucene_search_Hits__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Document;
        }
        namespace search
        {
          class Hits;
          class Query;
          class HitDoc;
          class Sort;
          class Filter;
          class Searcher;
          class Weight;
        }
      }
    }
  }
}

class org::apache::lucene::search::Hits : public ::java::lang::Object
{
public: // actually package-private
  Hits (::org::apache::lucene::search::Searcher *, ::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *);
  Hits (::org::apache::lucene::search::Searcher *, ::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::Sort *);
private:
  void getMoreDocs (jint);
public:
  jint length () { return length__; }
  ::org::apache::lucene::document::Document *doc (jint);
  jfloat score (jint);
  jint id (jint);
  ::java::util::Iterator *iterator ();
private:
  ::org::apache::lucene::search::HitDoc *hitDoc (jint);
  void addToFront (::org::apache::lucene::search::HitDoc *);
  void remove (::org::apache::lucene::search::HitDoc *);
  ::org::apache::lucene::search::Weight * __attribute__((aligned(__alignof__( ::java::lang::Object )))) weight;
  ::org::apache::lucene::search::Searcher *searcher;
  ::org::apache::lucene::search::Filter *filter;
  ::org::apache::lucene::search::Sort *sort;
  jint length__;
  ::java::util::Vector *hitDocs;
  ::org::apache::lucene::search::HitDoc *first;
  ::org::apache::lucene::search::HitDoc *last;
  jint numDocs;
  jint maxDocs;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Hits__ */
