// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentTermEnum__
#define __org_apache_lucene_index_SegmentTermEnum__

#pragma interface

#include <org/apache/lucene/index/TermEnum.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentTermEnum;
          class Term;
          class TermInfo;
          class TermBuffer;
          class FieldInfos;
        }
        namespace store
        {
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentTermEnum : public ::org::apache::lucene::index::TermEnum
{
public: // actually package-private
  SegmentTermEnum (::org::apache::lucene::store::IndexInput *, ::org::apache::lucene::index::FieldInfos *, jboolean);
public:  // actually protected
  ::java::lang::Object *clone ();
public: // actually package-private
  void seek (jlong, jint, ::org::apache::lucene::index::Term *, ::org::apache::lucene::index::TermInfo *);
public:
  jboolean next ();
public: // actually package-private
  void scanTo (::org::apache::lucene::index::Term *);
public:
  ::org::apache::lucene::index::Term *term ();
public: // actually package-private
  ::org::apache::lucene::index::Term *prev ();
  ::org::apache::lucene::index::TermInfo *termInfo ();
  void termInfo (::org::apache::lucene::index::TermInfo *);
public:
  jint docFreq ();
public: // actually package-private
  jlong freqPointer ();
  jlong proxPointer ();
public:
  void close ();
private:
  ::org::apache::lucene::store::IndexInput * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::TermEnum )))) input;
public: // actually package-private
  ::org::apache::lucene::index::FieldInfos *fieldInfos;
  jlong size;
  jlong position;
private:
  ::org::apache::lucene::index::TermBuffer *termBuffer;
  ::org::apache::lucene::index::TermBuffer *prevBuffer;
  ::org::apache::lucene::index::TermBuffer *scratch;
  ::org::apache::lucene::index::TermInfo *termInfo__;
  jint format;
  jboolean isIndex;
public: // actually package-private
  jlong indexPointer;
  jint indexInterval;
  jint skipInterval;
private:
  jint formatM1SkipInterval;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentTermEnum__ */
