// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_WhitespaceAnalyzer__
#define __org_apache_lucene_analysis_WhitespaceAnalyzer__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class WhitespaceAnalyzer;
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::WhitespaceAnalyzer : public ::org::apache::lucene::analysis::Analyzer
{
public:
  WhitespaceAnalyzer ();
  ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_WhitespaceAnalyzer__ */
