// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_ParseException__
#define __org_apache_lucene_queryParser_ParseException__

#pragma interface

#include <java/lang/Exception.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class ParseException;
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::ParseException : public ::java::lang::Exception
{
public:
  ParseException (::org::apache::lucene::queryParser::Token *, JArray<jintArray> *, JArray< ::java::lang::String *> *);
  ParseException ();
  ParseException (::java::lang::String *);
  virtual ::java::lang::String *getMessage ();
public:  // actually protected
  virtual ::java::lang::String *add_escapes (::java::lang::String *);
  jboolean __attribute__((aligned(__alignof__( ::java::lang::Exception ))))  specialConstructor;
public:
  ::org::apache::lucene::queryParser::Token *currentToken;
  JArray<jintArray> * expectedTokenSequences;
  JArray< ::java::lang::String *> *tokenImage;
public:  // actually protected
  ::java::lang::String *eol;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_ParseException__ */
