// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_Directory__
#define __org_apache_lucene_store_Directory__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class Directory;
          class Lock;
          class IndexInput;
          class IndexOutput;
          class LockFactory;
        }
      }
    }
  }
}

class org::apache::lucene::store::Directory : public ::java::lang::Object
{
public:
  Directory ();
  virtual JArray< ::java::lang::String *> *list () = 0;
  virtual jboolean fileExists (::java::lang::String *) = 0;
  virtual jlong fileModified (::java::lang::String *) = 0;
  virtual void touchFile (::java::lang::String *) = 0;
  virtual void deleteFile (::java::lang::String *) = 0;
  virtual void renameFile (::java::lang::String *, ::java::lang::String *) = 0;
  virtual jlong fileLength (::java::lang::String *) = 0;
  virtual ::org::apache::lucene::store::IndexOutput *createOutput (::java::lang::String *) = 0;
  virtual ::org::apache::lucene::store::IndexInput *openInput (::java::lang::String *) = 0;
  virtual ::org::apache::lucene::store::Lock *makeLock (::java::lang::String *);
  virtual void close () = 0;
  virtual void setLockFactory (::org::apache::lucene::store::LockFactory *);
  virtual ::org::apache::lucene::store::LockFactory *getLockFactory () { return lockFactory; }
  virtual ::java::lang::String *getLockID ();
public:  // actually protected
  ::org::apache::lucene::store::LockFactory * __attribute__((aligned(__alignof__( ::java::lang::Object )))) lockFactory;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_Directory__ */
