// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_IndexFileNameFilter__
#define __org_apache_lucene_index_IndexFileNameFilter__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexFileNameFilter;
        }
      }
    }
  }
}

class org::apache::lucene::index::IndexFileNameFilter : public ::java::lang::Object
{
public:
  IndexFileNameFilter ();
  virtual jboolean accept (::java::io::File *, ::java::lang::String *);
  virtual jboolean isCFSFile (::java::lang::String *);
  static ::org::apache::lucene::index::IndexFileNameFilter *getFilter ();
  virtual jboolean matches (::java::lang::String *, ::java::lang::String *);
public: // actually package-private
  static ::org::apache::lucene::index::IndexFileNameFilter *singleton;
private:
  ::java::util::HashSet * __attribute__((aligned(__alignof__( ::java::lang::Object )))) extensions;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_IndexFileNameFilter__ */
