// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldCacheImpl__
#define __org_apache_lucene_search_FieldCacheImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class FieldCacheImpl;
          class SortComparator;
          class FieldCache$StringIndex;
          class FieldCacheImpl$Cache;
          class FieldCache$FloatParser;
          class FieldCache$IntParser;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldCacheImpl : public ::java::lang::Object
{
public: // actually package-private
  FieldCacheImpl ();
public:
  virtual jintArray getInts (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  virtual jintArray getInts (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::FieldCache$IntParser *);
  virtual jfloatArray getFloats (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  virtual jfloatArray getFloats (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::FieldCache$FloatParser *);
  virtual JArray< ::java::lang::String *> *getStrings (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  virtual ::org::apache::lucene::search::FieldCache$StringIndex *getStringIndex (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  virtual ::java::lang::Object *getAuto (::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  virtual JArray< ::java::lang::Comparable *> *getCustom (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::SortComparator *);
private:
  static ::org::apache::lucene::search::FieldCache$IntParser *INT_PARSER;
  static ::org::apache::lucene::search::FieldCache$FloatParser *FLOAT_PARSER;
public: // actually package-private
  ::org::apache::lucene::search::FieldCacheImpl$Cache * __attribute__((aligned(__alignof__( ::java::lang::Object )))) intsCache;
  ::org::apache::lucene::search::FieldCacheImpl$Cache *floatsCache;
  ::org::apache::lucene::search::FieldCacheImpl$Cache *stringsCache;
  ::org::apache::lucene::search::FieldCacheImpl$Cache *stringsIndexCache;
  ::org::apache::lucene::search::FieldCacheImpl$Cache *autoCache;
  ::org::apache::lucene::search::FieldCacheImpl$Cache *customCache;

  friend class org_apache_lucene_search_FieldCacheImpl$Entry;
  friend class org_apache_lucene_search_FieldCacheImpl$CreationPlaceholder;
  friend class org_apache_lucene_search_FieldCacheImpl$Cache;
  friend class org_apache_lucene_search_FieldCache$IntParser;
  friend class org_apache_lucene_search_FieldCache$FloatParser;
  friend class org_apache_lucene_search_FieldCache$StringIndex;
  friend class org_apache_lucene_search_FieldCacheImpl$3;
  friend class org_apache_lucene_search_FieldCacheImpl$4;
  friend class org_apache_lucene_search_FieldCacheImpl$5;
  friend class org_apache_lucene_search_FieldCacheImpl$6;
  friend class org_apache_lucene_search_FieldCacheImpl$7;
  friend class org_apache_lucene_search_FieldCacheImpl$8;
  friend class org_apache_lucene_search_FieldCacheImpl$1;
  friend class org_apache_lucene_search_FieldCacheImpl$2;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldCacheImpl__ */
