// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer__
#define __org_apache_lucene_search_BooleanScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer;
          class Explanation;
          class HitCollector;
          class Scorer;
          class Similarity;
          class BooleanScorer$Bucket;
          class BooleanScorer$BucketTable;
          class BooleanScorer$SubScorer;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer : public ::org::apache::lucene::search::Scorer
{
public: // actually package-private
  BooleanScorer (::org::apache::lucene::search::Similarity *);
  void add (::org::apache::lucene::search::Scorer *, jboolean, jboolean);
private:
  void computeCoordFactors ();
public:
  void score (::org::apache::lucene::search::HitCollector *);
public:  // actually protected
  jboolean score (::org::apache::lucene::search::HitCollector *, jint);
public:
  jint doc ();
  jboolean next ();
  jfloat score ();
  jboolean skipTo (jint);
  ::org::apache::lucene::search::Explanation *explain (jint);
  ::java::lang::String *toString ();
private:
  ::org::apache::lucene::search::BooleanScorer$SubScorer * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) scorers;
  ::org::apache::lucene::search::BooleanScorer$BucketTable *bucketTable;
  jint maxCoord;
  jfloatArray coordFactors;
  jint requiredMask;
  jint prohibitedMask;
  jint nextMask;
  jint end;
  ::org::apache::lucene::search::BooleanScorer$Bucket *current;

  friend class org_apache_lucene_search_BooleanScorer$Collector;
  friend class org_apache_lucene_search_BooleanScorer$BucketTable;
  friend class org_apache_lucene_search_BooleanScorer$Bucket;
  friend class org_apache_lucene_search_BooleanScorer$SubScorer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer__ */
