// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_MultiTermDocs__
#define __org_apache_lucene_index_MultiTermDocs__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class MultiTermDocs;
          class TermEnum;
          class TermDocs;
          class Term;
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::index::MultiTermDocs : public ::java::lang::Object
{
public:
  MultiTermDocs (JArray< ::org::apache::lucene::index::IndexReader *> *, jintArray);
  virtual jint doc ();
  virtual jint freq ();
  virtual void seek (::org::apache::lucene::index::Term *);
  virtual void seek (::org::apache::lucene::index::TermEnum *);
  virtual jboolean next ();
  virtual jint read (jintArray, jintArray);
  virtual jboolean skipTo (jint);
private:
  ::org::apache::lucene::index::TermDocs *termDocs (jint);
public:  // actually protected
  virtual ::org::apache::lucene::index::TermDocs *termDocs (::org::apache::lucene::index::IndexReader *);
public:
  virtual void close ();
public:  // actually protected
  JArray< ::org::apache::lucene::index::IndexReader *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) readers;
  jintArray starts;
  ::org::apache::lucene::index::Term *term;
  jint base;
  jint pointer;
private:
  JArray< ::org::apache::lucene::index::TermDocs *> *readerTermDocs;
public:  // actually protected
  ::org::apache::lucene::index::TermDocs *current;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_MultiTermDocs__ */
