// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_IndexInput__
#define __org_apache_lucene_store_IndexInput__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::store::IndexInput : public ::java::lang::Object
{
public:
  IndexInput ();
  virtual jbyte readByte () = 0;
  virtual void readBytes (jbyteArray, jint, jint) = 0;
  virtual jint readInt ();
  virtual jint readVInt ();
  virtual jlong readLong ();
  virtual jlong readVLong ();
  virtual ::java::lang::String *readString ();
  virtual void readChars (jcharArray, jint, jint);
  virtual void skipChars (jint);
  virtual void close () = 0;
  virtual jlong getFilePointer () = 0;
  virtual void seek (jlong) = 0;
  virtual jlong length () = 0;
  virtual ::java::lang::Object *clone ();
private:
  jcharArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  chars;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_IndexInput__ */
