// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __net_sf_snowball_ext_LovinsStemmer__
#define __net_sf_snowball_ext_LovinsStemmer__

#pragma interface

#include <net/sf/snowball/SnowballProgram.h>
#include <gcj/array.h>

extern "Java"
{
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        namespace ext
        {
          class LovinsStemmer;
        }
        class Among;
      }
    }
  }
}

class net::sf::snowball::ext::LovinsStemmer : public ::net::sf::snowball::SnowballProgram
{
public:
  LovinsStemmer ();
private:
  void copy_from (::net::sf::snowball::ext::LovinsStemmer *);
  jboolean r_A ();
  jboolean r_B ();
  jboolean r_C ();
  jboolean r_D ();
  jboolean r_E ();
  jboolean r_F ();
  jboolean r_G ();
  jboolean r_H ();
  jboolean r_I ();
  jboolean r_J ();
  jboolean r_K ();
  jboolean r_L ();
  jboolean r_M ();
  jboolean r_N ();
  jboolean r_O ();
  jboolean r_P ();
  jboolean r_Q ();
  jboolean r_R ();
  jboolean r_S ();
  jboolean r_T ();
  jboolean r_U ();
  jboolean r_V ();
  jboolean r_W ();
  jboolean r_X ();
  jboolean r_Y ();
  jboolean r_Z ();
  jboolean r_AA ();
  jboolean r_BB ();
  jboolean r_CC ();
  jboolean r_endings ();
  jboolean r_undouble ();
  jboolean r_respell ();
public:
  virtual jboolean stem ();
private:
  JArray< ::net::sf::snowball::Among *> * __attribute__((aligned(__alignof__( ::net::sf::snowball::SnowballProgram )))) a_0;
  JArray< ::net::sf::snowball::Among *> *a_1;
  JArray< ::net::sf::snowball::Among *> *a_2;
  JArray< ::net::sf::snowball::Among *> *a_3;
public:

  static ::java::lang::Class class$;
};

#endif /* __net_sf_snowball_ext_LovinsStemmer__ */
