// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_MMapDirectory$MMapIndexInput__
#define __org_apache_lucene_store_MMapDirectory$MMapIndexInput__

#pragma interface

#include <org/apache/lucene/store/IndexInput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class MMapDirectory$MMapIndexInput;
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      class ByteBuffer;
    }
  }
}

class org::apache::lucene::store::MMapDirectory$MMapIndexInput : public ::org::apache::lucene::store::IndexInput
{
private:
  MMapDirectory$MMapIndexInput (::java::io::RandomAccessFile *);
public:
  virtual jbyte readByte ();
  virtual void readBytes (jbyteArray, jint, jint);
  virtual jlong getFilePointer ();
  virtual void seek (jlong);
  virtual jlong length () { return length__; }
  virtual ::java::lang::Object *clone ();
  virtual void close () { }
private:
  ::java::nio::ByteBuffer * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::IndexInput )))) buffer;
  jlong length__;

  friend class org_apache_lucene_store_MMapDirectory$MMapIndexInput;
  friend class org_apache_lucene_store_MMapDirectory$1;
  friend class java_nio_channels_FileChannel$MapMode;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_MMapDirectory$MMapIndexInput__ */
