// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_CompoundFileReader$CSIndexInput__
#define __org_apache_lucene_index_CompoundFileReader$CSIndexInput__

#pragma interface

#include <org/apache/lucene/store/BufferedIndexInput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class CompoundFileReader$CSIndexInput;
        }
        namespace store
        {
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::index::CompoundFileReader$CSIndexInput : public ::org::apache::lucene::store::BufferedIndexInput
{
public: // actually package-private
  CompoundFileReader$CSIndexInput (::org::apache::lucene::store::IndexInput *, jlong, jlong);
public:  // actually protected
  void readInternal (jbyteArray, jint, jint);
  void seekInternal (jlong) { }
public:
  void close () { }
  jlong length () { return length__; }
public: // actually package-private
  ::org::apache::lucene::store::IndexInput * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::BufferedIndexInput )))) base;
  jlong fileOffset;
  jlong length__;

  friend class org_apache_lucene_index_CompoundFileReader$CSIndexInput;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_CompoundFileReader$CSIndexInput__ */
