// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_ISOLatin1AccentFilter__
#define __org_apache_lucene_analysis_ISOLatin1AccentFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class ISOLatin1AccentFilter;
          class Token;
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::ISOLatin1AccentFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  ISOLatin1AccentFilter (::org::apache::lucene::analysis::TokenStream *);
  ::org::apache::lucene::analysis::Token *next ();
  static ::java::lang::String *removeAccents (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_ISOLatin1AccentFilter__ */
