// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_BitVector__
#define __org_apache_lucene_util_BitVector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class BitVector;
        }
        namespace store
        {
          class Directory;
        }
      }
    }
  }
}

class org::apache::lucene::util::BitVector : public ::java::lang::Object
{
public:
  BitVector (jint);
  void set (jint);
  void clear (jint);
  jboolean get (jint);
  jint size () { return size__; }
  jint count ();
  void write (::org::apache::lucene::store::Directory *, ::java::lang::String *);
  BitVector (::org::apache::lucene::store::Directory *, ::java::lang::String *);
private:
  jbyteArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  bits;
  jint size__;
  jint count__;
  static jbyteArray BYTE_COUNTS;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_BitVector__ */
