// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldSortedHitQueue$2__
#define __org_apache_lucene_search_FieldSortedHitQueue$2__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldSortedHitQueue$2;
          class ScoreDoc;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldSortedHitQueue$2 : public ::java::lang::Object
{
public: // actually package-private
  FieldSortedHitQueue$2 (jintArray);
public:
  jint compare (::org::apache::lucene::search::ScoreDoc *, ::org::apache::lucene::search::ScoreDoc *);
  virtual ::java::lang::Comparable *sortValue (::org::apache::lucene::search::ScoreDoc *);
  virtual jint sortType ();
private:
  jintArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  val$fieldOrder;

  friend class org_apache_lucene_search_FieldSortedHitQueue$2;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldSortedHitQueue$2__ */
