// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer2$1__
#define __org_apache_lucene_search_BooleanScorer2$1__

#pragma interface

#include <org/apache/lucene/search/DisjunctionSumScorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer2$1;
          class BooleanScorer2;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer2$1 : public ::org::apache::lucene::search::DisjunctionSumScorer
{
public: // actually package-private
  BooleanScorer2$1 (::org::apache::lucene::search::BooleanScorer2 *, ::java::util::List *, jint);
public:
  virtual jfloat score ();
private:
  jint __attribute__((aligned(__alignof__( ::org::apache::lucene::search::DisjunctionSumScorer ))))  lastScoredDoc;
  ::org::apache::lucene::search::BooleanScorer2 *this$0;

  friend class org_apache_lucene_search_BooleanScorer2$1;
  friend class org_apache_lucene_search_BooleanScorer2$Coordinator;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer2$1__ */
