/* ====================================================================
 * Copyright (c) 2004-2005 Open Source Applications Foundation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions: 
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 * ====================================================================
 */

package org.osafoundation.util;

import java.io.IOException;
import java.util.Enumeration;
import java.util.NoSuchElementException;
import org.apache.lucene.analysis.Token;
import org.apache.lucene.analysis.TokenStream;


public class TokenEnumeration implements Enumeration {

    protected TokenStream tokenStream;
    protected Token current;

    public TokenEnumeration(TokenStream tokenStream)
    {
        this.tokenStream = tokenStream;
    }

    public boolean hasMoreElements()
    {
        if (current == null)
            try {
                current = tokenStream.next();
            } catch (IOException e) {
                return false;
            }

        return current != null;
    }

    public Object nextElement()
    {
        if (current == null)
        {
            try {
                current = tokenStream.next();
            } catch (IOException e) {
                throw new NoSuchElementException(e.toString());
            }

            if (current == null)
                throw new NoSuchElementException();
        }

        try {
            return current;
        } finally {
            current = null;
        }
    }
}
