// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Hit__
#define __org_apache_lucene_search_Hit__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Hit;
          class Hits;
        }
        namespace document
        {
          class Document;
        }
      }
    }
  }
}

class org::apache::lucene::search::Hit : public ::java::lang::Object
{
public: // actually package-private
  Hit (::org::apache::lucene::search::Hits *, jint);
public:
  virtual ::org::apache::lucene::document::Document *getDocument ();
  virtual jfloat getScore ();
  virtual jint getId ();
private:
  void fetchTheHit ();
public:
  virtual jfloat getBoost ();
  virtual ::java::lang::String *get (::java::lang::String *);
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::document::Document * __attribute__((aligned(__alignof__( ::java::lang::Object )))) doc;
  jboolean resolved;
  ::org::apache::lucene::search::Hits *hits;
  jint hitNumber;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Hit__ */
