// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_PerFieldAnalyzerWrapper__
#define __org_apache_lucene_analysis_PerFieldAnalyzerWrapper__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class PerFieldAnalyzerWrapper;
          class TokenStream;
          class Analyzer;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::PerFieldAnalyzerWrapper : public ::org::apache::lucene::analysis::Analyzer
{
public:
  PerFieldAnalyzerWrapper (::org::apache::lucene::analysis::Analyzer *);
  virtual void addAnalyzer (::java::lang::String *, ::org::apache::lucene::analysis::Analyzer *);
  virtual ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);
  virtual jint getPositionIncrementGap (::java::lang::String *);
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::analysis::Analyzer * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Analyzer )))) defaultAnalyzer;
  ::java::util::Map *analyzerMap;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_PerFieldAnalyzerWrapper__ */
