// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FuzzyLikeThisQuery$FieldVals__
#define __org_apache_lucene_search_FuzzyLikeThisQuery$FieldVals__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FuzzyLikeThisQuery$FieldVals;
          class FuzzyLikeThisQuery;
        }
      }
    }
  }
}

class org::apache::lucene::search::FuzzyLikeThisQuery$FieldVals : public ::java::lang::Object
{
public:
  FuzzyLikeThisQuery$FieldVals (::org::apache::lucene::search::FuzzyLikeThisQuery *, ::java::lang::String *, jfloat, jint, ::java::lang::String *);
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) queryString;
  ::java::lang::String *fieldName;
  jfloat minSimilarity;
  jint prefixLength;
private:
  ::org::apache::lucene::search::FuzzyLikeThisQuery *this$0;

  friend class org_apache_lucene_search_FuzzyLikeThisQuery$FieldVals;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FuzzyLikeThisQuery$FieldVals__ */
