// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermVectorsReader__
#define __org_apache_lucene_index_TermVectorsReader__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class Directory;
          class IndexInput;
        }
        namespace index
        {
          class TermVectorsReader;
          class SegmentTermVector;
          class TermFreqVector;
          class FieldInfos;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermVectorsReader : public ::java::lang::Object
{
public: // actually package-private
  TermVectorsReader (::org::apache::lucene::store::Directory *, ::java::lang::String *, ::org::apache::lucene::index::FieldInfos *);
private:
  jint checkValidFormat (::org::apache::lucene::store::IndexInput *);
public: // actually package-private
  virtual void close ();
  virtual jint size () { return size__; }
  virtual ::org::apache::lucene::index::TermFreqVector *get (jint, ::java::lang::String *);
  virtual JArray< ::org::apache::lucene::index::TermFreqVector *> *get (jint);
private:
  JArray< ::org::apache::lucene::index::SegmentTermVector *> *readTermVectors (JArray< ::java::lang::String *> *, jlongArray);
  ::org::apache::lucene::index::SegmentTermVector *readTermVector (::java::lang::String *, jlong);
public:  // actually protected
  virtual ::java::lang::Object *clone ();
private:
  ::org::apache::lucene::index::FieldInfos * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fieldInfos;
  ::org::apache::lucene::store::IndexInput *tvx;
  ::org::apache::lucene::store::IndexInput *tvd;
  ::org::apache::lucene::store::IndexInput *tvf;
  jint size__;
  jint tvdFormat;
  jint tvfFormat;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermVectorsReader__ */
