// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_NoLockFactory__
#define __org_apache_lucene_store_NoLockFactory__

#pragma interface

#include <org/apache/lucene/store/LockFactory.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class Lock;
          class NoLockFactory;
          class NoLock;
        }
      }
    }
  }
}

class org::apache::lucene::store::NoLockFactory : public ::org::apache::lucene::store::LockFactory
{
public:
  NoLockFactory ();
  static ::org::apache::lucene::store::NoLockFactory *getNoLockFactory ();
  virtual ::org::apache::lucene::store::Lock *makeLock (::java::lang::String *);
  virtual void clearAllLocks () { }
private:
  static ::org::apache::lucene::store::NoLock *singletonLock;
  static ::org::apache::lucene::store::NoLockFactory *singleton;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_NoLockFactory__ */
