// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_th_ThaiWordFilter__
#define __org_apache_lucene_analysis_th_ThaiWordFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace th
          {
            class ThaiWordFilter;
          }
          class TokenStream;
          class Token;
        }
      }
    }
  }
  namespace java
  {
    namespace text
    {
      class BreakIterator;
    }
  }
}

class org::apache::lucene::analysis::th::ThaiWordFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  ThaiWordFilter (::org::apache::lucene::analysis::TokenStream *);
  virtual ::org::apache::lucene::analysis::Token *next ();
private:
  ::java::text::BreakIterator * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter )))) breaker;
  ::org::apache::lucene::analysis::Token *thaiToken;

  friend class java_lang_Character$UnicodeBlock;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_th_ThaiWordFilter__ */
