// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentInfos$FindSegmentsFile__
#define __org_apache_lucene_index_SegmentInfos$FindSegmentsFile__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentInfos$FindSegmentsFile;
        }
        namespace store
        {
          class Directory;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentInfos$FindSegmentsFile : public ::java::lang::Object
{
public:
  SegmentInfos$FindSegmentsFile (::java::io::File *);
  SegmentInfos$FindSegmentsFile (::org::apache::lucene::store::Directory *);
  virtual ::java::lang::Object *run ();
public:  // actually protected
  virtual ::java::lang::Object *doBody (::java::lang::String *) = 0;
public: // actually package-private
  ::java::io::File * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fileDirectory;
  ::org::apache::lucene::store::Directory *directory;

  friend class org_apache_lucene_index_SegmentInfos$FindSegmentsFile;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentInfos$FindSegmentsFile__ */
