// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldCache__
#define __org_apache_lucene_search_FieldCache__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class SortComparator;
          class FieldCache$StringIndex;
          class FieldCache$FloatParser;
          class FieldCache$IntParser;
          class FieldCache;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldCache : public ::java::lang::Object
{
public:
  virtual jintArray getInts (::org::apache::lucene::index::IndexReader *, ::java::lang::String *) = 0;
  virtual jintArray getInts (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::FieldCache$IntParser *) = 0;
  virtual jfloatArray getFloats (::org::apache::lucene::index::IndexReader *, ::java::lang::String *) = 0;
  virtual jfloatArray getFloats (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::FieldCache$FloatParser *) = 0;
  virtual JArray< ::java::lang::String *> *getStrings (::org::apache::lucene::index::IndexReader *, ::java::lang::String *) = 0;
  virtual ::org::apache::lucene::search::FieldCache$StringIndex *getStringIndex (::org::apache::lucene::index::IndexReader *, ::java::lang::String *) = 0;
  virtual ::java::lang::Object *getAuto (::org::apache::lucene::index::IndexReader *, ::java::lang::String *) = 0;
  virtual JArray< ::java::lang::Comparable *> *getCustom (::org::apache::lucene::index::IndexReader *, ::java::lang::String *, ::org::apache::lucene::search::SortComparator *) = 0;
  static const jint STRING_INDEX = -1L;
  static ::org::apache::lucene::search::FieldCache *DEFAULT;

  friend class org_apache_lucene_search_FieldCache$FloatParser;
  friend class org_apache_lucene_search_FieldCache$IntParser;
  friend class org_apache_lucene_search_FieldCache$StringIndex;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_search_FieldCache__ */
