// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_de_GermanStemmer__
#define __org_apache_lucene_analysis_de_GermanStemmer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace de
          {
            class GermanStemmer;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::de::GermanStemmer : public ::java::lang::Object
{
public:
  GermanStemmer ();
public:  // actually protected
  virtual ::java::lang::String *stem (::java::lang::String *);
private:
  jboolean isStemmable (::java::lang::String *);
  void strip (::java::lang::StringBuffer *);
  void optimize (::java::lang::StringBuffer *);
  void removeParticleDenotion (::java::lang::StringBuffer *);
  void substitute (::java::lang::StringBuffer *);
  void resubstitute (::java::lang::StringBuffer *);
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sb;
  jint substCount;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_de_GermanStemmer__ */
