// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Searcher__
#define __org_apache_lucene_search_Searcher__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Document;
        }
        namespace index
        {
          class Term;
        }
        namespace search
        {
          class Searcher;
          class Weight;
          class Explanation;
          class TopDocs;
          class HitCollector;
          class TopFieldDocs;
          class Sort;
          class Filter;
          class Hits;
          class Query;
          class Similarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::Searcher : public ::java::lang::Object
{
public:
  Searcher ();
  ::org::apache::lucene::search::Hits *search (::org::apache::lucene::search::Query *);
  virtual ::org::apache::lucene::search::Hits *search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *);
  virtual ::org::apache::lucene::search::Hits *search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Sort *);
  virtual ::org::apache::lucene::search::Hits *search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::Sort *);
  virtual ::org::apache::lucene::search::TopFieldDocs *search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::Sort *);
  virtual void search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::HitCollector *);
  virtual void search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::HitCollector *);
  virtual ::org::apache::lucene::search::TopDocs *search (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::Filter *, jint);
  virtual ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::search::Query *, jint);
  virtual void setSimilarity (::org::apache::lucene::search::Similarity *);
  virtual ::org::apache::lucene::search::Similarity *getSimilarity () { return similarity; }
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Query *);
public:
  virtual jintArray docFreqs (JArray< ::org::apache::lucene::index::Term *> *);
  virtual void search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::HitCollector *) = 0;
  virtual void close () = 0;
  virtual jint docFreq (::org::apache::lucene::index::Term *) = 0;
  virtual jint maxDoc () = 0;
  virtual ::org::apache::lucene::search::TopDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint) = 0;
  virtual ::org::apache::lucene::document::Document *doc (jint) = 0;
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::search::Query *) = 0;
  virtual ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::search::Weight *, jint) = 0;
  virtual ::org::apache::lucene::search::TopFieldDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::Sort *) = 0;
private:
  ::org::apache::lucene::search::Similarity * __attribute__((aligned(__alignof__( ::java::lang::Object )))) similarity;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Searcher__ */
