// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldSortedHitQueue$4__
#define __org_apache_lucene_search_FieldSortedHitQueue$4__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldSortedHitQueue$4;
          class ScoreDoc;
          class FieldCache$StringIndex;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldSortedHitQueue$4 : public ::java::lang::Object
{
public: // actually package-private
  FieldSortedHitQueue$4 (::org::apache::lucene::search::FieldCache$StringIndex *);
public:
  jint compare (::org::apache::lucene::search::ScoreDoc *, ::org::apache::lucene::search::ScoreDoc *);
  virtual ::java::lang::Comparable *sortValue (::org::apache::lucene::search::ScoreDoc *);
  virtual jint sortType ();
private:
  ::org::apache::lucene::search::FieldCache$StringIndex * __attribute__((aligned(__alignof__( ::java::lang::Object )))) val$index;

  friend class org_apache_lucene_search_FieldCache$StringIndex;
  friend class org_apache_lucene_search_FieldSortedHitQueue$4;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldSortedHitQueue$4__ */
