// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FieldReaderException__
#define __org_apache_lucene_index_FieldReaderException__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class FieldReaderException;
        }
      }
    }
  }
}

class org::apache::lucene::index::FieldReaderException : public ::java::lang::RuntimeException
{
public:
  FieldReaderException ();
  FieldReaderException (::java::lang::Throwable *);
  FieldReaderException (::java::lang::String *);
  FieldReaderException (::java::lang::String *, ::java::lang::Throwable *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FieldReaderException__ */
