// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_RangeFilter__
#define __org_apache_lucene_search_RangeFilter__

#pragma interface

#include <org/apache/lucene/search/Filter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class RangeFilter;
        }
      }
    }
  }
}

class org::apache::lucene::search::RangeFilter : public ::org::apache::lucene::search::Filter
{
public:
  RangeFilter (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, jboolean, jboolean);
  static ::org::apache::lucene::search::RangeFilter *Less (::java::lang::String *, ::java::lang::String *);
  static ::org::apache::lucene::search::RangeFilter *More (::java::lang::String *, ::java::lang::String *);
  virtual ::java::util::BitSet *bits (::org::apache::lucene::index::IndexReader *);
  virtual ::java::lang::String *toString ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Filter )))) fieldName;
  ::java::lang::String *lowerTerm;
  ::java::lang::String *upperTerm;
  jboolean includeLower;
  jboolean includeUpper;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_RangeFilter__ */
