// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_WeightedTerm__
#define __org_apache_lucene_search_highlight_WeightedTerm__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class WeightedTerm;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::WeightedTerm : public ::java::lang::Object
{
public:
  WeightedTerm (jfloat, ::java::lang::String *);
  virtual ::java::lang::String *getTerm () { return term; }
  virtual jfloat getWeight () { return weight; }
  virtual void setTerm (::java::lang::String *);
  virtual void setWeight (jfloat);
public: // actually package-private
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  weight;
  ::java::lang::String *term;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_WeightedTerm__ */
