// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ExactPhraseScorer__
#define __org_apache_lucene_search_ExactPhraseScorer__

#pragma interface

#include <org/apache/lucene/search/PhraseScorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermPositions;
        }
        namespace search
        {
          class ExactPhraseScorer;
          class Similarity;
          class Weight;
        }
      }
    }
  }
}

class org::apache::lucene::search::ExactPhraseScorer : public ::org::apache::lucene::search::PhraseScorer
{
public: // actually package-private
  ExactPhraseScorer (::org::apache::lucene::search::Weight *, JArray< ::org::apache::lucene::index::TermPositions *> *, jintArray, ::org::apache::lucene::search::Similarity *, jbyteArray);
public:  // actually protected
  jfloat phraseFreq ();
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ExactPhraseScorer__ */
