// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FieldInfo__
#define __org_apache_lucene_index_FieldInfo__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class FieldInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::FieldInfo : public ::java::lang::Object
{
public: // actually package-private
  FieldInfo (::java::lang::String *, jboolean, jint, jboolean, jboolean, jboolean, jboolean);
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name;
  jboolean isIndexed;
  jint number;
  jboolean storeTermVector;
  jboolean storeOffsetWithTermVector;
  jboolean storePositionWithTermVector;
  jboolean omitNorms;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FieldInfo__ */
