// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Scorer__
#define __org_apache_lucene_search_Scorer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Scorer;
          class Explanation;
          class HitCollector;
          class Similarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::Scorer : public ::java::lang::Object
{
public:  // actually protected
  Scorer (::org::apache::lucene::search::Similarity *);
public:
  virtual ::org::apache::lucene::search::Similarity *getSimilarity () { return similarity; }
  virtual void score (::org::apache::lucene::search::HitCollector *);
public:  // actually protected
  virtual jboolean score (::org::apache::lucene::search::HitCollector *, jint);
public:
  virtual jboolean next () = 0;
  virtual jint doc () = 0;
  virtual jfloat score () = 0;
  virtual jboolean skipTo (jint) = 0;
  virtual ::org::apache::lucene::search::Explanation *explain (jint) = 0;
private:
  ::org::apache::lucene::search::Similarity * __attribute__((aligned(__alignof__( ::java::lang::Object )))) similarity;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Scorer__ */
