// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_WordlistLoader__
#define __org_apache_lucene_analysis_WordlistLoader__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class WordlistLoader;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::WordlistLoader : public ::java::lang::Object
{
public:
  WordlistLoader ();
  static ::java::util::HashSet *getWordSet (::java::io::File *);
  static ::java::util::HashSet *getWordSet (::java::io::Reader *);
  static ::java::util::HashMap *getStemDict (::java::io::File *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_WordlistLoader__ */
