// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_MultipleTermPositions$IntQueue__
#define __org_apache_lucene_index_MultipleTermPositions$IntQueue__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class MultipleTermPositions$IntQueue;
        }
      }
    }
  }
}

class org::apache::lucene::index::MultipleTermPositions$IntQueue : public ::java::lang::Object
{
private:
  MultipleTermPositions$IntQueue ();
public: // actually package-private
  void add (jint);
  jint next ();
  void sort ();
  void clear ();
  jint size ();
private:
  void growArray ();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  _arraySize;
  jint _index;
  jint _lastIndex;
  jintArray _array;

  friend class org_apache_lucene_index_MultipleTermPositions$IntQueue;
  friend class org_apache_lucene_index_MultipleTermPositions$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_MultipleTermPositions$IntQueue__ */
