// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_TermsFilter__
#define __org_apache_lucene_search_TermsFilter__

#pragma interface

#include <org/apache/lucene/search/Filter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class TermsFilter;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::TermsFilter : public ::org::apache::lucene::search::Filter
{
public:
  TermsFilter ();
  virtual void addTerm (::org::apache::lucene::index::Term *);
  virtual ::java::util::BitSet *bits (::org::apache::lucene::index::IndexReader *);
public: // actually package-private
  ::java::util::ArrayList * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Filter )))) termsList;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_TermsFilter__ */
