// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_Field$TermVector__
#define __org_apache_lucene_document_Field$TermVector__

#pragma interface

#include <org/apache/lucene/util/Parameter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Field$TermVector;
        }
      }
    }
  }
}

class org::apache::lucene::document::Field$TermVector : public ::org::apache::lucene::util::Parameter
{
private:
  Field$TermVector (::java::lang::String *);
public:
  static ::org::apache::lucene::document::Field$TermVector *NO;
  static ::org::apache::lucene::document::Field$TermVector *YES;
  static ::org::apache::lucene::document::Field$TermVector *WITH_POSITIONS;
  static ::org::apache::lucene::document::Field$TermVector *WITH_OFFSETS;
  static ::org::apache::lucene::document::Field$TermVector *WITH_POSITIONS_OFFSETS;

  friend class org_apache_lucene_document_Field$TermVector;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_Field$TermVector__ */
