// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_HitDoc__
#define __org_apache_lucene_search_HitDoc__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class HitDoc;
        }
        namespace document
        {
          class Document;
        }
      }
    }
  }
}

class org::apache::lucene::search::HitDoc : public ::java::lang::Object
{
public: // actually package-private
  HitDoc (jfloat, jint);
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  score;
  jint id;
  ::org::apache::lucene::document::Document *doc;
  ::org::apache::lucene::search::HitDoc *next;
  ::org::apache::lucene::search::HitDoc *prev;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_HitDoc__ */
