// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldDoc__
#define __org_apache_lucene_search_FieldDoc__

#pragma interface

#include <org/apache/lucene/search/ScoreDoc.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldDoc;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldDoc : public ::org::apache::lucene::search::ScoreDoc
{
public:
  FieldDoc (jint, jfloat);
  FieldDoc (jint, jfloat, JArray< ::java::lang::Comparable *> *);
  JArray< ::java::lang::Comparable *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::ScoreDoc )))) fields;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldDoc__ */
