// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BoostingQuery$1$1__
#define __org_apache_lucene_search_BoostingQuery$1$1__

#pragma interface

#include <org/apache/lucene/search/DefaultSimilarity.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BoostingQuery$1$1;
          class BoostingQuery$1;
        }
      }
    }
  }
}

class org::apache::lucene::search::BoostingQuery$1$1 : public ::org::apache::lucene::search::DefaultSimilarity
{
public: // actually package-private
  BoostingQuery$1$1 (::org::apache::lucene::search::BoostingQuery$1 *);
public:
  virtual jfloat coord (jint, jint);
private:
  ::org::apache::lucene::search::BoostingQuery$1 * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::DefaultSimilarity )))) this$1;

  friend class org_apache_lucene_search_BoostingQuery$1;
  friend class org_apache_lucene_search_BoostingQuery$1$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BoostingQuery$1$1__ */
