// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_SmallFloat__
#define __org_apache_lucene_util_SmallFloat__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class SmallFloat;
        }
      }
    }
  }
}

class org::apache::lucene::util::SmallFloat : public ::java::lang::Object
{
public:
  SmallFloat ();
  static jbyte floatToByte (jfloat, jint, jint);
  static jfloat byteToFloat (jbyte, jint, jint);
  static jbyte floatToByte315 (jfloat);
  static jfloat byte315ToFloat (jbyte);
  static jbyte floatToByte52 (jfloat);
  static jfloat byte52ToFloat (jbyte);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_SmallFloat__ */
