// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer$Collector__
#define __org_apache_lucene_search_BooleanScorer$Collector__

#pragma interface

#include <org/apache/lucene/search/HitCollector.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer$Collector;
          class BooleanScorer$BucketTable;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer$Collector : public ::org::apache::lucene::search::HitCollector
{
public:
  BooleanScorer$Collector (jint, ::org::apache::lucene::search::BooleanScorer$BucketTable *);
  void collect (jint, jfloat);
private:
  ::org::apache::lucene::search::BooleanScorer$BucketTable * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::HitCollector )))) bucketTable;
  jint mask;

  friend class org_apache_lucene_search_BooleanScorer$BucketTable;
  friend class org_apache_lucene_search_BooleanScorer$Collector;
  friend class org_apache_lucene_search_BooleanScorer$Bucket;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer$Collector__ */
