// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_SpanOrQuery$SpanQueue__
#define __org_apache_lucene_search_spans_SpanOrQuery$SpanQueue__

#pragma interface

#include <org/apache/lucene/util/PriorityQueue.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace spans
          {
            class SpanOrQuery$SpanQueue;
            class SpanOrQuery;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::SpanOrQuery$SpanQueue : public ::org::apache::lucene::util::PriorityQueue
{
public:
  SpanOrQuery$SpanQueue (::org::apache::lucene::search::spans::SpanOrQuery *, jint);
public:  // actually protected
  jboolean lessThan (::java::lang::Object *, ::java::lang::Object *);
private:
  ::org::apache::lucene::search::spans::SpanOrQuery * __attribute__((aligned(__alignof__( ::org::apache::lucene::util::PriorityQueue )))) this$0;

  friend class org_apache_lucene_search_spans_SpanOrQuery$SpanQueue;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_SpanOrQuery$SpanQueue__ */
