// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_fr_FrenchStemmer__
#define __org_apache_lucene_analysis_fr_FrenchStemmer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace fr
          {
            class FrenchStemmer;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::fr::FrenchStemmer : public ::java::lang::Object
{
public:
  FrenchStemmer ();
public:  // actually protected
  virtual ::java::lang::String *stem (::java::lang::String *);
private:
  void setStrings ();
  void step1 ();
  jboolean step2a ();
  void step2b ();
  void step3 ();
  void step4 ();
  void step5 ();
  void step6 ();
  jboolean deleteFromIfPrecededIn (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::String *, ::java::lang::String *);
  jboolean deleteFromIfTestVowelBeforeIn (::java::lang::String *, JArray< ::java::lang::String *> *, jboolean, ::java::lang::String *);
  void deleteButSuffixFrom (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::String *, jboolean);
  void deleteButSuffixFromElseReplace (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::String *, jboolean, ::java::lang::String *, ::java::lang::String *);
  jboolean replaceFrom (::java::lang::String *, JArray< ::java::lang::String *> *, ::java::lang::String *);
  void deleteFrom (::java::lang::String *, JArray< ::java::lang::String *> *);
  jboolean isVowel (jchar);
  ::java::lang::String *retrieveR (::java::lang::StringBuffer *);
  ::java::lang::String *retrieveRV (::java::lang::StringBuffer *);
  ::java::lang::StringBuffer *treatVowels (::java::lang::StringBuffer *);
  jboolean isStemmable (::java::lang::String *);
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) sb;
  ::java::lang::StringBuffer *tb;
  ::java::lang::String *R0;
  ::java::lang::String *RV;
  ::java::lang::String *R1;
  ::java::lang::String *R2;
  jboolean suite;
  jboolean modified;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_fr_FrenchStemmer__ */
