// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ConstantScoreQuery__
#define __org_apache_lucene_search_ConstantScoreQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class ConstantScoreQuery;
          class Weight;
          class Searcher;
          class Query;
          class Filter;
        }
      }
    }
  }
}

class org::apache::lucene::search::ConstantScoreQuery : public ::org::apache::lucene::search::Query
{
public:
  ConstantScoreQuery (::org::apache::lucene::search::Filter *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *) { return reinterpret_cast< ::org::apache::lucene::search::Query *> (this); }
  virtual void extractTerms (::java::util::Set *) { }
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Searcher *);
public:
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
public:  // actually protected
  ::org::apache::lucene::search::Filter * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Query )))) filter;

  friend class org_apache_lucene_search_ConstantScoreQuery$ConstantScorer;
  friend class org_apache_lucene_search_ConstantScoreQuery$ConstantWeight;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ConstantScoreQuery__ */
