// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FuzzyTermEnum__
#define __org_apache_lucene_search_FuzzyTermEnum__

#pragma interface

#include <org/apache/lucene/search/FilteredTermEnum.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FuzzyTermEnum;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::FuzzyTermEnum : public ::org::apache::lucene::search::FilteredTermEnum
{
public:
  FuzzyTermEnum (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::index::Term *);
  FuzzyTermEnum (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::index::Term *, jfloat);
  FuzzyTermEnum (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::index::Term *, jfloat, jint);
public:  // actually protected
  jboolean termCompare (::org::apache::lucene::index::Term *);
public:
  jfloat difference ();
  jboolean endEnum () { return endEnum__; }
private:
  static jint min (jint, jint, jint);
  JArray<jintArray> * initDistanceArray ();
  jfloat similarity (::java::lang::String *);
  void growDistanceArray (jint);
  jint getMaxDistance (jint);
  void initializeMaxDistances ();
  jint calculateMaxDistance (jint);
public:
  void close ();
private:
  static const jint TYPICAL_LONGEST_WORD_IN_INDEX = 19L;
  JArray<jintArray> * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::FilteredTermEnum ))))  d;
  jfloat similarity__;
  jboolean endEnum__;
  ::org::apache::lucene::index::Term *searchTerm;
  ::java::lang::String *field;
  ::java::lang::String *text;
  ::java::lang::String *prefix;
  jfloat minimumSimilarity;
  jfloat scale_factor;
  jintArray maxDistances;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FuzzyTermEnum__ */
