// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_standard_TokenMgrError__
#define __org_apache_lucene_analysis_standard_TokenMgrError__

#pragma interface

#include <java/lang/Error.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace standard
          {
            class TokenMgrError;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::standard::TokenMgrError : public ::java::lang::Error
{
public:  // actually protected
  static ::java::lang::String *addEscapes (::java::lang::String *);
  static ::java::lang::String *LexicalError (jboolean, jint, jint, jint, ::java::lang::String *, jchar);
public:
  virtual ::java::lang::String *getMessage ();
  TokenMgrError ();
  TokenMgrError (::java::lang::String *, jint);
  TokenMgrError (jboolean, jint, jint, jint, ::java::lang::String *, jchar, jint);
public: // actually package-private
  static const jint LEXICAL_ERROR = 0L;
  static const jint STATIC_LEXER_ERROR = 1L;
  static const jint INVALID_LEXICAL_STATE = 2L;
  static const jint LOOP_DETECTED = 3L;
  jint __attribute__((aligned(__alignof__( ::java::lang::Error ))))  errorCode;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_standard_TokenMgrError__ */
