// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_Token__
#define __org_apache_lucene_analysis_Token__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::Token : public ::java::lang::Object
{
public:
  Token (::java::lang::String *, jint, jint);
  Token (::java::lang::String *, jint, jint, ::java::lang::String *);
  virtual void setPositionIncrement (jint);
  virtual jint getPositionIncrement () { return positionIncrement; }
  virtual void setTermText (::java::lang::String *);
  ::java::lang::String *termText () { return termText__; }
  jint startOffset () { return startOffset__; }
  jint endOffset () { return endOffset__; }
  ::java::lang::String *type () { return type__; }
  virtual ::java::lang::String *toString ();
  virtual ::java::lang::Object *clone ();
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) termText__;
  jint startOffset__;
  jint endOffset__;
  ::java::lang::String *type__;
private:
  jint positionIncrement;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_Token__ */
