// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_NumberTools__
#define __org_apache_lucene_document_NumberTools__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class NumberTools;
        }
      }
    }
  }
}

class org::apache::lucene::document::NumberTools : public ::java::lang::Object
{
public:
  NumberTools ();
  static ::java::lang::String *longToString (jlong);
  static jlong stringToLong (::java::lang::String *);
private:
  static const jint RADIX = 36L;
  static const jint NEGATIVE_PREFIX = 45L;
  static const jint POSITIVE_PREFIX = 48L;
public:
  static ::java::lang::String *MIN_STRING_VALUE;
  static ::java::lang::String *MAX_STRING_VALUE;
  static jint STR_SIZE;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_NumberTools__ */
