// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_TextFragment__
#define __org_apache_lucene_search_highlight_TextFragment__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class TextFragment;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::TextFragment : public ::java::lang::Object
{
public:
  TextFragment (::java::lang::StringBuffer *, jint, jint);
public: // actually package-private
  virtual void setScore (jfloat);
public:
  virtual jfloat getScore () { return score; }
  virtual void merge (::org::apache::lucene::search::highlight::TextFragment *);
  virtual jboolean follows (::org::apache::lucene::search::highlight::TextFragment *);
  virtual jint getFragNum () { return fragNum; }
  virtual ::java::lang::String *toString ();
public: // actually package-private
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) markedUpText;
  jint fragNum;
  jint textStartPos;
  jint textEndPos;
  jfloat score;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_TextFragment__ */
