// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_nl_DutchStemFilter__
#define __org_apache_lucene_analysis_nl_DutchStemFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class TokenStream;
          namespace nl
          {
            class DutchStemFilter;
            class DutchStemmer;
          }
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::nl::DutchStemFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  DutchStemFilter (::org::apache::lucene::analysis::TokenStream *);
  DutchStemFilter (::org::apache::lucene::analysis::TokenStream *, ::java::util::Set *);
  DutchStemFilter (::org::apache::lucene::analysis::TokenStream *, ::java::util::Set *, ::java::util::Map *);
  ::org::apache::lucene::analysis::Token *next ();
  void setStemmer (::org::apache::lucene::analysis::nl::DutchStemmer *);
  void setExclusionTable (::java::util::HashSet *);
  void setStemDictionary (::java::util::HashMap *);
private:
  ::org::apache::lucene::analysis::Token * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter )))) token;
  ::org::apache::lucene::analysis::nl::DutchStemmer *stemmer;
  ::java::util::Set *exclusions;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_nl_DutchStemFilter__ */
