// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_DateTools$Resolution__
#define __org_apache_lucene_document_DateTools$Resolution__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class DateTools$Resolution;
        }
      }
    }
  }
}

class org::apache::lucene::document::DateTools$Resolution : public ::java::lang::Object
{
private:
  DateTools$Resolution ();
  DateTools$Resolution (::java::lang::String *);
public:
  virtual ::java::lang::String *toString () { return resolution; }
  static ::org::apache::lucene::document::DateTools$Resolution *YEAR;
  static ::org::apache::lucene::document::DateTools$Resolution *MONTH;
  static ::org::apache::lucene::document::DateTools$Resolution *DAY;
  static ::org::apache::lucene::document::DateTools$Resolution *HOUR;
  static ::org::apache::lucene::document::DateTools$Resolution *MINUTE;
  static ::org::apache::lucene::document::DateTools$Resolution *SECOND;
  static ::org::apache::lucene::document::DateTools$Resolution *MILLISECOND;
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) resolution;

  friend class org_apache_lucene_document_DateTools$Resolution;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_DateTools$Resolution__ */
