// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_Highlighter__
#define __org_apache_lucene_search_highlight_Highlighter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class TokenStream;
          class Analyzer;
        }
        namespace search
        {
          namespace highlight
          {
            class Highlighter;
            class TextFragment;
            class Scorer;
            class Fragmenter;
            class Encoder;
            class Formatter;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::Highlighter : public ::java::lang::Object
{
public:
  Highlighter (::org::apache::lucene::search::highlight::Scorer *);
  Highlighter (::org::apache::lucene::search::highlight::Formatter *, ::org::apache::lucene::search::highlight::Scorer *);
  Highlighter (::org::apache::lucene::search::highlight::Formatter *, ::org::apache::lucene::search::highlight::Encoder *, ::org::apache::lucene::search::highlight::Scorer *);
  ::java::lang::String *getBestFragment (::org::apache::lucene::analysis::Analyzer *, ::java::lang::String *, ::java::lang::String *);
  ::java::lang::String *getBestFragment (::org::apache::lucene::analysis::TokenStream *, ::java::lang::String *);
  JArray< ::java::lang::String *> *getBestFragments (::org::apache::lucene::analysis::Analyzer *, ::java::lang::String *, jint);
  JArray< ::java::lang::String *> *getBestFragments (::org::apache::lucene::analysis::Analyzer *, ::java::lang::String *, ::java::lang::String *, jint);
  JArray< ::java::lang::String *> *getBestFragments (::org::apache::lucene::analysis::TokenStream *, ::java::lang::String *, jint);
  JArray< ::org::apache::lucene::search::highlight::TextFragment *> *getBestTextFragments (::org::apache::lucene::analysis::TokenStream *, ::java::lang::String *, jboolean, jint);
private:
  void mergeContiguousFragments (JArray< ::org::apache::lucene::search::highlight::TextFragment *> *);
public:
  ::java::lang::String *getBestFragments (::org::apache::lucene::analysis::TokenStream *, ::java::lang::String *, jint, ::java::lang::String *);
  virtual jint getMaxDocBytesToAnalyze () { return maxDocBytesToAnalyze; }
  virtual void setMaxDocBytesToAnalyze (jint);
  virtual ::org::apache::lucene::search::highlight::Fragmenter *getTextFragmenter () { return textFragmenter; }
  virtual void setTextFragmenter (::org::apache::lucene::search::highlight::Fragmenter *);
  virtual ::org::apache::lucene::search::highlight::Scorer *getFragmentScorer () { return fragmentScorer; }
  virtual void setFragmentScorer (::org::apache::lucene::search::highlight::Scorer *);
  virtual ::org::apache::lucene::search::highlight::Encoder *getEncoder () { return encoder; }
  virtual void setEncoder (::org::apache::lucene::search::highlight::Encoder *);
  static const jint DEFAULT_MAX_DOC_BYTES_TO_ANALYZE = 51200L;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  maxDocBytesToAnalyze;
  ::org::apache::lucene::search::highlight::Formatter *formatter;
  ::org::apache::lucene::search::highlight::Encoder *encoder;
  ::org::apache::lucene::search::highlight::Fragmenter *textFragmenter;
  ::org::apache::lucene::search::highlight::Scorer *fragmentScorer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_Highlighter__ */
