// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer2__
#define __org_apache_lucene_search_BooleanScorer2__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer2;
          class Explanation;
          class HitCollector;
          class Similarity;
          class Scorer;
          class BooleanScorer2$Coordinator;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer2 : public ::org::apache::lucene::search::Scorer
{
public:
  BooleanScorer2 (::org::apache::lucene::search::Similarity *, jint);
  BooleanScorer2 (::org::apache::lucene::search::Similarity *);
  virtual void add (::org::apache::lucene::search::Scorer *, jboolean, jboolean);
private:
  void initCountingSumScorer ();
  ::org::apache::lucene::search::Scorer *countingDisjunctionSumScorer (::java::util::List *, jint);
  ::org::apache::lucene::search::Scorer *countingConjunctionSumScorer (::java::util::List *);
  ::org::apache::lucene::search::Scorer *dualConjunctionSumScorer (::org::apache::lucene::search::Scorer *, ::org::apache::lucene::search::Scorer *);
  ::org::apache::lucene::search::Scorer *makeCountingSumScorer ();
  ::org::apache::lucene::search::Scorer *makeCountingSumScorerNoReq ();
  ::org::apache::lucene::search::Scorer *makeCountingSumScorerSomeReq ();
  ::org::apache::lucene::search::Scorer *addProhibitedScorers (::org::apache::lucene::search::Scorer *);
public:
  virtual void score (::org::apache::lucene::search::HitCollector *);
public:  // actually protected
  virtual jboolean score (::org::apache::lucene::search::HitCollector *, jint);
public:
  virtual jint doc ();
  virtual jboolean next ();
  virtual jfloat score ();
  virtual jboolean skipTo (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  ::java::util::ArrayList * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) requiredScorers;
  ::java::util::ArrayList *optionalScorers;
  ::java::util::ArrayList *prohibitedScorers;
  ::org::apache::lucene::search::BooleanScorer2$Coordinator *coordinator;
  ::org::apache::lucene::search::Scorer *countingSumScorer;
  jint minNrShouldMatch;
  static ::org::apache::lucene::search::Similarity *defaultSimilarity;

  friend class org_apache_lucene_search_BooleanScorer2$SingleMatchScorer;
  friend class org_apache_lucene_search_BooleanScorer2$Coordinator;
  friend class org_apache_lucene_search_BooleanScorer2$1;
  friend class org_apache_lucene_search_BooleanScorer2$2;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer2__ */
