// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer2$Coordinator__
#define __org_apache_lucene_search_BooleanScorer2$Coordinator__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer2$Coordinator;
          class BooleanScorer2;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer2$Coordinator : public ::java::lang::Object
{
private:
  BooleanScorer2$Coordinator (::org::apache::lucene::search::BooleanScorer2 *);
public: // actually package-private
  virtual void init ();
  virtual void initDoc ();
  virtual jfloat coordFactor ();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  maxCoord;
private:
  jfloatArray coordFactors;
public: // actually package-private
  jint nrMatchers;
private:
  ::org::apache::lucene::search::BooleanScorer2 *this$0;

  friend class org_apache_lucene_search_BooleanScorer2$Coordinator;
  friend class org_apache_lucene_search_BooleanScorer2$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer2$Coordinator__ */
