// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_PrefixFilter$1__
#define __org_apache_lucene_search_PrefixFilter$1__

#pragma interface

#include <org/apache/lucene/search/PrefixGenerator.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Term;
        }
        namespace search
        {
          class PrefixFilter$1;
          class PrefixFilter;
        }
      }
    }
  }
}

class org::apache::lucene::search::PrefixFilter$1 : public ::org::apache::lucene::search::PrefixGenerator
{
public: // actually package-private
  PrefixFilter$1 (::org::apache::lucene::search::PrefixFilter *, ::org::apache::lucene::index::Term *, ::java::util::BitSet *);
public:
  virtual void handleDoc (jint);
private:
  ::java::util::BitSet * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::PrefixGenerator )))) val$bitSet;
  ::org::apache::lucene::search::PrefixFilter *this$0;

  friend class org_apache_lucene_search_PrefixFilter$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_PrefixFilter$1__ */
