// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_DisjunctionSumScorer__
#define __org_apache_lucene_search_DisjunctionSumScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class DisjunctionSumScorer;
          class Explanation;
          class HitCollector;
        }
        namespace util
        {
          class ScorerDocQueue;
        }
      }
    }
  }
}

class org::apache::lucene::search::DisjunctionSumScorer : public ::org::apache::lucene::search::Scorer
{
public:
  DisjunctionSumScorer (::java::util::List *, jint);
  DisjunctionSumScorer (::java::util::List *);
private:
  void initScorerDocQueue ();
public:
  virtual void score (::org::apache::lucene::search::HitCollector *);
public:  // actually protected
  virtual jboolean score (::org::apache::lucene::search::HitCollector *, jint);
public:
  virtual jboolean next ();
public:  // actually protected
  virtual jboolean advanceAfterCurrent ();
public:
  virtual jfloat score () { return currentScore; }
  virtual jint doc () { return currentDoc; }
  virtual jint nrMatchers () { return nrMatchers__; }
  virtual jboolean skipTo (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  jint __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer ))))  nrScorers;
public:  // actually protected
  ::java::util::List *subScorers;
private:
  jint minimumNrMatchers;
  ::org::apache::lucene::util::ScorerDocQueue *scorerDocQueue;
  jint queueSize;
  jint currentDoc;
public:  // actually protected
  jint nrMatchers__;
private:
  jfloat currentScore;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_DisjunctionSumScorer__ */
