// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_WildcardQuery__
#define __org_apache_lucene_search_WildcardQuery__

#pragma interface

#include <org/apache/lucene/search/MultiTermQuery.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class WildcardQuery;
          class Query;
          class FilteredTermEnum;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::WildcardQuery : public ::org::apache::lucene::search::MultiTermQuery
{
public:
  WildcardQuery (::org::apache::lucene::index::Term *);
public:  // actually protected
  virtual ::org::apache::lucene::search::FilteredTermEnum *getEnum (::org::apache::lucene::index::IndexReader *);
public:
  virtual jboolean equals (::java::lang::Object *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
private:
  jboolean __attribute__((aligned(__alignof__( ::org::apache::lucene::search::MultiTermQuery ))))  termContainsWildcard;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_WildcardQuery__ */
