// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __net_sf_snowball_ext_DutchStemmer__
#define __net_sf_snowball_ext_DutchStemmer__

#pragma interface

#include <net/sf/snowball/SnowballProgram.h>
#include <gcj/array.h>

extern "Java"
{
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        namespace ext
        {
          class DutchStemmer;
        }
        class Among;
      }
    }
  }
}

class net::sf::snowball::ext::DutchStemmer : public ::net::sf::snowball::SnowballProgram
{
public:
  DutchStemmer ();
private:
  void copy_from (::net::sf::snowball::ext::DutchStemmer *);
  jboolean r_prelude ();
  jboolean r_mark_regions ();
  jboolean r_postlude ();
  jboolean r_R1 ();
  jboolean r_R2 ();
  jboolean r_undouble ();
  jboolean r_e_ending ();
  jboolean r_en_ending ();
  jboolean r_standard_suffix ();
public:
  virtual jboolean stem ();
private:
  JArray< ::net::sf::snowball::Among *> * __attribute__((aligned(__alignof__( ::net::sf::snowball::SnowballProgram )))) a_0;
  JArray< ::net::sf::snowball::Among *> *a_1;
  JArray< ::net::sf::snowball::Among *> *a_2;
  JArray< ::net::sf::snowball::Among *> *a_3;
  JArray< ::net::sf::snowball::Among *> *a_4;
  JArray< ::net::sf::snowball::Among *> *a_5;
  static jcharArray g_v;
  static jcharArray g_v_I;
  static jcharArray g_v_j;
  jint I_p2;
  jint I_p1;
  jboolean B_e_found;
public:

  static ::java::lang::Class class$;
};

#endif /* __net_sf_snowball_ext_DutchStemmer__ */
