// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer$BucketTable__
#define __org_apache_lucene_search_BooleanScorer$BucketTable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer$BucketTable;
          class HitCollector;
          class BooleanScorer;
          class BooleanScorer$Bucket;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer$BucketTable : public ::java::lang::Object
{
public:
  BooleanScorer$BucketTable (::org::apache::lucene::search::BooleanScorer *);
  jint size ();
  ::org::apache::lucene::search::HitCollector *newCollector (jint);
  static const jint SIZE = 2048L;
  static const jint MASK = 2047L;
public: // actually package-private
  JArray< ::org::apache::lucene::search::BooleanScorer$Bucket *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) buckets;
  ::org::apache::lucene::search::BooleanScorer$Bucket *first;
private:
  ::org::apache::lucene::search::BooleanScorer *scorer;

  friend class org_apache_lucene_search_BooleanScorer$Bucket;
  friend class org_apache_lucene_search_BooleanScorer$BucketTable;
  friend class org_apache_lucene_search_BooleanScorer$Collector;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer$BucketTable__ */
