// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermInfo__
#define __org_apache_lucene_index_TermInfo__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermInfo : public ::java::lang::Object
{
public: // actually package-private
  TermInfo ();
  TermInfo (jint, jlong, jlong);
  TermInfo (::org::apache::lucene::index::TermInfo *);
  void set (jint, jlong, jlong, jint);
  void set (::org::apache::lucene::index::TermInfo *);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  docFreq;
  jlong freqPointer;
  jlong proxPointer;
  jint skipOffset;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermInfo__ */
