// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_Document__
#define __org_apache_lucene_document_Document__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Document;
          class Field;
          class Fieldable;
        }
      }
    }
  }
}

class org::apache::lucene::document::Document : public ::java::lang::Object
{
public:
  Document ();
  void setBoost (jfloat);
  jfloat getBoost () { return boost; }
  void add (::org::apache::lucene::document::Fieldable *);
  void removeField (::java::lang::String *);
  void removeFields (::java::lang::String *);
  ::org::apache::lucene::document::Field *getField (::java::lang::String *);
  ::org::apache::lucene::document::Fieldable *getFieldable (::java::lang::String *);
  ::java::lang::String *get (::java::lang::String *);
  ::java::util::Enumeration *fields ();
  ::java::util::List *getFields () { return fields__; }
  JArray< ::org::apache::lucene::document::Field *> *getFields (::java::lang::String *);
  JArray< ::org::apache::lucene::document::Fieldable *> *getFieldables (::java::lang::String *);
  JArray< ::java::lang::String *> *getValues (::java::lang::String *);
  JArray<jbyteArray> * getBinaryValues (::java::lang::String *);
  jbyteArray getBinaryValue (::java::lang::String *);
  ::java::lang::String *toString ();
public: // actually package-private
  ::java::util::List * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fields__;
private:
  jfloat boost;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_Document__ */
