// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FilterIndexReader$FilterTermPositions__
#define __org_apache_lucene_index_FilterIndexReader$FilterTermPositions__

#pragma interface

#include <org/apache/lucene/index/FilterIndexReader$FilterTermDocs.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class FilterIndexReader$FilterTermPositions;
          class TermPositions;
        }
      }
    }
  }
}

class org::apache::lucene::index::FilterIndexReader$FilterTermPositions : public ::org::apache::lucene::index::FilterIndexReader$FilterTermDocs
{
public:
  FilterIndexReader$FilterTermPositions (::org::apache::lucene::index::TermPositions *);
  virtual jint nextPosition ();

  friend class org_apache_lucene_index_FilterIndexReader$FilterTermPositions;
  friend class org_apache_lucene_index_FilterIndexReader$FilterTermDocs;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FilterIndexReader$FilterTermPositions__ */
