// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentTermVector__
#define __org_apache_lucene_index_SegmentTermVector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentTermVector;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentTermVector : public ::java::lang::Object
{
public: // actually package-private
  SegmentTermVector (::java::lang::String *, JArray< ::java::lang::String *> *, jintArray);
public:
  virtual ::java::lang::String *getField () { return field; }
  virtual ::java::lang::String *toString ();
  virtual jint size ();
  virtual JArray< ::java::lang::String *> *getTerms () { return terms; }
  virtual jintArray getTermFrequencies () { return termFreqs; }
  virtual jint indexOf (::java::lang::String *);
  virtual jintArray indexesOf (JArray< ::java::lang::String *> *, jint, jint);
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) field;
  JArray< ::java::lang::String *> *terms;
  jintArray termFreqs;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentTermVector__ */
