// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_ru_RussianStemFilter__
#define __org_apache_lucene_analysis_ru_RussianStemFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class TokenStream;
          namespace ru
          {
            class RussianStemFilter;
            class RussianStemmer;
          }
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::ru::RussianStemFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  RussianStemFilter (::org::apache::lucene::analysis::TokenStream *, jcharArray);
  ::org::apache::lucene::analysis::Token *next ();
  void setStemmer (::org::apache::lucene::analysis::ru::RussianStemmer *);
private:
  ::org::apache::lucene::analysis::Token * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter )))) token;
  ::org::apache::lucene::analysis::ru::RussianStemmer *stemmer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_ru_RussianStemFilter__ */
