// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_standard_StandardTokenizer__
#define __org_apache_lucene_analysis_standard_StandardTokenizer__

#pragma interface

#include <org/apache/lucene/analysis/Tokenizer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class Token;
          namespace standard
          {
            class StandardTokenizer;
            class ParseException;
            class CharStream;
            class Token;
            class StandardTokenizerTokenManager;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::standard::StandardTokenizer : public ::org::apache::lucene::analysis::Tokenizer
{
public:
  StandardTokenizer (::java::io::Reader *);
  ::org::apache::lucene::analysis::Token *next ();
private:
  static void jj_la1_0_mth ();
public:
  StandardTokenizer (::org::apache::lucene::analysis::standard::CharStream *);
  virtual void ReInit (::org::apache::lucene::analysis::standard::CharStream *);
  StandardTokenizer (::org::apache::lucene::analysis::standard::StandardTokenizerTokenManager *);
  virtual void ReInit (::org::apache::lucene::analysis::standard::StandardTokenizerTokenManager *);
private:
  ::org::apache::lucene::analysis::standard::Token *jj_consume_token (jint);
public:
  ::org::apache::lucene::analysis::standard::Token *getNextToken ();
  ::org::apache::lucene::analysis::standard::Token *getToken (jint);
private:
  jint jj_ntk ();
public:
  virtual ::org::apache::lucene::analysis::standard::ParseException *generateParseException ();
  void enable_tracing () { }
  void disable_tracing () { }
  ::org::apache::lucene::analysis::standard::StandardTokenizerTokenManager * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Tokenizer )))) token_source;
  ::org::apache::lucene::analysis::standard::Token *token;
  ::org::apache::lucene::analysis::standard::Token *jj_nt;
private:
  jint jj_ntk__;
  jint jj_gen;
  jintArray jj_la1;
  static jintArray jj_la1_0;
  ::java::util::Vector *jj_expentries;
  jintArray jj_expentry;
  jint jj_kind;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_standard_StandardTokenizer__ */
