// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_DateTools__
#define __org_apache_lucene_document_DateTools__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class DateTools;
          class DateTools$Resolution;
        }
      }
    }
  }
  namespace java
  {
    namespace text
    {
      class SimpleDateFormat;
    }
  }
}

class org::apache::lucene::document::DateTools : public ::java::lang::Object
{
private:
  DateTools ();
public:
  static ::java::lang::String *dateToString (::java::util::Date *, ::org::apache::lucene::document::DateTools$Resolution *);
  static ::java::lang::String *timeToString (jlong, ::org::apache::lucene::document::DateTools$Resolution *);
  static jlong stringToTime (::java::lang::String *);
  static ::java::util::Date *stringToDate (::java::lang::String *);
  static ::java::util::Date *round (::java::util::Date *, ::org::apache::lucene::document::DateTools$Resolution *);
  static jlong round (jlong, ::org::apache::lucene::document::DateTools$Resolution *);
private:
  static ::java::util::TimeZone *GMT;
  static ::java::text::SimpleDateFormat *YEAR_FORMAT;
  static ::java::text::SimpleDateFormat *MONTH_FORMAT;
  static ::java::text::SimpleDateFormat *DAY_FORMAT;
  static ::java::text::SimpleDateFormat *HOUR_FORMAT;
  static ::java::text::SimpleDateFormat *MINUTE_FORMAT;
  static ::java::text::SimpleDateFormat *SECOND_FORMAT;
  static ::java::text::SimpleDateFormat *MILLISECOND_FORMAT;

  friend class org_apache_lucene_document_DateTools$Resolution;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_DateTools__ */
