// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_MultiTermPositions__
#define __org_apache_lucene_index_MultiTermPositions__

#pragma interface

#include <org/apache/lucene/index/MultiTermDocs.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class MultiTermPositions;
          class TermDocs;
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::index::MultiTermPositions : public ::org::apache::lucene::index::MultiTermDocs
{
public:
  MultiTermPositions (JArray< ::org::apache::lucene::index::IndexReader *> *, jintArray);
public:  // actually protected
  virtual ::org::apache::lucene::index::TermDocs *termDocs (::org::apache::lucene::index::IndexReader *);
public:
  virtual jint nextPosition ();

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_MultiTermPositions__ */
