// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_DateField__
#define __org_apache_lucene_document_DateField__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class DateField;
        }
      }
    }
  }
}

class org::apache::lucene::document::DateField : public ::java::lang::Object
{
private:
  DateField ();
public:
  static ::java::lang::String *MIN_DATE_STRING ();
  static ::java::lang::String *MAX_DATE_STRING ();
  static ::java::lang::String *dateToString (::java::util::Date *);
  static ::java::lang::String *timeToString (jlong);
  static jlong stringToTime (::java::lang::String *);
  static ::java::util::Date *stringToDate (::java::lang::String *);
private:
  static jint DATE_LEN;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_DateField__ */
