// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermVectorsWriter$TVField__
#define __org_apache_lucene_index_TermVectorsWriter$TVField__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermVectorsWriter$TVField;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermVectorsWriter$TVField : public ::java::lang::Object
{
public: // actually package-private
  TermVectorsWriter$TVField (jint, jboolean, jboolean);
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  number;
  jlong tvfPointer;
  jboolean storePositions;
  jboolean storeOffsets;

  friend class org_apache_lucene_index_TermVectorsWriter$TVField;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermVectorsWriter$TVField__ */
