// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ParallelMultiSearcher__
#define __org_apache_lucene_search_ParallelMultiSearcher__

#pragma interface

#include <org/apache/lucene/search/MultiSearcher.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Term;
        }
        namespace search
        {
          class ParallelMultiSearcher;
          class Query;
          class HitCollector;
          class TopFieldDocs;
          class Sort;
          class TopDocs;
          class Filter;
          class Weight;
          class Searchable;
        }
      }
    }
  }
}

class org::apache::lucene::search::ParallelMultiSearcher : public ::org::apache::lucene::search::MultiSearcher
{
public:
  ParallelMultiSearcher (JArray< ::org::apache::lucene::search::Searchable *> *);
  virtual jint docFreq (::org::apache::lucene::index::Term *);
  virtual ::org::apache::lucene::search::TopDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint);
  virtual ::org::apache::lucene::search::TopFieldDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::Sort *);
  virtual void search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::HitCollector *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::search::Query *);
private:
  JArray< ::org::apache::lucene::search::Searchable *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::MultiSearcher )))) searchables;
  jintArray starts;

  friend class org_apache_lucene_search_ParallelMultiSearcher$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ParallelMultiSearcher__ */
