// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentMergeQueue__
#define __org_apache_lucene_index_SegmentMergeQueue__

#pragma interface

#include <org/apache/lucene/util/PriorityQueue.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentMergeQueue;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentMergeQueue : public ::org::apache::lucene::util::PriorityQueue
{
public: // actually package-private
  SegmentMergeQueue (jint);
public:  // actually protected
  jboolean lessThan (::java::lang::Object *, ::java::lang::Object *);
public: // actually package-private
  void close ();
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentMergeQueue__ */
