// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_MultiSearcher$CachedDfSource__
#define __org_apache_lucene_search_MultiSearcher$CachedDfSource__

#pragma interface

#include <org/apache/lucene/search/Searcher.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Document;
        }
        namespace search
        {
          class MultiSearcher$CachedDfSource;
          class TopFieldDocs;
          class Sort;
          class TopDocs;
          class HitCollector;
          class Filter;
          class Explanation;
          class Weight;
          class Query;
        }
        namespace index
        {
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::MultiSearcher$CachedDfSource : public ::org::apache::lucene::search::Searcher
{
public:
  MultiSearcher$CachedDfSource (::java::util::Map *, jint);
  virtual jint docFreq (::org::apache::lucene::index::Term *);
  virtual jintArray docFreqs (JArray< ::org::apache::lucene::index::Term *> *);
  virtual jint maxDoc () { return maxDoc__; }
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::search::Query *);
  virtual void close ();
  virtual ::org::apache::lucene::document::Document *doc (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::search::Weight *, jint);
  virtual void search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, ::org::apache::lucene::search::HitCollector *);
  virtual ::org::apache::lucene::search::TopDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint);
  virtual ::org::apache::lucene::search::TopFieldDocs *search (::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Filter *, jint, ::org::apache::lucene::search::Sort *);
private:
  ::java::util::Map * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Searcher )))) dfMap;
  jint maxDoc__;

  friend class org_apache_lucene_search_MultiSearcher$CachedDfSource;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_MultiSearcher$CachedDfSource__ */
