// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_NearSpansUnordered__
#define __org_apache_lucene_search_spans_NearSpansUnordered__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          namespace spans
          {
            class NearSpansUnordered;
            class NearSpansUnordered$CellQueue;
            class NearSpansUnordered$SpansCell;
            class SpanNearQuery;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::NearSpansUnordered : public ::java::lang::Object
{
public:
  NearSpansUnordered (::org::apache::lucene::search::spans::SpanNearQuery *, ::org::apache::lucene::index::IndexReader *);
  virtual jboolean next ();
  virtual jboolean skipTo (jint);
private:
  ::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *min ();
public:
  virtual jint doc ();
  virtual jint start ();
  virtual jint end ();
  virtual ::java::lang::String *toString ();
private:
  void initList (jboolean);
  void addToList (::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *);
  void firstToLast ();
  void queueToList ();
  void listToQueue ();
  jboolean atMatch ();
  ::org::apache::lucene::search::spans::SpanNearQuery * __attribute__((aligned(__alignof__( ::java::lang::Object )))) query;
  ::java::util::List *ordered;
  jint slop;
  ::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *first;
  ::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *last;
  jint totalLength;
  ::org::apache::lucene::search::spans::NearSpansUnordered$CellQueue *queue;
  ::org::apache::lucene::search::spans::NearSpansUnordered$SpansCell *max;
  jboolean more;
  jboolean firstTime;

  friend class org_apache_lucene_search_spans_NearSpansUnordered$SpansCell;
  friend class org_apache_lucene_search_spans_NearSpansUnordered$CellQueue;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_NearSpansUnordered__ */
