// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_IndexFileNames__
#define __org_apache_lucene_index_IndexFileNames__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexFileNames;
        }
      }
    }
  }
}

class org::apache::lucene::index::IndexFileNames : public ::java::lang::Object
{
public: // actually package-private
  IndexFileNames ();
public:
  static ::java::lang::String *fileNameFromGeneration (::java::lang::String *, ::java::lang::String *, jlong);
public: // actually package-private
  static ::java::lang::String *SEGMENTS;
  static ::java::lang::String *SEGMENTS_GEN;
  static ::java::lang::String *DELETABLE;
  static JArray< ::java::lang::String *> *INDEX_EXTENSIONS;
  static JArray< ::java::lang::String *> *COMPOUND_EXTENSIONS;
  static JArray< ::java::lang::String *> *VECTOR_EXTENSIONS;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_IndexFileNames__ */
