// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_ScorerDocQueue$HeapedScorerDoc__
#define __org_apache_lucene_util_ScorerDocQueue$HeapedScorerDoc__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class ScorerDocQueue$HeapedScorerDoc;
          class ScorerDocQueue;
        }
        namespace search
        {
          class Scorer;
        }
      }
    }
  }
}

class org::apache::lucene::util::ScorerDocQueue$HeapedScorerDoc : public ::java::lang::Object
{
public: // actually package-private
  ScorerDocQueue$HeapedScorerDoc (::org::apache::lucene::util::ScorerDocQueue *, ::org::apache::lucene::search::Scorer *);
  ScorerDocQueue$HeapedScorerDoc (::org::apache::lucene::util::ScorerDocQueue *, ::org::apache::lucene::search::Scorer *, jint);
  virtual void adjust ();
  ::org::apache::lucene::search::Scorer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) scorer;
  jint doc;
private:
  ::org::apache::lucene::util::ScorerDocQueue *this$0;

  friend class org_apache_lucene_util_ScorerDocQueue$HeapedScorerDoc;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_ScorerDocQueue$HeapedScorerDoc__ */
