// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_HitIterator__
#define __org_apache_lucene_search_HitIterator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class HitIterator;
          class Hits;
        }
      }
    }
  }
}

class org::apache::lucene::search::HitIterator : public ::java::lang::Object
{
public: // actually package-private
  HitIterator (::org::apache::lucene::search::Hits *);
public:
  virtual jboolean hasNext ();
  virtual ::java::lang::Object *next ();
  virtual void remove ();
  virtual jint length ();
private:
  ::org::apache::lucene::search::Hits * __attribute__((aligned(__alignof__( ::java::lang::Object )))) hits;
  jint hitNumber;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_HitIterator__ */
