// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer$Bucket__
#define __org_apache_lucene_search_BooleanScorer$Bucket__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer$Bucket;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer$Bucket : public ::java::lang::Object
{
public: // actually package-private
  BooleanScorer$Bucket ();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  doc;
  jfloat score;
  jint bits;
  jint coord;
  ::org::apache::lucene::search::BooleanScorer$Bucket *next;

  friend class org_apache_lucene_search_BooleanScorer$Bucket;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer$Bucket__ */
