// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldCache$StringIndex__
#define __org_apache_lucene_search_FieldCache$StringIndex__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldCache$StringIndex;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldCache$StringIndex : public ::java::lang::Object
{
public:
  FieldCache$StringIndex (jintArray, JArray< ::java::lang::String *> *);
  JArray< ::java::lang::String *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) lookup;
  jintArray order;

  friend class org_apache_lucene_search_FieldCache$StringIndex;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldCache$StringIndex__ */
