// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_Constants__
#define __org_apache_lucene_util_Constants__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class Constants;
        }
      }
    }
  }
}

class org::apache::lucene::util::Constants : public ::java::lang::Object
{
private:
  Constants ();
public:
  static ::java::lang::String *JAVA_VERSION;
  static jboolean JAVA_1_1;
  static jboolean JAVA_1_2;
  static jboolean JAVA_1_3;
  static ::java::lang::String *OS_NAME;
  static jboolean LINUX;
  static jboolean WINDOWS;
  static jboolean SUN_OS;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_Constants__ */
