// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_WildcardTermEnum__
#define __org_apache_lucene_search_WildcardTermEnum__

#pragma interface

#include <org/apache/lucene/search/FilteredTermEnum.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class WildcardTermEnum;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::WildcardTermEnum : public ::org::apache::lucene::search::FilteredTermEnum
{
public:
  WildcardTermEnum (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::index::Term *);
public:  // actually protected
  jboolean termCompare (::org::apache::lucene::index::Term *);
public:
  jfloat difference ();
  jboolean endEnum () { return endEnum__; }
  static jboolean wildcardEquals (::java::lang::String *, jint, ::java::lang::String *, jint);
  virtual void close ();
public: // actually package-private
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::FilteredTermEnum )))) searchTerm;
  ::java::lang::String *field;
  ::java::lang::String *text;
  ::java::lang::String *pre;
  jint preLen;
  jboolean endEnum__;
public:
  static const jint WILDCARD_STRING = 42L;
  static const jint WILDCARD_CHAR = 63L;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_WildcardTermEnum__ */
