// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Query__
#define __org_apache_lucene_search_Query__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class Similarity;
          class Query;
          class Weight;
          class Searcher;
        }
      }
    }
  }
}

class org::apache::lucene::search::Query : public ::java::lang::Object
{
public:
  Query ();
  virtual void setBoost (jfloat);
  virtual jfloat getBoost () { return boost; }
  virtual ::java::lang::String *toString (::java::lang::String *) = 0;
  virtual ::java::lang::String *toString ();
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Searcher *);
public:
  virtual ::org::apache::lucene::search::Weight *weight (::org::apache::lucene::search::Searcher *);
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *) { return this; }
  virtual ::org::apache::lucene::search::Query *combine (JArray< ::org::apache::lucene::search::Query *> *);
  virtual void extractTerms (::java::util::Set *);
  static ::org::apache::lucene::search::Query *mergeBooleanQueries (JArray< ::org::apache::lucene::search::Query *> *);
  virtual ::org::apache::lucene::search::Similarity *getSimilarity (::org::apache::lucene::search::Searcher *);
  virtual ::java::lang::Object *clone ();
private:
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  boost;

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Query__ */
