// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_db_DbLock__
#define __org_apache_lucene_store_db_DbLock__

#pragma interface

#include <org/apache/lucene/store/Lock.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          namespace db
          {
            class DbLock;
          }
        }
      }
    }
  }
}

class org::apache::lucene::store::db::DbLock : public ::org::apache::lucene::store::Lock
{
public:
  DbLock ();
  virtual jboolean obtain ();
  virtual void release ();
  virtual jboolean isLocked () { return isLocked__; }
public: // actually package-private
  jboolean __attribute__((aligned(__alignof__( ::org::apache::lucene::store::Lock ))))  isLocked__;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_db_DbLock__ */
