// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanQuery__
#define __org_apache_lucene_search_BooleanQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class BooleanQuery;
          class Weight;
          class BooleanClause;
          class BooleanClause$Occur;
          class Query;
          class Similarity;
          class Searcher;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanQuery : public ::org::apache::lucene::search::Query
{
public:
  static jint getMaxClauseCount ();
  static void setMaxClauseCount (jint);
  BooleanQuery ();
  BooleanQuery (jboolean);
  virtual jboolean isCoordDisabled () { return disableCoord; }
  virtual ::org::apache::lucene::search::Similarity *getSimilarity (::org::apache::lucene::search::Searcher *);
  virtual void setMinimumNumberShouldMatch (jint);
  virtual jint getMinimumNumberShouldMatch () { return minNrShouldMatch; }
  virtual void add (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::BooleanClause$Occur *);
  virtual void add (::org::apache::lucene::search::BooleanClause *);
  virtual JArray< ::org::apache::lucene::search::BooleanClause *> *getClauses ();
  static void setUseScorer14 (jboolean);
  static jboolean getUseScorer14 ();
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Searcher *);
public:
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
  virtual void extractTerms (::java::util::Set *);
  virtual ::java::lang::Object *clone ();
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  static jint maxClauseCount;
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Query )))) clauses;
  jboolean disableCoord;
public:  // actually protected
  jint minNrShouldMatch;
private:
  static jboolean useScorer14;

  friend class org_apache_lucene_search_BooleanQuery$BooleanWeight2;
  friend class org_apache_lucene_search_BooleanQuery$BooleanWeight;
  friend class org_apache_lucene_search_BooleanQuery$TooManyClauses;
  friend class org_apache_lucene_search_BooleanClause$Occur;
  friend class org_apache_lucene_search_BooleanQuery$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanQuery__ */
