// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __net_sf_snowball_TestApp__
#define __net_sf_snowball_TestApp__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        class TestApp;
      }
    }
  }
}

class net::sf::snowball::TestApp : public ::java::lang::Object
{
public:
  TestApp ();
  static void main (JArray< ::java::lang::String *> *);
private:
  static void exitWithUsage ();
public:

  static ::java::lang::Class class$;
};

#endif /* __net_sf_snowball_TestApp__ */
