// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_util_PriorityQueue__
#define __org_apache_lucene_util_PriorityQueue__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace util
        {
          class PriorityQueue;
        }
      }
    }
  }
}

class org::apache::lucene::util::PriorityQueue : public ::java::lang::Object
{
public:
  PriorityQueue ();
public:  // actually protected
  virtual jboolean lessThan (::java::lang::Object *, ::java::lang::Object *) = 0;
  void initialize (jint);
public:
  void put (::java::lang::Object *);
  virtual jboolean insert (::java::lang::Object *);
  ::java::lang::Object *top ();
  ::java::lang::Object *pop ();
  void adjustTop ();
  jint size () { return size__; }
  void clear ();
private:
  void upHeap ();
  void downHeap ();
  JArray< ::java::lang::Object *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) heap;
  jint size__;
  jint maxSize;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_util_PriorityQueue__ */
