// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FilterIndexReader$FilterTermEnum__
#define __org_apache_lucene_index_FilterIndexReader$FilterTermEnum__

#pragma interface

#include <org/apache/lucene/index/TermEnum.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class FilterIndexReader$FilterTermEnum;
          class Term;
          class TermEnum;
        }
      }
    }
  }
}

class org::apache::lucene::index::FilterIndexReader$FilterTermEnum : public ::org::apache::lucene::index::TermEnum
{
public:
  FilterIndexReader$FilterTermEnum (::org::apache::lucene::index::TermEnum *);
  virtual jboolean next ();
  virtual ::org::apache::lucene::index::Term *term ();
  virtual jint docFreq ();
  virtual void close ();
public:  // actually protected
  ::org::apache::lucene::index::TermEnum * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::TermEnum )))) in;

  friend class org_apache_lucene_index_FilterIndexReader$FilterTermEnum;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FilterIndexReader$FilterTermEnum__ */
