// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_TokenSources__
#define __org_apache_lucene_search_highlight_TokenSources__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class TokenSources;
          }
        }
        namespace analysis
        {
          class TokenStream;
          class Analyzer;
        }
        namespace index
        {
          class TermPositionVector;
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::TokenSources : public ::java::lang::Object
{
public:
  TokenSources ();
  static ::org::apache::lucene::analysis::TokenStream *getAnyTokenStream (::org::apache::lucene::index::IndexReader *, jint, ::java::lang::String *, ::org::apache::lucene::analysis::Analyzer *);
  static ::org::apache::lucene::analysis::TokenStream *getTokenStream (::org::apache::lucene::index::TermPositionVector *);
  static ::org::apache::lucene::analysis::TokenStream *getTokenStream (::org::apache::lucene::index::TermPositionVector *, jboolean);
  static ::org::apache::lucene::analysis::TokenStream *getTokenStream (::org::apache::lucene::index::IndexReader *, jint, ::java::lang::String *);
  static ::org::apache::lucene::analysis::TokenStream *getTokenStream (::org::apache::lucene::index::IndexReader *, jint, ::java::lang::String *, ::org::apache::lucene::analysis::Analyzer *);

  friend class org_apache_lucene_search_highlight_TokenSources$1;
  friend class org_apache_lucene_search_highlight_TokenSources$1StoredTokenStream;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_TokenSources__ */
