// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ConstantScoreRangeQuery__
#define __org_apache_lucene_search_ConstantScoreRangeQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ConstantScoreRangeQuery;
          class Query;
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::ConstantScoreRangeQuery : public ::org::apache::lucene::search::Query
{
public:
  ConstantScoreRangeQuery (::java::lang::String *, ::java::lang::String *, ::java::lang::String *, jboolean, jboolean);
  virtual ::java::lang::String *getField () { return fieldName; }
  virtual ::java::lang::String *getLowerVal () { return lowerVal; }
  virtual ::java::lang::String *getUpperVal () { return upperVal; }
  virtual jboolean includesLower () { return includeLower; }
  virtual jboolean includesUpper () { return includeUpper; }
  virtual ::org::apache::lucene::search::Query *rewrite (::org::apache::lucene::index::IndexReader *);
  virtual ::java::lang::String *toString (::java::lang::String *);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Query )))) fieldName;
  ::java::lang::String *lowerVal;
  ::java::lang::String *upperVal;
  jboolean includeLower;
  jboolean includeUpper;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ConstantScoreRangeQuery__ */
