// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_ru_RussianLowerCaseFilter__
#define __org_apache_lucene_analysis_ru_RussianLowerCaseFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace ru
          {
            class RussianLowerCaseFilter;
          }
          class Token;
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::ru::RussianLowerCaseFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  RussianLowerCaseFilter (::org::apache::lucene::analysis::TokenStream *, jcharArray);
  ::org::apache::lucene::analysis::Token *next ();
public: // actually package-private
  jcharArray __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter ))))  charset;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_ru_RussianLowerCaseFilter__ */
