// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_SpanFirstQuery$1__
#define __org_apache_lucene_search_spans_SpanFirstQuery$1__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          namespace spans
          {
            class SpanFirstQuery$1;
            class SpanFirstQuery;
            class Spans;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::SpanFirstQuery$1 : public ::java::lang::Object
{
public: // actually package-private
  SpanFirstQuery$1 (::org::apache::lucene::search::spans::SpanFirstQuery *, ::org::apache::lucene::index::IndexReader *);
public:
  virtual jboolean next ();
  virtual jboolean skipTo (jint);
  virtual jint doc ();
  virtual jint start ();
  virtual jint end ();
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::search::spans::Spans * __attribute__((aligned(__alignof__( ::java::lang::Object )))) spans;
  ::org::apache::lucene::index::IndexReader *val$reader;
  ::org::apache::lucene::search::spans::SpanFirstQuery *this$0;

  friend class org_apache_lucene_search_spans_SpanFirstQuery$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_SpanFirstQuery$1__ */
