// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_regex_RegexTermEnum__
#define __org_apache_lucene_search_regex_RegexTermEnum__

#pragma interface

#include <org/apache/lucene/search/FilteredTermEnum.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Term;
          class IndexReader;
        }
        namespace search
        {
          namespace regex
          {
            class RegexTermEnum;
            class RegexCapabilities;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::regex::RegexTermEnum : public ::org::apache::lucene::search::FilteredTermEnum
{
public:
  RegexTermEnum (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::index::Term *, ::org::apache::lucene::search::regex::RegexCapabilities *);
public:  // actually protected
  jboolean termCompare (::org::apache::lucene::index::Term *);
public:
  jfloat difference ();
  jboolean endEnum () { return endEnum__; }
  virtual void close ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::FilteredTermEnum )))) field;
  ::java::lang::String *pre;
  jboolean endEnum__;
  ::org::apache::lucene::search::regex::RegexCapabilities *regexImpl;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_regex_RegexTermEnum__ */
