// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentReader$Norm__
#define __org_apache_lucene_index_SegmentReader$Norm__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentReader$Norm;
          class SegmentInfo;
          class SegmentReader;
        }
        namespace store
        {
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentReader$Norm : public ::java::lang::Object
{
public:
  SegmentReader$Norm (::org::apache::lucene::index::SegmentReader *, ::org::apache::lucene::store::IndexInput *, jint);
private:
  void reWrite (::org::apache::lucene::index::SegmentInfo *);
  ::org::apache::lucene::store::IndexInput * __attribute__((aligned(__alignof__( ::java::lang::Object )))) in;
  jbyteArray bytes;
  jboolean dirty;
  jint number;
  ::org::apache::lucene::index::SegmentReader *this$0;

  friend class org_apache_lucene_index_SegmentReader$Norm;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentReader$Norm__ */
