// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_TokenFilter__
#define __org_apache_lucene_analysis_TokenFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenStream.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class TokenFilter;
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::TokenFilter : public ::org::apache::lucene::analysis::TokenStream
{
public:  // actually protected
  TokenFilter (::org::apache::lucene::analysis::TokenStream *);
public:
  virtual void close ();
public:  // actually protected
  ::org::apache::lucene::analysis::TokenStream * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenStream )))) input;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_TokenFilter__ */
