// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_similar_SimilarityQueries__
#define __org_apache_lucene_search_similar_SimilarityQueries__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace similar
          {
            class SimilarityQueries;
          }
          class Query;
        }
        namespace analysis
        {
          class Analyzer;
        }
      }
    }
  }
}

class org::apache::lucene::search::similar::SimilarityQueries : public ::java::lang::Object
{
private:
  SimilarityQueries ();
public:
  static ::org::apache::lucene::search::Query *formSimilarQuery (::java::lang::String *, ::org::apache::lucene::analysis::Analyzer *, ::java::lang::String *, ::java::util::Set *);

  friend class org_apache_lucene_search_BooleanQuery$TooManyClauses;
  friend class org_apache_lucene_search_BooleanClause$Occur;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_similar_SimilarityQueries__ */
