// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Sort__
#define __org_apache_lucene_search_Sort__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class SortField;
          class Sort;
        }
      }
    }
  }
}

class org::apache::lucene::search::Sort : public ::java::lang::Object
{
public:
  Sort ();
  Sort (::java::lang::String *);
  Sort (::java::lang::String *, jboolean);
  Sort (JArray< ::java::lang::String *> *);
  Sort (::org::apache::lucene::search::SortField *);
  Sort (JArray< ::org::apache::lucene::search::SortField *> *);
  void setSort (::java::lang::String *);
  virtual void setSort (::java::lang::String *, jboolean);
  virtual void setSort (JArray< ::java::lang::String *> *);
  virtual void setSort (::org::apache::lucene::search::SortField *);
  virtual void setSort (JArray< ::org::apache::lucene::search::SortField *> *);
  virtual JArray< ::org::apache::lucene::search::SortField *> *getSort () { return fields; }
  virtual ::java::lang::String *toString ();
  static ::org::apache::lucene::search::Sort *RELEVANCE;
  static ::org::apache::lucene::search::Sort *INDEXORDER;
public: // actually package-private
  JArray< ::org::apache::lucene::search::SortField *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fields;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Sort__ */
