// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_QueryParser$JJCalls__
#define __org_apache_lucene_queryParser_QueryParser$JJCalls__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class QueryParser$JJCalls;
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::QueryParser$JJCalls : public ::java::lang::Object
{
public: // actually package-private
  QueryParser$JJCalls ();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  gen;
  ::org::apache::lucene::queryParser::Token *first;
  jint arg;
  ::org::apache::lucene::queryParser::QueryParser$JJCalls *next;

  friend class org_apache_lucene_queryParser_QueryParser$JJCalls;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_QueryParser$JJCalls__ */
