// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_FieldsReader$FieldForMerge__
#define __org_apache_lucene_index_FieldsReader$FieldForMerge__

#pragma interface

#include <org/apache/lucene/document/AbstractField.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class FieldsReader$FieldForMerge;
          class FieldInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::FieldsReader$FieldForMerge : public ::org::apache::lucene::document::AbstractField
{
public:
  ::java::lang::String *stringValue ();
  ::java::io::Reader *readerValue () { return 0; }
  jbyteArray binaryValue ();
  FieldsReader$FieldForMerge (::java::lang::Object *, ::org::apache::lucene::index::FieldInfo *, jboolean, jboolean, jboolean);

  friend class org_apache_lucene_index_FieldsReader$FieldForMerge;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_FieldsReader$FieldForMerge__ */
