// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_QueryParserConstants__
#define __org_apache_lucene_queryParser_QueryParserConstants__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class QueryParserConstants;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::QueryParserConstants : public ::java::lang::Object
{
public:
  static const jint EOF = 0L;
  static const jint _NUM_CHAR = 1L;
  static const jint _ESCAPED_CHAR = 2L;
  static const jint _TERM_START_CHAR = 3L;
  static const jint _TERM_CHAR = 4L;
  static const jint _WHITESPACE = 5L;
  static const jint AND = 7L;
  static const jint OR = 8L;
  static const jint NOT = 9L;
  static const jint PLUS = 10L;
  static const jint MINUS = 11L;
  static const jint LPAREN = 12L;
  static const jint RPAREN = 13L;
  static const jint COLON = 14L;
  static const jint CARAT = 15L;
  static const jint QUOTED = 16L;
  static const jint TERM = 17L;
  static const jint FUZZY_SLOP = 18L;
  static const jint PREFIXTERM = 19L;
  static const jint WILDTERM = 20L;
  static const jint RANGEIN_START = 21L;
  static const jint RANGEEX_START = 22L;
  static const jint NUMBER = 23L;
  static const jint RANGEIN_TO = 24L;
  static const jint RANGEIN_END = 25L;
  static const jint RANGEIN_QUOTED = 26L;
  static const jint RANGEIN_GOOP = 27L;
  static const jint RANGEEX_TO = 28L;
  static const jint RANGEEX_END = 29L;
  static const jint RANGEEX_QUOTED = 30L;
  static const jint RANGEEX_GOOP = 31L;
  static const jint Boost = 0L;
  static const jint RangeEx = 1L;
  static const jint RangeIn = 2L;
  static const jint DEFAULT = 3L;
  static JArray< ::java::lang::String *> *tokenImage;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_queryParser_QueryParserConstants__ */
