// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_SimpleFSLock__
#define __org_apache_lucene_store_SimpleFSLock__

#pragma interface

#include <org/apache/lucene/store/Lock.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class SimpleFSLock;
        }
      }
    }
  }
}

class org::apache::lucene::store::SimpleFSLock : public ::org::apache::lucene::store::Lock
{
public:
  SimpleFSLock (::java::io::File *, ::java::lang::String *);
  virtual jboolean obtain ();
  virtual void release ();
  virtual jboolean isLocked ();
  virtual ::java::lang::String *toString ();
public: // actually package-private
  ::java::io::File * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::Lock )))) lockFile;
  ::java::io::File *lockDir;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_SimpleFSLock__ */
