// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_StopFilter__
#define __org_apache_lucene_analysis_StopFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class StopFilter;
          class Token;
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::StopFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  StopFilter (::org::apache::lucene::analysis::TokenStream *, JArray< ::java::lang::String *> *);
  StopFilter (::org::apache::lucene::analysis::TokenStream *, JArray< ::java::lang::String *> *, jboolean);
  StopFilter (::org::apache::lucene::analysis::TokenStream *, ::java::util::Set *, jboolean);
  StopFilter (::org::apache::lucene::analysis::TokenStream *, ::java::util::Set *);
  static ::java::util::Set *makeStopSet (JArray< ::java::lang::String *> *);
  static ::java::util::Set *makeStopSet (JArray< ::java::lang::String *> *, jboolean);
  ::org::apache::lucene::analysis::Token *next ();
private:
  ::java::util::Set * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter )))) stopWords;
  jboolean ignoreCase;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_StopFilter__ */
