// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_PrefixGenerator__
#define __org_apache_lucene_search_PrefixGenerator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class PrefixGenerator;
        }
        namespace index
        {
          class IndexReader;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::search::PrefixGenerator : public ::java::lang::Object
{
public: // actually package-private
  PrefixGenerator (::org::apache::lucene::index::Term *);
public:
  virtual void generate (::org::apache::lucene::index::IndexReader *);
public:  // actually protected
  ::org::apache::lucene::index::Term * __attribute__((aligned(__alignof__( ::java::lang::Object )))) prefix;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_PrefixGenerator__ */
