// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_MultipleTermPositions$TermPositionsQueue__
#define __org_apache_lucene_index_MultipleTermPositions$TermPositionsQueue__

#pragma interface

#include <org/apache/lucene/util/PriorityQueue.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class MultipleTermPositions$TermPositionsQueue;
          class TermPositions;
        }
      }
    }
  }
}

class org::apache::lucene::index::MultipleTermPositions$TermPositionsQueue : public ::org::apache::lucene::util::PriorityQueue
{
public: // actually package-private
  MultipleTermPositions$TermPositionsQueue (::java::util::List *);
  ::org::apache::lucene::index::TermPositions *peek ();
public:
  jboolean lessThan (::java::lang::Object *, ::java::lang::Object *);

  friend class org_apache_lucene_index_MultipleTermPositions$TermPositionsQueue;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_MultipleTermPositions$TermPositionsQueue__ */
