// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_Field$Store__
#define __org_apache_lucene_document_Field$Store__

#pragma interface

#include <org/apache/lucene/util/Parameter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Field$Store;
        }
      }
    }
  }
}

class org::apache::lucene::document::Field$Store : public ::org::apache::lucene::util::Parameter
{
private:
  Field$Store (::java::lang::String *);
public:
  static ::org::apache::lucene::document::Field$Store *COMPRESS;
  static ::org::apache::lucene::document::Field$Store *YES;
  static ::org::apache::lucene::document::Field$Store *NO;

  friend class org_apache_lucene_document_Field$Store;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_Field$Store__ */
