// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_RAMFile__
#define __org_apache_lucene_store_RAMFile__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class RAMFile;
          class RAMDirectory;
        }
      }
    }
  }
}

class org::apache::lucene::store::RAMFile : public ::java::lang::Object
{
public: // actually package-private
  RAMFile ();
  RAMFile (::org::apache::lucene::store::RAMDirectory *);
  virtual jlong getLength ();
  virtual void setLength (jlong);
  virtual jlong getLastModified ();
  virtual void setLastModified (jlong);
  jbyteArray addBuffer (jint);
  virtual jlong getSizeInBytes ();
private:
  static const jlong serialVersionUID = 1LL;
public: // actually package-private
  ::java::util::ArrayList * __attribute__((aligned(__alignof__( ::java::lang::Object )))) buffers;
  jlong length;
  ::org::apache::lucene::store::RAMDirectory *directory;
  jlong sizeInBytes;
private:
  jlong lastModified;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_RAMFile__ */
