// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Similarity__
#define __org_apache_lucene_search_Similarity__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Term;
        }
        namespace search
        {
          class Searcher;
          class Similarity;
        }
      }
    }
  }
}

class org::apache::lucene::search::Similarity : public ::java::lang::Object
{
public:
  Similarity ();
  static void setDefault (::org::apache::lucene::search::Similarity *);
  static ::org::apache::lucene::search::Similarity *getDefault ();
  static jfloat decodeNorm (jbyte);
  static jfloatArray getNormDecoder ();
  virtual jfloat lengthNorm (::java::lang::String *, jint) = 0;
  virtual jfloat queryNorm (jfloat) = 0;
  static jbyte encodeNorm (jfloat);
  virtual jfloat tf (jint);
  virtual jfloat sloppyFreq (jint) = 0;
  virtual jfloat tf (jfloat) = 0;
  virtual jfloat idf (::org::apache::lucene::index::Term *, ::org::apache::lucene::search::Searcher *);
  virtual jfloat idf (::java::util::Collection *, ::org::apache::lucene::search::Searcher *);
  virtual jfloat idf (jint, jint) = 0;
  virtual jfloat coord (jint, jint) = 0;
private:
  static ::org::apache::lucene::search::Similarity *defaultImpl;
  static jfloatArray NORM_TABLE;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_Similarity__ */
