// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_PorterStemmer__
#define __org_apache_lucene_analysis_PorterStemmer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class PorterStemmer;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::PorterStemmer : public ::java::lang::Object
{
public:
  PorterStemmer ();
  virtual void reset ();
  virtual void add (jchar);
  virtual ::java::lang::String *toString ();
  virtual jint getResultLength () { return i; }
  virtual jcharArray getResultBuffer () { return b; }
private:
  jboolean cons (jint);
  jint m ();
  jboolean vowelinstem ();
  jboolean doublec (jint);
  jboolean cvc (jint);
  jboolean ends (::java::lang::String *);
public: // actually package-private
  virtual void setto (::java::lang::String *);
  virtual void r (::java::lang::String *);
private:
  void step1 ();
  void step2 ();
  void step3 ();
  void step4 ();
  void step5 ();
  void step6 ();
public:
  virtual ::java::lang::String *stem (::java::lang::String *);
  virtual jboolean stem (jcharArray);
  virtual jboolean stem (jcharArray, jint, jint);
  virtual jboolean stem (jcharArray, jint);
  virtual jboolean stem ();
  virtual jboolean stem (jint);
  static void main (JArray< ::java::lang::String *> *);
private:
  jcharArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  b;
  jint i;
  jint j;
  jint k;
  jint k0;
  jboolean dirty;
  static const jint INC = 50L;
  static const jint EXTRA = 1L;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_PorterStemmer__ */
