// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __com_sleepycat_db_DbHandleExtractor__
#define __com_sleepycat_db_DbHandleExtractor__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace com
  {
    namespace sleepycat
    {
      namespace db
      {
        class DbHandleExtractor;
        class Transaction;
        namespace internal
        {
          class DbTxn;
          class Db;
        }
        class Database;
      }
    }
  }
}

class com::sleepycat::db::DbHandleExtractor : public ::java::lang::Object
{
private:
  DbHandleExtractor ();
public:
  static ::com::sleepycat::db::internal::Db *getDb (::com::sleepycat::db::Database *) { return db; }
  static ::com::sleepycat::db::internal::DbTxn *getDbTxn (::com::sleepycat::db::Transaction *) { return txn; }

  static ::java::lang::Class class$;
};

#endif /* __com_sleepycat_db_DbHandleExtractor__ */
