// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_SpanScorer__
#define __org_apache_lucene_search_spans_SpanScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Explanation;
          class Similarity;
          class Weight;
          namespace spans
          {
            class SpanScorer;
            class Spans;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::SpanScorer : public ::org::apache::lucene::search::Scorer
{
public: // actually package-private
  SpanScorer (::org::apache::lucene::search::spans::Spans *, ::org::apache::lucene::search::Weight *, ::org::apache::lucene::search::Similarity *, jbyteArray);
public:
  virtual jboolean next ();
  virtual jboolean skipTo (jint);
private:
  jboolean setFreqCurrentDoc ();
public:
  virtual jint doc () { return doc__; }
  virtual jfloat score ();
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
private:
  ::org::apache::lucene::search::spans::Spans * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) spans;
  ::org::apache::lucene::search::Weight *weight;
  jbyteArray norms;
  jfloat value;
  jboolean firstTime;
  jboolean more;
  jint doc__;
  jfloat freq;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_SpanScorer__ */
