// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_fr_FrenchAnalyzer__
#define __org_apache_lucene_analysis_fr_FrenchAnalyzer__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace fr
          {
            class FrenchAnalyzer;
          }
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::fr::FrenchAnalyzer : public ::org::apache::lucene::analysis::Analyzer
{
public:
  FrenchAnalyzer ();
  FrenchAnalyzer (JArray< ::java::lang::String *> *);
  FrenchAnalyzer (::java::io::File *);
  void setStemExclusionTable (JArray< ::java::lang::String *> *);
  void setStemExclusionTable (::java::util::Hashtable *);
  void setStemExclusionTable (::java::io::File *);
  ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);
  static JArray< ::java::lang::String *> *FRENCH_STOP_WORDS;
private:
  ::java::util::Set * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Analyzer )))) stoptable;
  ::java::util::Set *excltable;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_fr_FrenchAnalyzer__ */
