// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_NativeFSLock__
#define __org_apache_lucene_store_NativeFSLock__

#pragma interface

#include <org/apache/lucene/store/Lock.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class NativeFSLock;
        }
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class FileLock;
        class FileChannel;
      }
    }
  }
}

class org::apache::lucene::store::NativeFSLock : public ::org::apache::lucene::store::Lock
{
public:
  NativeFSLock (::java::io::File *, ::java::lang::String *);
  virtual jboolean obtain ();
  virtual void release ();
  virtual jboolean isLocked ();
  virtual ::java::lang::String *toString ();
  virtual void finalize ();
private:
  ::java::io::RandomAccessFile * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::Lock )))) f;
  ::java::nio::channels::FileChannel *channel;
  ::java::nio::channels::FileLock *lock;
  ::java::io::File *path;
  ::java::io::File *lockDir;
  static ::java::util::HashSet *LOCK_HELD;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_NativeFSLock__ */
