// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_TopFieldDocCollector__
#define __org_apache_lucene_search_TopFieldDocCollector__

#pragma interface

#include <org/apache/lucene/search/TopDocCollector.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class TopFieldDocCollector;
          class TopDocs;
          class Sort;
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::TopFieldDocCollector : public ::org::apache::lucene::search::TopDocCollector
{
public:
  TopFieldDocCollector (::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::search::Sort *, jint);
  virtual void collect (jint, jfloat);
  virtual ::org::apache::lucene::search::TopDocs *topDocs ();

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_TopFieldDocCollector__ */
