// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_TopFieldDocs__
#define __org_apache_lucene_search_TopFieldDocs__

#pragma interface

#include <org/apache/lucene/search/TopDocs.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class TopFieldDocs;
          class ScoreDoc;
          class SortField;
        }
      }
    }
  }
}

class org::apache::lucene::search::TopFieldDocs : public ::org::apache::lucene::search::TopDocs
{
public: // actually package-private
  TopFieldDocs (jint, JArray< ::org::apache::lucene::search::ScoreDoc *> *, JArray< ::org::apache::lucene::search::SortField *> *, jfloat);
public:
  JArray< ::org::apache::lucene::search::SortField *> * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::TopDocs )))) fields;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_TopFieldDocs__ */
