// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_snowball_SnowballFilter__
#define __org_apache_lucene_analysis_snowball_SnowballFilter__

#pragma interface

#include <org/apache/lucene/analysis/TokenFilter.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace snowball
          {
            class SnowballFilter;
          }
          class Token;
          class TokenStream;
        }
      }
    }
  }
  namespace net
  {
    namespace sf
    {
      namespace snowball
      {
        class SnowballProgram;
      }
    }
  }
}

class org::apache::lucene::analysis::snowball::SnowballFilter : public ::org::apache::lucene::analysis::TokenFilter
{
public:
  SnowballFilter (::org::apache::lucene::analysis::TokenStream *, ::java::lang::String *);
  ::org::apache::lucene::analysis::Token *next ();
private:
  static JArray< ::java::lang::Object *> *EMPTY_ARGS;
  ::net::sf::snowball::SnowballProgram * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenFilter )))) stemmer;
  ::java::lang::reflect::Method *stemMethod;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_snowball_SnowballFilter__ */
