// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_PhrasePositions__
#define __org_apache_lucene_search_PhrasePositions__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class PhrasePositions;
        }
        namespace index
        {
          class TermPositions;
        }
      }
    }
  }
}

class org::apache::lucene::search::PhrasePositions : public ::java::lang::Object
{
public: // actually package-private
  PhrasePositions (::org::apache::lucene::index::TermPositions *, jint);
  jboolean next ();
  jboolean skipTo (jint);
  void firstPosition ();
  jboolean nextPosition ();
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  doc;
  jint position;
  jint count;
  jint offset;
  ::org::apache::lucene::index::TermPositions *tp;
  ::org::apache::lucene::search::PhrasePositions *next__;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_PhrasePositions__ */
