// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_IndexSearcher$1__
#define __org_apache_lucene_search_IndexSearcher$1__

#pragma interface

#include <org/apache/lucene/search/HitCollector.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class IndexSearcher$1;
          class IndexSearcher;
          class HitCollector;
        }
      }
    }
  }
}

class org::apache::lucene::search::IndexSearcher$1 : public ::org::apache::lucene::search::HitCollector
{
public: // actually package-private
  IndexSearcher$1 (::org::apache::lucene::search::IndexSearcher *, ::java::util::BitSet *, ::org::apache::lucene::search::HitCollector *);
public:
  void collect (jint, jfloat);
private:
  ::java::util::BitSet * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::HitCollector )))) val$bits;
  ::org::apache::lucene::search::HitCollector *val$results;
  ::org::apache::lucene::search::IndexSearcher *this$0;

  friend class org_apache_lucene_search_IndexSearcher$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_IndexSearcher$1__ */
