// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_SimpleFSLockFactory__
#define __org_apache_lucene_store_SimpleFSLockFactory__

#pragma interface

#include <org/apache/lucene/store/LockFactory.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class SimpleFSLockFactory;
          class Lock;
        }
      }
    }
  }
}

class org::apache::lucene::store::SimpleFSLockFactory : public ::org::apache::lucene::store::LockFactory
{
public:
  SimpleFSLockFactory ();
  SimpleFSLockFactory (::java::io::File *);
  SimpleFSLockFactory (::java::lang::String *);
public:  // actually protected
  virtual void init (::java::io::File *);
public:
  virtual ::org::apache::lucene::store::Lock *makeLock (::java::lang::String *);
  virtual void clearAllLocks ();
  static ::java::lang::String *LOCK_DIR;
private:
  ::java::io::File * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::LockFactory )))) lockDir;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_SimpleFSLockFactory__ */
