// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_Tokenizer__
#define __org_apache_lucene_analysis_Tokenizer__

#pragma interface

#include <org/apache/lucene/analysis/TokenStream.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class Tokenizer;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::Tokenizer : public ::org::apache::lucene::analysis::TokenStream
{
public:  // actually protected
  Tokenizer ();
  Tokenizer (::java::io::Reader *);
public:
  virtual void close ();
public:  // actually protected
  ::java::io::Reader * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::TokenStream )))) input;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_Tokenizer__ */
