// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanQuery$TooManyClauses__
#define __org_apache_lucene_search_BooleanQuery$TooManyClauses__

#pragma interface

#include <java/lang/RuntimeException.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanQuery$TooManyClauses;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanQuery$TooManyClauses : public ::java::lang::RuntimeException
{
public:
  BooleanQuery$TooManyClauses ();
  virtual ::java::lang::String *getMessage ();

  friend class org_apache_lucene_search_BooleanQuery$TooManyClauses;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanQuery$TooManyClauses__ */
