// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_db_Block__
#define __org_apache_lucene_store_db_Block__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          namespace db
          {
            class Block;
            class DbDirectory;
            class File;
          }
        }
      }
    }
  }
  namespace com
  {
    namespace sleepycat
    {
      namespace db
      {
        class DatabaseEntry;
      }
    }
  }
}

class org::apache::lucene::store::db::Block : public ::java::lang::Object
{
public:  // actually protected
  Block (::org::apache::lucene::store::db::File *);
  virtual jbyteArray getKey ();
  virtual jbyteArray getData ();
  virtual void seek (jlong);
  virtual void get (::org::apache::lucene::store::db::DbDirectory *);
  virtual void put (::org::apache::lucene::store::db::DbDirectory *);
  ::com::sleepycat::db::DatabaseEntry * __attribute__((aligned(__alignof__( ::java::lang::Object )))) key;
  ::com::sleepycat::db::DatabaseEntry *data;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_db_Block__ */
