// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ConjunctionScorer$1__
#define __org_apache_lucene_search_ConjunctionScorer$1__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class ConjunctionScorer$1;
          class ConjunctionScorer;
        }
      }
    }
  }
}

class org::apache::lucene::search::ConjunctionScorer$1 : public ::java::lang::Object
{
public: // actually package-private
  ConjunctionScorer$1 (::org::apache::lucene::search::ConjunctionScorer *);
public:
  virtual jint compare (::java::lang::Object *, ::java::lang::Object *);
private:
  ::org::apache::lucene::search::ConjunctionScorer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) this$0;

  friend class org_apache_lucene_search_ConjunctionScorer$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ConjunctionScorer$1__ */
