// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_KeywordTokenizer__
#define __org_apache_lucene_analysis_KeywordTokenizer__

#pragma interface

#include <org/apache/lucene/analysis/Tokenizer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class KeywordTokenizer;
          class Token;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::KeywordTokenizer : public ::org::apache::lucene::analysis::Tokenizer
{
public:
  KeywordTokenizer (::java::io::Reader *);
  KeywordTokenizer (::java::io::Reader *, jint);
  virtual ::org::apache::lucene::analysis::Token *next ();
private:
  static const jint DEFAULT_BUFFER_SIZE = 256L;
  jboolean __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Tokenizer ))))  done;
  jcharArray buffer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_KeywordTokenizer__ */
