// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_SimpleHTMLEncoder__
#define __org_apache_lucene_search_highlight_SimpleHTMLEncoder__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class SimpleHTMLEncoder;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::SimpleHTMLEncoder : public ::java::lang::Object
{
public:
  SimpleHTMLEncoder ();
  virtual ::java::lang::String *encodeText (::java::lang::String *);
  static ::java::lang::String *htmlEncode (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_SimpleHTMLEncoder__ */
