// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_Fieldable__
#define __org_apache_lucene_document_Fieldable__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class Fieldable;
        }
      }
    }
  }
}

class org::apache::lucene::document::Fieldable : public ::java::lang::Object
{
public:
  virtual void setBoost (jfloat) = 0;
  virtual jfloat getBoost () = 0;
  virtual ::java::lang::String *name () = 0;
  virtual ::java::lang::String *stringValue () = 0;
  virtual ::java::io::Reader *readerValue () = 0;
  virtual jbyteArray binaryValue () = 0;
  virtual jboolean isStored () = 0;
  virtual jboolean isIndexed () = 0;
  virtual jboolean isTokenized () = 0;
  virtual jboolean isCompressed () = 0;
  virtual jboolean isTermVectorStored () = 0;
  virtual jboolean isStoreOffsetWithTermVector () = 0;
  virtual jboolean isStorePositionWithTermVector () = 0;
  virtual jboolean isBinary () = 0;
  virtual jboolean getOmitNorms () = 0;
  virtual void setOmitNorms (jboolean) = 0;
  virtual jboolean isLazy () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_document_Fieldable__ */
