// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_standard_CharStream__
#define __org_apache_lucene_analysis_standard_CharStream__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace standard
          {
            class CharStream;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::standard::CharStream : public ::java::lang::Object
{
public:
  virtual jchar readChar () = 0;
  virtual jint getColumn () = 0;
  virtual jint getLine () = 0;
  virtual jint getEndColumn () = 0;
  virtual jint getEndLine () = 0;
  virtual jint getBeginColumn () = 0;
  virtual jint getBeginLine () = 0;
  virtual void backup (jint) = 0;
  virtual jchar BeginToken () = 0;
  virtual ::java::lang::String *GetImage () = 0;
  virtual jcharArray GetSuffix (jint) = 0;
  virtual void Done () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_analysis_standard_CharStream__ */
