// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentInfos$2__
#define __org_apache_lucene_index_SegmentInfos$2__

#pragma interface

#include <org/apache/lucene/index/SegmentInfos$FindSegmentsFile.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentInfos$2;
        }
        namespace store
        {
          class Directory;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentInfos$2 : public ::org::apache::lucene::index::SegmentInfos$FindSegmentsFile
{
public: // actually package-private
  SegmentInfos$2 (::org::apache::lucene::store::Directory *);
public:
  virtual ::java::lang::Object *doBody (::java::lang::String *);

  friend class org_apache_lucene_index_SegmentInfos$2;
  friend class org_apache_lucene_index_SegmentInfos$FindSegmentsFile;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentInfos$2__ */
