// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_spans_SpanQuery__
#define __org_apache_lucene_search_spans_SpanQuery__

#pragma interface

#include <org/apache/lucene/search/Query.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class Weight;
          class Searcher;
          namespace spans
          {
            class SpanQuery;
            class Spans;
          }
        }
        namespace index
        {
          class IndexReader;
        }
      }
    }
  }
}

class org::apache::lucene::search::spans::SpanQuery : public ::org::apache::lucene::search::Query
{
public:
  SpanQuery ();
  virtual ::org::apache::lucene::search::spans::Spans *getSpans (::org::apache::lucene::index::IndexReader *) = 0;
  virtual ::java::lang::String *getField () = 0;
  virtual ::java::util::Collection *getTerms () = 0;
public:  // actually protected
  virtual ::org::apache::lucene::search::Weight *createWeight (::org::apache::lucene::search::Searcher *);
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_spans_SpanQuery__ */
