// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentTermPositionVector__
#define __org_apache_lucene_index_SegmentTermPositionVector__

#pragma interface

#include <org/apache/lucene/index/SegmentTermVector.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class SegmentTermPositionVector;
          class TermVectorOffsetInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentTermPositionVector : public ::org::apache::lucene::index::SegmentTermVector
{
public:
  SegmentTermPositionVector (::java::lang::String *, JArray< ::java::lang::String *> *, jintArray, JArray<jintArray> *, JArray<JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *> *);
  virtual JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *getOffsets (jint);
  virtual jintArray getTermPositions (jint);
public:  // actually protected
  JArray<jintArray> * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::SegmentTermVector ))))  positions;
  JArray<JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *> *offsets;
public:
  static jintArray EMPTY_TERM_POS;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentTermPositionVector__ */
