// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_LockFactory__
#define __org_apache_lucene_store_LockFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class LockFactory;
          class Lock;
        }
      }
    }
  }
}

class org::apache::lucene::store::LockFactory : public ::java::lang::Object
{
public:
  LockFactory ();
  virtual void setLockPrefix (::java::lang::String *);
  virtual ::java::lang::String *getLockPrefix () { return lockPrefix; }
  virtual ::org::apache::lucene::store::Lock *makeLock (::java::lang::String *) = 0;
  virtual void clearAllLocks () = 0;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) lockPrefix;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_LockFactory__ */
