// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_Weight__
#define __org_apache_lucene_search_Weight__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class Weight;
          class Explanation;
          class Scorer;
          class Query;
        }
      }
    }
  }
}

class org::apache::lucene::search::Weight : public ::java::lang::Object
{
public:
  virtual ::org::apache::lucene::search::Query *getQuery () = 0;
  virtual jfloat getValue () = 0;
  virtual jfloat sumOfSquaredWeights () = 0;
  virtual void normalize (jfloat) = 0;
  virtual ::org::apache::lucene::search::Scorer *scorer (::org::apache::lucene::index::IndexReader *) = 0;
  virtual ::org::apache::lucene::search::Explanation *explain (::org::apache::lucene::index::IndexReader *, jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_search_Weight__ */
