// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_br_BrazilianStemmer__
#define __org_apache_lucene_analysis_br_BrazilianStemmer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace br
          {
            class BrazilianStemmer;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::br::BrazilianStemmer : public ::java::lang::Object
{
public:
  BrazilianStemmer ();
public:  // actually protected
  virtual ::java::lang::String *stem (::java::lang::String *);
private:
  jboolean isStemmable (::java::lang::String *);
  jboolean isIndexable (::java::lang::String *);
  jboolean isVowel (jchar);
  ::java::lang::String *getR1 (::java::lang::String *);
  ::java::lang::String *getRV (::java::lang::String *);
  ::java::lang::String *changeTerm (::java::lang::String *);
  jboolean suffix (::java::lang::String *, ::java::lang::String *);
  ::java::lang::String *replaceSuffix (::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  ::java::lang::String *removeSuffix (::java::lang::String *, ::java::lang::String *);
  jboolean suffixPreceded (::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  void createCT (::java::lang::String *);
  jboolean step1 ();
  jboolean step2 ();
  void step3 ();
  void step4 ();
  void step5 ();
public:
  virtual ::java::lang::String *log ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) TERM;
  ::java::lang::String *CT;
  ::java::lang::String *R1;
  ::java::lang::String *R2;
  ::java::lang::String *RV;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_br_BrazilianStemmer__ */
