// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_QueryParserTokenManager__
#define __org_apache_lucene_queryParser_QueryParserTokenManager__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class QueryParserTokenManager;
          class Token;
          class CharStream;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::QueryParserTokenManager : public ::java::lang::Object
{
public:
  virtual void setDebugStream (::java::io::PrintStream *);
private:
  jint jjStopStringLiteralDfa_3 (jint, jlong);
  jint jjStartNfa_3 (jint, jlong);
  jint jjStopAtPos (jint, jint);
  jint jjStartNfaWithStates_3 (jint, jint, jint);
  jint jjMoveStringLiteralDfa0_3 ();
  void jjCheckNAdd (jint);
  void jjAddStates (jint, jint);
  void jjCheckNAddTwoStates (jint, jint);
  void jjCheckNAddStates (jint, jint);
  void jjCheckNAddStates (jint);
  jint jjMoveNfa_3 (jint, jint);
  jint jjStopStringLiteralDfa_1 (jint, jlong);
  jint jjStartNfa_1 (jint, jlong);
  jint jjStartNfaWithStates_1 (jint, jint, jint);
  jint jjMoveStringLiteralDfa0_1 ();
  jint jjMoveStringLiteralDfa1_1 (jlong);
  jint jjMoveNfa_1 (jint, jint);
  jint jjMoveStringLiteralDfa0_0 ();
  jint jjMoveNfa_0 (jint, jint);
  jint jjStopStringLiteralDfa_2 (jint, jlong);
  jint jjStartNfa_2 (jint, jlong);
  jint jjStartNfaWithStates_2 (jint, jint, jint);
  jint jjMoveStringLiteralDfa0_2 ();
  jint jjMoveStringLiteralDfa1_2 (jlong);
  jint jjMoveNfa_2 (jint, jint);
  static jboolean jjCanMove_0 (jint, jint, jint, jlong, jlong);
public:
  QueryParserTokenManager (::org::apache::lucene::queryParser::CharStream *);
  QueryParserTokenManager (::org::apache::lucene::queryParser::CharStream *, jint);
  virtual void ReInit (::org::apache::lucene::queryParser::CharStream *);
private:
  void ReInitRounds ();
public:
  virtual void ReInit (::org::apache::lucene::queryParser::CharStream *, jint);
  virtual void SwitchTo (jint);
public:  // actually protected
  virtual ::org::apache::lucene::queryParser::Token *jjFillToken ();
public:
  virtual ::org::apache::lucene::queryParser::Token *getNextToken ();
  ::java::io::PrintStream * __attribute__((aligned(__alignof__( ::java::lang::Object )))) debugStream;
public: // actually package-private
  static jlongArray jjbitVec0;
  static jlongArray jjbitVec2;
  static jintArray jjnextStates;
public:
  static JArray< ::java::lang::String *> *jjstrLiteralImages;
  static JArray< ::java::lang::String *> *lexStateNames;
  static jintArray jjnewLexState;
public: // actually package-private
  static jlongArray jjtoToken;
  static jlongArray jjtoSkip;
public:  // actually protected
  ::org::apache::lucene::queryParser::CharStream *input_stream;
private:
  jintArray jjrounds;
  jintArray jjstateSet;
public:  // actually protected
  jchar curChar;
public: // actually package-private
  jint curLexState;
  jint defaultLexState;
  jint jjnewStateCnt;
  jint jjround;
  jint jjmatchedPos;
  jint jjmatchedKind;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_QueryParserTokenManager__ */
