// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanClause$Occur__
#define __org_apache_lucene_search_BooleanClause$Occur__

#pragma interface

#include <org/apache/lucene/util/Parameter.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanClause$Occur;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanClause$Occur : public ::org::apache::lucene::util::Parameter
{
private:
  BooleanClause$Occur (::java::lang::String *);
public:
  ::java::lang::String *toString ();
  static ::org::apache::lucene::search::BooleanClause$Occur *MUST;
  static ::org::apache::lucene::search::BooleanClause$Occur *SHOULD;
  static ::org::apache::lucene::search::BooleanClause$Occur *MUST_NOT;

  friend class org_apache_lucene_search_BooleanClause$Occur;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanClause$Occur__ */
