// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_MapFieldSelector__
#define __org_apache_lucene_document_MapFieldSelector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class MapFieldSelector;
          class FieldSelectorResult;
        }
      }
    }
  }
}

class org::apache::lucene::document::MapFieldSelector : public ::java::lang::Object
{
public:
  MapFieldSelector (::java::util::Map *);
  MapFieldSelector (::java::util::List *);
  MapFieldSelector (JArray< ::java::lang::String *> *);
  virtual ::org::apache::lucene::document::FieldSelectorResult *accept (::java::lang::String *);
public: // actually package-private
  ::java::util::Map * __attribute__((aligned(__alignof__( ::java::lang::Object )))) fieldSelections;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_MapFieldSelector__ */
