// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanClause__
#define __org_apache_lucene_search_BooleanClause__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanClause;
          class BooleanClause$Occur;
          class Query;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanClause : public ::java::lang::Object
{
public:
  BooleanClause (::org::apache::lucene::search::Query *, ::org::apache::lucene::search::BooleanClause$Occur *);
  virtual ::org::apache::lucene::search::BooleanClause$Occur *getOccur () { return occur; }
  virtual void setOccur (::org::apache::lucene::search::BooleanClause$Occur *);
  virtual ::org::apache::lucene::search::Query *getQuery () { return query; }
  virtual void setQuery (::org::apache::lucene::search::Query *);
  virtual jboolean isProhibited ();
  virtual jboolean isRequired ();
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual ::java::lang::String *toString ();
private:
  ::org::apache::lucene::search::Query * __attribute__((aligned(__alignof__( ::java::lang::Object )))) query;
  ::org::apache::lucene::search::BooleanClause$Occur *occur;

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanClause__ */
