// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_MultiTermEnum__
#define __org_apache_lucene_index_MultiTermEnum__

#pragma interface

#include <org/apache/lucene/index/TermEnum.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class MultiTermEnum;
          class IndexReader;
          class Term;
          class SegmentMergeQueue;
        }
      }
    }
  }
}

class org::apache::lucene::index::MultiTermEnum : public ::org::apache::lucene::index::TermEnum
{
public:
  MultiTermEnum (JArray< ::org::apache::lucene::index::IndexReader *> *, jintArray, ::org::apache::lucene::index::Term *);
  virtual jboolean next ();
  virtual ::org::apache::lucene::index::Term *term () { return term__; }
  virtual jint docFreq () { return docFreq__; }
  virtual void close ();
private:
  ::org::apache::lucene::index::SegmentMergeQueue * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::TermEnum )))) queue;
  ::org::apache::lucene::index::Term *term__;
  jint docFreq__;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_MultiTermEnum__ */
