// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_ConstantScoreQuery$ConstantScorer__
#define __org_apache_lucene_search_ConstantScoreQuery$ConstantScorer__

#pragma interface

#include <org/apache/lucene/search/Scorer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class ConstantScoreQuery$ConstantScorer;
          class Explanation;
          class Weight;
          class Similarity;
          class ConstantScoreQuery;
        }
      }
    }
  }
}

class org::apache::lucene::search::ConstantScoreQuery$ConstantScorer : public ::org::apache::lucene::search::Scorer
{
public:
  ConstantScoreQuery$ConstantScorer (::org::apache::lucene::search::ConstantScoreQuery *, ::org::apache::lucene::search::Similarity *, ::org::apache::lucene::index::IndexReader *, ::org::apache::lucene::search::Weight *);
  virtual jboolean next ();
  virtual jint doc () { return doc__; }
  virtual jfloat score () { return theScore; }
  virtual jboolean skipTo (jint);
  virtual ::org::apache::lucene::search::Explanation *explain (jint);
public: // actually package-private
  ::java::util::BitSet * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::Scorer )))) bits;
  jfloat theScore;
  jint doc__;
private:
  ::org::apache::lucene::search::ConstantScoreQuery *this$0;

  friend class org_apache_lucene_search_ConstantScoreQuery$ConstantScorer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_ConstantScoreQuery$ConstantScorer__ */
