// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_queryParser_FastCharStream__
#define __org_apache_lucene_queryParser_FastCharStream__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace queryParser
        {
          class FastCharStream;
        }
      }
    }
  }
}

class org::apache::lucene::queryParser::FastCharStream : public ::java::lang::Object
{
public:
  FastCharStream (::java::io::Reader *);
  jchar readChar ();
private:
  void refill ();
public:
  jchar BeginToken ();
  void backup (jint);
  ::java::lang::String *GetImage ();
  jcharArray GetSuffix (jint);
  void Done ();
  jint getColumn ();
  jint getLine ();
  jint getEndColumn ();
  jint getEndLine ();
  jint getBeginColumn ();
  jint getBeginLine ();
public: // actually package-private
  jcharArray __attribute__((aligned(__alignof__( ::java::lang::Object ))))  buffer;
  jint bufferLength;
  jint bufferPosition;
  jint tokenStart;
  jint bufferStart;
  ::java::io::Reader *input;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_queryParser_FastCharStream__ */
