// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_TopDocs__
#define __org_apache_lucene_search_TopDocs__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class TopDocs;
          class ScoreDoc;
        }
      }
    }
  }
}

class org::apache::lucene::search::TopDocs : public ::java::lang::Object
{
public:
  virtual jfloat getMaxScore () { return maxScore; }
  virtual void setMaxScore (jfloat);
public: // actually package-private
  TopDocs (jint, JArray< ::org::apache::lucene::search::ScoreDoc *> *, jfloat);
public:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  totalHits;
  JArray< ::org::apache::lucene::search::ScoreDoc *> *scoreDocs;
private:
  jfloat maxScore;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_TopDocs__ */
