// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_AbstractField__
#define __org_apache_lucene_document_AbstractField__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class AbstractField;
          class Field$TermVector;
          class Field$Index;
          class Field$Store;
        }
      }
    }
  }
}

class org::apache::lucene::document::AbstractField : public ::java::lang::Object
{
public:  // actually protected
  AbstractField ();
  AbstractField (::java::lang::String *, ::org::apache::lucene::document::Field$Store *, ::org::apache::lucene::document::Field$Index *, ::org::apache::lucene::document::Field$TermVector *);
public:
  virtual void setBoost (jfloat);
  virtual jfloat getBoost () { return boost; }
  virtual ::java::lang::String *name () { return name__; }
public:  // actually protected
  virtual void setStoreTermVector (::org::apache::lucene::document::Field$TermVector *);
public:
  jboolean isStored () { return isStored__; }
  jboolean isIndexed () { return isIndexed__; }
  jboolean isTokenized () { return isTokenized__; }
  jboolean isCompressed () { return isCompressed__; }
  jboolean isTermVectorStored () { return storeTermVector; }
  virtual jboolean isStoreOffsetWithTermVector () { return storeOffsetWithTermVector; }
  virtual jboolean isStorePositionWithTermVector () { return storePositionWithTermVector; }
  jboolean isBinary () { return isBinary__; }
  virtual jboolean getOmitNorms () { return omitNorms; }
  virtual void setOmitNorms (jboolean);
  virtual jboolean isLazy () { return lazy; }
  ::java::lang::String *toString ();
  virtual ::java::lang::String *stringValue () = 0;
  virtual ::java::io::Reader *readerValue () = 0;
  virtual jbyteArray binaryValue () = 0;
public:  // actually protected
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) name__;
  jboolean storeTermVector;
  jboolean storeOffsetWithTermVector;
  jboolean storePositionWithTermVector;
  jboolean omitNorms;
  jboolean isStored__;
  jboolean isIndexed__;
  jboolean isTokenized__;
  jboolean isBinary__;
  jboolean isCompressed__;
  jboolean lazy;
  jfloat boost;
  ::java::lang::Object *fieldsData;

  friend class org_apache_lucene_document_Field$Store;
  friend class org_apache_lucene_document_Field$Index;
  friend class org_apache_lucene_document_Field$TermVector;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_AbstractField__ */
