// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_LoadFirstFieldSelector__
#define __org_apache_lucene_document_LoadFirstFieldSelector__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class LoadFirstFieldSelector;
          class FieldSelectorResult;
        }
      }
    }
  }
}

class org::apache::lucene::document::LoadFirstFieldSelector : public ::java::lang::Object
{
public:
  LoadFirstFieldSelector ();
  virtual ::org::apache::lucene::document::FieldSelectorResult *accept (::java::lang::String *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_LoadFirstFieldSelector__ */
