// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_SegmentInfos$1__
#define __org_apache_lucene_index_SegmentInfos$1__

#pragma interface

#include <org/apache/lucene/index/SegmentInfos$FindSegmentsFile.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class Directory;
        }
        namespace index
        {
          class SegmentInfos$1;
          class SegmentInfos;
        }
      }
    }
  }
}

class org::apache::lucene::index::SegmentInfos$1 : public ::org::apache::lucene::index::SegmentInfos$FindSegmentsFile
{
public: // actually package-private
  SegmentInfos$1 (::org::apache::lucene::index::SegmentInfos *, ::org::apache::lucene::store::Directory *);
public:
  virtual ::java::lang::Object *doBody (::java::lang::String *);
private:
  ::org::apache::lucene::index::SegmentInfos * __attribute__((aligned(__alignof__( ::org::apache::lucene::index::SegmentInfos$FindSegmentsFile )))) this$0;

  friend class org_apache_lucene_index_SegmentInfos$1;
  friend class org_apache_lucene_index_SegmentInfos$FindSegmentsFile;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_SegmentInfos$1__ */
