// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_BooleanScorer$SubScorer__
#define __org_apache_lucene_search_BooleanScorer$SubScorer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class BooleanScorer$SubScorer;
          class HitCollector;
          class Scorer;
        }
      }
    }
  }
}

class org::apache::lucene::search::BooleanScorer$SubScorer : public ::java::lang::Object
{
public:
  BooleanScorer$SubScorer (::org::apache::lucene::search::Scorer *, jboolean, jboolean, ::org::apache::lucene::search::HitCollector *, ::org::apache::lucene::search::BooleanScorer$SubScorer *);
  ::org::apache::lucene::search::Scorer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) scorer;
  jboolean done;
  jboolean required;
  jboolean prohibited;
  ::org::apache::lucene::search::HitCollector *collector;
  ::org::apache::lucene::search::BooleanScorer$SubScorer *next;

  friend class org_apache_lucene_search_BooleanScorer$SubScorer;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_BooleanScorer$SubScorer__ */
