// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_QueryTermExtractor__
#define __org_apache_lucene_search_highlight_QueryTermExtractor__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class FilteredQuery;
          class BooleanQuery;
          namespace highlight
          {
            class QueryTermExtractor;
            class WeightedTerm;
          }
          class Query;
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::QueryTermExtractor : public ::java::lang::Object
{
public:
  QueryTermExtractor ();
  static JArray< ::org::apache::lucene::search::highlight::WeightedTerm *> *getTerms (::org::apache::lucene::search::Query *);
  static JArray< ::org::apache::lucene::search::highlight::WeightedTerm *> *getIdfWeightedTerms (::org::apache::lucene::search::Query *, ::org::apache::lucene::index::IndexReader *, ::java::lang::String *);
  static JArray< ::org::apache::lucene::search::highlight::WeightedTerm *> *getTerms (::org::apache::lucene::search::Query *, jboolean, ::java::lang::String *);
  static JArray< ::org::apache::lucene::search::highlight::WeightedTerm *> *getTerms (::org::apache::lucene::search::Query *, jboolean);
private:
  static void getTerms (::org::apache::lucene::search::Query *, ::java::util::HashSet *, jboolean, ::java::lang::String *);
  static void getTermsFromBooleanQuery (::org::apache::lucene::search::BooleanQuery *, ::java::util::HashSet *, jboolean, ::java::lang::String *);
  static void getTermsFromFilteredQuery (::org::apache::lucene::search::FilteredQuery *, ::java::util::HashSet *, jboolean, ::java::lang::String *);

  friend class org_apache_lucene_search_BooleanClause$Occur;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_QueryTermExtractor__ */
