// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_WhitespaceTokenizer__
#define __org_apache_lucene_analysis_WhitespaceTokenizer__

#pragma interface

#include <org/apache/lucene/analysis/CharTokenizer.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          class WhitespaceTokenizer;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::WhitespaceTokenizer : public ::org::apache::lucene::analysis::CharTokenizer
{
public:
  WhitespaceTokenizer (::java::io::Reader *);
public:  // actually protected
  virtual jboolean isTokenChar (jchar);
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_WhitespaceTokenizer__ */
