// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermVectorsWriter$TVTerm__
#define __org_apache_lucene_index_TermVectorsWriter$TVTerm__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermVectorsWriter$TVTerm;
          class TermVectorOffsetInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermVectorsWriter$TVTerm : public ::java::lang::Object
{
private:
  TermVectorsWriter$TVTerm ();
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) termText;
  jint freq;
  jintArray positions;
  JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *offsets;

  friend class org_apache_lucene_index_TermVectorsWriter$TVTerm;
  friend class org_apache_lucene_index_TermVectorsWriter$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermVectorsWriter$TVTerm__ */
