// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldSortedHitQueue$5__
#define __org_apache_lucene_search_FieldSortedHitQueue$5__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FieldSortedHitQueue$5;
          class ScoreDoc;
        }
      }
    }
  }
  namespace java
  {
    namespace text
    {
      class Collator;
    }
  }
}

class org::apache::lucene::search::FieldSortedHitQueue$5 : public ::java::lang::Object
{
public: // actually package-private
  FieldSortedHitQueue$5 (JArray< ::java::lang::String *> *, ::java::text::Collator *);
public:
  jint compare (::org::apache::lucene::search::ScoreDoc *, ::org::apache::lucene::search::ScoreDoc *);
  virtual ::java::lang::Comparable *sortValue (::org::apache::lucene::search::ScoreDoc *);
  virtual jint sortType ();
private:
  JArray< ::java::lang::String *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) val$index;
  ::java::text::Collator *val$collator;

  friend class org_apache_lucene_search_FieldSortedHitQueue$5;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldSortedHitQueue$5__ */
