// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_highlight_GradientFormatter__
#define __org_apache_lucene_search_highlight_GradientFormatter__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace highlight
          {
            class GradientFormatter;
            class TokenGroup;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::highlight::GradientFormatter : public ::java::lang::Object
{
public:
  GradientFormatter (jfloat, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *, ::java::lang::String *);
  virtual ::java::lang::String *highlightTerm (::java::lang::String *, ::org::apache::lucene::search::highlight::TokenGroup *);
public:  // actually protected
  virtual ::java::lang::String *getForegroundColorString (jfloat);
  virtual ::java::lang::String *getBackgroundColorString (jfloat);
private:
  jint getColorVal (jint, jint, jfloat);
  static ::java::lang::String *intToHex (jint);
public:
  static jint hexToInt (::java::lang::String *);
private:
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  maxScore;
public: // actually package-private
  jint fgRMin;
  jint fgGMin;
  jint fgBMin;
  jint fgRMax;
  jint fgGMax;
  jint fgBMax;
public:  // actually protected
  jboolean highlightForeground;
public: // actually package-private
  jint bgRMin;
  jint bgGMin;
  jint bgBMin;
  jint bgRMax;
  jint bgGMax;
  jint bgBMax;
public:  // actually protected
  jboolean highlightBackground;
private:
  static jcharArray hexDigits;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_highlight_GradientFormatter__ */
