// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery$1__
#define __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery$1__

#pragma interface

#include <org/apache/lucene/search/SimilarityDelegator.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class FuzzyLikeThisQuery$FuzzyTermQuery$1;
          class Similarity;
          class FuzzyLikeThisQuery$FuzzyTermQuery;
        }
      }
    }
  }
}

class org::apache::lucene::search::FuzzyLikeThisQuery$FuzzyTermQuery$1 : public ::org::apache::lucene::search::SimilarityDelegator
{
public: // actually package-private
  FuzzyLikeThisQuery$FuzzyTermQuery$1 (::org::apache::lucene::search::FuzzyLikeThisQuery$FuzzyTermQuery *, ::org::apache::lucene::search::Similarity *);
public:
  virtual jfloat tf (jfloat);
  virtual jfloat idf (jint, jint);
private:
  ::org::apache::lucene::search::FuzzyLikeThisQuery$FuzzyTermQuery * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::SimilarityDelegator )))) this$0;

  friend class org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery;
  friend class org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FuzzyLikeThisQuery$FuzzyTermQuery$1__ */
