// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_Term__
#define __org_apache_lucene_index_Term__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::index::Term : public ::java::lang::Object
{
public:
  Term (::java::lang::String *, ::java::lang::String *);
public: // actually package-private
  Term (::java::lang::String *, ::java::lang::String *, jboolean);
public:
  ::java::lang::String *field () { return field__; }
  ::java::lang::String *text () { return text__; }
  ::org::apache::lucene::index::Term *createTerm (::java::lang::String *);
  jboolean equals (::java::lang::Object *);
  jint hashCode ();
  jint compareTo (::java::lang::Object *);
  jint compareTo (::org::apache::lucene::index::Term *);
public: // actually package-private
  void set (::java::lang::String *, ::java::lang::String *);
public:
  ::java::lang::String *toString ();
private:
  void readObject (::java::io::ObjectInputStream *);
public: // actually package-private
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) field__;
  ::java::lang::String *text__;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_Term__ */
