// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermEnum__
#define __org_apache_lucene_index_TermEnum__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermEnum;
          class Term;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermEnum : public ::java::lang::Object
{
public:
  TermEnum ();
  virtual jboolean next () = 0;
  virtual ::org::apache::lucene::index::Term *term () = 0;
  virtual jint docFreq () = 0;
  virtual void close () = 0;
  virtual jboolean skipTo (::org::apache::lucene::index::Term *);

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermEnum__ */
