// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_FieldCacheImpl$6__
#define __org_apache_lucene_search_FieldCacheImpl$6__

#pragma interface

#include <org/apache/lucene/search/FieldCacheImpl$Cache.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class IndexReader;
        }
        namespace search
        {
          class FieldCacheImpl$6;
          class FieldCacheImpl;
        }
      }
    }
  }
}

class org::apache::lucene::search::FieldCacheImpl$6 : public ::org::apache::lucene::search::FieldCacheImpl$Cache
{
public: // actually package-private
  FieldCacheImpl$6 (::org::apache::lucene::search::FieldCacheImpl *);
public:  // actually protected
  virtual ::java::lang::Object *createValue (::org::apache::lucene::index::IndexReader *, ::java::lang::Object *);
private:
  ::org::apache::lucene::search::FieldCacheImpl * __attribute__((aligned(__alignof__( ::org::apache::lucene::search::FieldCacheImpl$Cache )))) this$0;

  friend class org_apache_lucene_search_FieldCacheImpl$6;
  friend class org_apache_lucene_search_FieldCache$StringIndex;
  friend class org_apache_lucene_search_FieldCacheImpl$Cache;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_FieldCacheImpl$6__ */
