// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_FSIndexOutput__
#define __org_apache_lucene_store_FSIndexOutput__

#pragma interface

#include <org/apache/lucene/store/BufferedIndexOutput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class FSIndexOutput;
        }
      }
    }
  }
}

class org::apache::lucene::store::FSIndexOutput : public ::org::apache::lucene::store::BufferedIndexOutput
{
public:
  FSIndexOutput (::java::io::File *);
  virtual void flushBuffer (jbyteArray, jint);
  virtual void close ();
  virtual void seek (jlong);
  virtual jlong length ();
public:  // actually protected
  virtual void finalize ();
public: // actually package-private
  ::java::io::RandomAccessFile * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::BufferedIndexOutput )))) file;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_FSIndexOutput__ */
