// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_ParallelReader$ParallelTermDocs__
#define __org_apache_lucene_index_ParallelReader$ParallelTermDocs__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class ParallelReader$ParallelTermDocs;
          class TermEnum;
          class Term;
          class ParallelReader;
          class TermDocs;
        }
      }
    }
  }
}

class org::apache::lucene::index::ParallelReader$ParallelTermDocs : public ::java::lang::Object
{
public:
  ParallelReader$ParallelTermDocs (::org::apache::lucene::index::ParallelReader *);
  ParallelReader$ParallelTermDocs (::org::apache::lucene::index::ParallelReader *, ::org::apache::lucene::index::Term *);
  virtual jint doc ();
  virtual jint freq ();
  virtual void seek (::org::apache::lucene::index::Term *);
  virtual void seek (::org::apache::lucene::index::TermEnum *);
  virtual jboolean next ();
  virtual jint read (jintArray, jintArray);
  virtual jboolean skipTo (jint);
  virtual void close ();
public:  // actually protected
  ::org::apache::lucene::index::TermDocs * __attribute__((aligned(__alignof__( ::java::lang::Object )))) termDocs;
private:
  ::org::apache::lucene::index::ParallelReader *this$0;

  friend class org_apache_lucene_index_ParallelReader$ParallelTermDocs;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_ParallelReader$ParallelTermDocs__ */
