// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_standard_StandardTokenizerConstants__
#define __org_apache_lucene_analysis_standard_StandardTokenizerConstants__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace standard
          {
            class StandardTokenizerConstants;
          }
        }
      }
    }
  }
}

class org::apache::lucene::analysis::standard::StandardTokenizerConstants : public ::java::lang::Object
{
public:
  static const jint EOF = 0L;
  static const jint ALPHANUM = 1L;
  static const jint APOSTROPHE = 2L;
  static const jint ACRONYM = 3L;
  static const jint COMPANY = 4L;
  static const jint EMAIL = 5L;
  static const jint HOST = 6L;
  static const jint NUM = 7L;
  static const jint P = 8L;
  static const jint HAS_DIGIT = 9L;
  static const jint ALPHA = 10L;
  static const jint LETTER = 11L;
  static const jint CJ = 12L;
  static const jint KOREAN = 13L;
  static const jint DIGIT = 14L;
  static const jint NOISE = 15L;
  static const jint DEFAULT = 0L;
  static JArray< ::java::lang::String *> *tokenImage;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __org_apache_lucene_analysis_standard_StandardTokenizerConstants__ */
