// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_RAMInputStream__
#define __org_apache_lucene_store_RAMInputStream__

#pragma interface

#include <org/apache/lucene/store/BufferedIndexInput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class RAMInputStream;
          class RAMFile;
        }
      }
    }
  }
}

class org::apache::lucene::store::RAMInputStream : public ::org::apache::lucene::store::BufferedIndexInput
{
public:
  RAMInputStream (::org::apache::lucene::store::RAMFile *);
  virtual void readInternal (jbyteArray, jint, jint);
  virtual void close () { }
  virtual void seekInternal (jlong);
  virtual jlong length () { return length__; }
private:
  ::org::apache::lucene::store::RAMFile * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::BufferedIndexInput )))) file;
  jlong pointer;
  jlong length__;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_RAMInputStream__ */
