// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_ru_RussianAnalyzer__
#define __org_apache_lucene_analysis_ru_RussianAnalyzer__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace ru
          {
            class RussianAnalyzer;
          }
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::ru::RussianAnalyzer : public ::org::apache::lucene::analysis::Analyzer
{
public:
  RussianAnalyzer ();
  RussianAnalyzer (jcharArray);
  RussianAnalyzer (jcharArray, JArray< ::java::lang::String *> *);
private:
  static JArray< ::java::lang::String *> *makeStopWords (jcharArray);
public:
  RussianAnalyzer (jcharArray, ::java::util::Hashtable *);
  ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);
private:
  static const jint A = 0L;
  static const jint B = 1L;
  static const jint V = 2L;
  static const jint G = 3L;
  static const jint D = 4L;
  static const jint E = 5L;
  static const jint ZH = 6L;
  static const jint Z = 7L;
  static const jint I = 8L;
  static const jint I_ = 9L;
  static const jint K = 10L;
  static const jint L = 11L;
  static const jint M = 12L;
  static const jint N = 13L;
  static const jint O = 14L;
  static const jint P = 15L;
  static const jint R = 16L;
  static const jint S = 17L;
  static const jint T = 18L;
  static const jint U = 19L;
  static const jint X = 21L;
  static const jint CH = 23L;
  static const jint SH = 24L;
  static const jint SHCH = 25L;
  static const jint Y = 27L;
  static const jint SOFT = 28L;
  static const jint AE = 29L;
  static const jint IU = 30L;
  static const jint IA = 31L;
  static JArray<jcharArray> * RUSSIAN_STOP_WORDS;
  ::java::util::Set * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Analyzer )))) stopSet;
  jcharArray charset;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_ru_RussianAnalyzer__ */
