// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_index_TermVectorOffsetInfo__
#define __org_apache_lucene_index_TermVectorOffsetInfo__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace index
        {
          class TermVectorOffsetInfo;
        }
      }
    }
  }
}

class org::apache::lucene::index::TermVectorOffsetInfo : public ::java::lang::Object
{
public:
  TermVectorOffsetInfo ();
  TermVectorOffsetInfo (jint, jint);
  virtual jint getEndOffset () { return endOffset; }
  virtual void setEndOffset (jint);
  virtual jint getStartOffset () { return startOffset; }
  virtual void setStartOffset (jint);
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  static JArray< ::org::apache::lucene::index::TermVectorOffsetInfo *> *EMPTY_OFFSET_INFO;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  startOffset;
  jint endOffset;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_index_TermVectorOffsetInfo__ */
