// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_MMapDirectory__
#define __org_apache_lucene_store_MMapDirectory__

#pragma interface

#include <org/apache/lucene/store/FSDirectory.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class MMapDirectory;
          class IndexInput;
        }
      }
    }
  }
}

class org::apache::lucene::store::MMapDirectory : public ::org::apache::lucene::store::FSDirectory
{
public:
  MMapDirectory ();
  virtual ::org::apache::lucene::store::IndexInput *openInput (::java::lang::String *);

  friend class org_apache_lucene_store_MMapDirectory$1;
  friend class org_apache_lucene_store_MMapDirectory$MultiMMapIndexInput;
  friend class org_apache_lucene_store_MMapDirectory$MMapIndexInput;

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_MMapDirectory__ */
