// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_document_FieldSelectorResult__
#define __org_apache_lucene_document_FieldSelectorResult__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace document
        {
          class FieldSelectorResult;
        }
      }
    }
  }
}

class org::apache::lucene::document::FieldSelectorResult : public ::java::lang::Object
{
private:
  FieldSelectorResult (jint);
public:
  jboolean equals (::java::lang::Object *);
  jint hashCode () { return id; }
  static ::org::apache::lucene::document::FieldSelectorResult *LOAD;
  static ::org::apache::lucene::document::FieldSelectorResult *LAZY_LOAD;
  static ::org::apache::lucene::document::FieldSelectorResult *NO_LOAD;
  static ::org::apache::lucene::document::FieldSelectorResult *LOAD_AND_BREAK;
  static ::org::apache::lucene::document::FieldSelectorResult *LOAD_FOR_MERGE;
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  id;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_document_FieldSelectorResult__ */
