// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_QueryTermVector__
#define __org_apache_lucene_search_QueryTermVector__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class QueryTermVector;
        }
        namespace analysis
        {
          class Analyzer;
        }
      }
    }
  }
}

class org::apache::lucene::search::QueryTermVector : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getField () { return 0; }
  QueryTermVector (JArray< ::java::lang::String *> *);
  QueryTermVector (::java::lang::String *, ::org::apache::lucene::analysis::Analyzer *);
private:
  void processTerms (JArray< ::java::lang::String *> *);
public:
  ::java::lang::String *toString ();
  virtual jint size ();
  virtual JArray< ::java::lang::String *> *getTerms () { return terms; }
  virtual jintArray getTermFrequencies () { return termFreqs; }
  virtual jint indexOf (::java::lang::String *);
  virtual jintArray indexesOf (JArray< ::java::lang::String *> *, jint, jint);
private:
  JArray< ::java::lang::String *> * __attribute__((aligned(__alignof__( ::java::lang::Object )))) terms;
  jintArray termFreqs;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_QueryTermVector__ */
