// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_analysis_snowball_SnowballAnalyzer__
#define __org_apache_lucene_analysis_snowball_SnowballAnalyzer__

#pragma interface

#include <org/apache/lucene/analysis/Analyzer.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace analysis
        {
          namespace snowball
          {
            class SnowballAnalyzer;
          }
          class TokenStream;
        }
      }
    }
  }
}

class org::apache::lucene::analysis::snowball::SnowballAnalyzer : public ::org::apache::lucene::analysis::Analyzer
{
public:
  SnowballAnalyzer (::java::lang::String *);
  SnowballAnalyzer (::java::lang::String *, JArray< ::java::lang::String *> *);
  virtual ::org::apache::lucene::analysis::TokenStream *tokenStream (::java::lang::String *, ::java::io::Reader *);
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::org::apache::lucene::analysis::Analyzer )))) name;
  ::java::util::Set *stopSet;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_analysis_snowball_SnowballAnalyzer__ */
