// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_regex_PythonRegexCapabilities__
#define __org_apache_lucene_search_regex_PythonRegexCapabilities__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          namespace regex
          {
            class PythonRegexCapabilities;
          }
        }
      }
    }
  }
}

class org::apache::lucene::search::regex::PythonRegexCapabilities : public ::java::lang::Object
{
public:
  PythonRegexCapabilities ();
public:  // actually protected
  virtual void finalize ();
public:
  virtual void compile (::java::lang::String *);
  virtual jboolean match (::java::lang::String *);
  virtual ::java::lang::String *prefix ();
public:  // actually protected
  jlong __attribute__((aligned(__alignof__( ::java::lang::Object ))))  pythonRE;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_regex_PythonRegexCapabilities__ */
