// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_search_TopDocCollector__
#define __org_apache_lucene_search_TopDocCollector__

#pragma interface

#include <org/apache/lucene/search/HitCollector.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace search
        {
          class TopDocCollector;
          class TopDocs;
        }
        namespace util
        {
          class PriorityQueue;
        }
      }
    }
  }
}

class org::apache::lucene::search::TopDocCollector : public ::org::apache::lucene::search::HitCollector
{
public:
  TopDocCollector (jint);
public: // actually package-private
  TopDocCollector (jint, ::org::apache::lucene::util::PriorityQueue *);
public:
  virtual void collect (jint, jfloat);
  virtual jint getTotalHits () { return totalHits; }
  virtual ::org::apache::lucene::search::TopDocs *topDocs ();
private:
  jint __attribute__((aligned(__alignof__( ::org::apache::lucene::search::HitCollector ))))  numHits;
  jfloat minScore;
public: // actually package-private
  jint totalHits;
  ::org::apache::lucene::util::PriorityQueue *hq;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_search_TopDocCollector__ */
