// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __org_apache_lucene_store_RAMOutputStream__
#define __org_apache_lucene_store_RAMOutputStream__

#pragma interface

#include <org/apache/lucene/store/BufferedIndexOutput.h>
#include <gcj/array.h>

extern "Java"
{
  namespace org
  {
    namespace apache
    {
      namespace lucene
      {
        namespace store
        {
          class RAMOutputStream;
          class IndexOutput;
          class RAMFile;
        }
      }
    }
  }
}

class org::apache::lucene::store::RAMOutputStream : public ::org::apache::lucene::store::BufferedIndexOutput
{
public:
  RAMOutputStream ();
public: // actually package-private
  RAMOutputStream (::org::apache::lucene::store::RAMFile *);
public:
  virtual void writeTo (::org::apache::lucene::store::IndexOutput *);
  virtual void reset ();
  virtual void flushBuffer (jbyteArray, jint);
  virtual void close ();
  virtual void seek (jlong);
  virtual jlong length ();
private:
  ::org::apache::lucene::store::RAMFile * __attribute__((aligned(__alignof__( ::org::apache::lucene::store::BufferedIndexOutput )))) file;
  jlong pointer;
public:

  static ::java::lang::Class class$;
};

#endif /* __org_apache_lucene_store_RAMOutputStream__ */
